@@ -1,22 +1,26 @@
 # coding=utf-8
-"""
-Base Flask application class, used by tests or to be extended
-in real applications.
-"""
+"""Base Flask application class, used by tests or to be extended in real
+applications."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import errno
 import importlib
+import json
 import logging
 import logging.config
 import os
+import subprocess
+import warnings
 from functools import partial
 from itertools import chain, count
 from pathlib import Path
+from tempfile import NamedTemporaryFile
+from typing import Any, Dict
 
 import jinja2
 import sqlalchemy as sa
+import sqlalchemy.exc
 import yaml
 from babel.dates import LOCALTZ
 from flask import Blueprint, Flask, _request_ctx_stack, abort, \
@@ -30,7 +34,7 @@ from flask_babel import get_locale as babel_get_locale
 from flask_migrate import Migrate
 from flask_script import Manager as ScriptManager
 from pkg_resources import resource_filename
-from six import string_types, text_type
+from six import string_types
 from sqlalchemy.orm.attributes import NEVER_SET, NO_VALUE
 from werkzeug.datastructures import ImmutableDict
 from werkzeug.utils import import_string
@@ -51,6 +55,7 @@ from abilian.web.action import Endpoint, actions
 from abilian.web.admin import Admin
 from abilian.web.assets.filters import ClosureJS
 from abilian.web.blueprints import allow_access_for_roles
+from abilian.web.decorators import deprecated
 from abilian.web.filters import init_filters
 from abilian.web.nav import BreadcrumbItem
 from abilian.web.util import send_file_from_directory, url_for
@@ -61,11 +66,13 @@ logger = logging.getLogger(__name__)
 db = extensions.db
 __all__ = ['create_app', 'Application', 'ServiceManager']
 
+# Silence those warnings for now.
+warnings.simplefilter("ignore", category=sa.exc.SAWarning)
+
 
 class ServiceManager(object):
-    """
-    Mixin that provides lifecycle (register/start/stop) support for services.
-    """
+    """Mixin that provides lifecycle (register/start/stop) support for
+    services."""
 
     def __init__(self):
         self.services = {}
@@ -80,29 +87,28 @@ class ServiceManager(object):
 
 
 class PluginManager(object):
-    """
-    Mixin that provides support for loading plugins.
-    """
+    """Mixin that provides support for loading plugins."""
 
+    @deprecated
     def load_plugins(self):
         """Discover and load plugins.
 
-        At this point, prefer explicit loading using the :method:~`register_plugin`
-        method.
+        At this point, prefer explicit loading using the
+        :method:~`register_plugin` method.
         """
         loader = AppLoader()
         loader.load(__name__.split('.')[0])
         loader.register(self)
 
+    @deprecated
     def register_plugin(self, name):
-        """Load and register a plugin given its package name.
-        """
+        """Load and register a plugin given its package name."""
         logger.info("Registering plugin: " + name)
         module = importlib.import_module(name)
         module.register_plugin(self)
 
 
-default_config = dict(Flask.default_config)
+default_config = dict(Flask.default_config)  # type: Dict[str, Any]
 default_config.update(
     PRIVATE_SITE=False,
     TEMPLATE_DEBUG=False,
@@ -110,41 +116,52 @@ default_config.update(
     BABEL_ACCEPT_LANGUAGES=None,
     DEFAULT_COUNTRY=None,
     PLUGINS=(),
-    ADMIN_PANELS=('abilian.web.admin.panels.dashboard.DashboardPanel',
-                  'abilian.web.admin.panels.audit.AuditPanel',
-                  'abilian.web.admin.panels.login_sessions.LoginSessionsPanel',
-                  'abilian.web.admin.panels.settings.SettingsPanel',
-                  'abilian.web.admin.panels.users.UsersPanel',
-                  'abilian.web.admin.panels.groups.GroupsPanel',
-                  'abilian.web.admin.panels.sysinfo.SysinfoPanel',
-                  'abilian.services.vocabularies.admin.VocabularyPanel',
-                  'abilian.web.tags.admin.TagPanel'),
+    ADMIN_PANELS=(
+        'abilian.web.admin.panels.dashboard.DashboardPanel',
+        'abilian.web.admin.panels.audit.AuditPanel',
+        'abilian.web.admin.panels.login_sessions.LoginSessionsPanel',
+        'abilian.web.admin.panels.settings.SettingsPanel',
+        'abilian.web.admin.panels.users.UsersPanel',
+        'abilian.web.admin.panels.groups.GroupsPanel',
+        'abilian.web.admin.panels.sysinfo.SysinfoPanel',
+        'abilian.web.admin.panels.impersonate.ImpersonatePanel',
+        'abilian.services.vocabularies.admin.VocabularyPanel',
+        'abilian.web.tags.admin.TagPanel',
+    ),
     CELERYD_MAX_TASKS_PER_CHILD=1000,
     CELERY_ACCEPT_CONTENT=['pickle', 'json', 'msgpack', 'yaml'],
     CELERY_TIMEZONE=LOCALTZ,
     SENTRY_USER_ATTRS=('email', 'first_name', 'last_name'),
     SENTRY_INSTALL_CLIENT_JS=True,  # also install client JS
-    SENTRY_JS_VERSION='3.9.1',
+    SENTRY_JS_VERSION='1.1.22',
+    # TODO: remove, not needed for recent sentry-js
+    SENTRY_JS_PLUGINS=('console', 'jquery', 'native', 'require'),
     SESSION_COOKIE_NAME=None,
     SQLALCHEMY_POOL_RECYCLE=1800,  # 30min. default value in flask_sa is None
     SQLALCHEMY_TRACK_MODIFICATIONS=False,
-    LOGO_URL=Endpoint(
-        'abilian_static', filename='img/logo-abilian-32x32.png'),
+    LOGO_URL=Endpoint('abilian_static', filename='img/logo-abilian-32x32.png'),
     ABILIAN_UPSTREAM_INFO_ENABLED=False,  # upstream info extension
     TRACKING_CODE_SNIPPET='',  # tracking code to insert before </body>
-    MAIL_ADDRESS_TAG_CHAR=None)
+    MAIL_ADDRESS_TAG_CHAR=None,
+)
 default_config = ImmutableDict(default_config)
 
 
 class Application(Flask, ServiceManager, PluginManager):
-    """Base application class. Extend it in your own app.
+    """Base application class.
+
+    Extend it in your own app.
     """
     default_config = default_config
 
     #: Custom apps may want to always load some plugins: list them here.
-    APP_PLUGINS = ('abilian.web.search', 'abilian.web.tags',
-                   'abilian.web.comments', 'abilian.web.uploads',
-                   'abilian.web.attachments')
+    APP_PLUGINS = (
+        'abilian.web.search',
+        'abilian.web.tags',
+        'abilian.web.comments',
+        'abilian.web.uploads',
+        'abilian.web.attachments',
+    )
 
     #: Environment variable used to locate a config file to load last (after
     #: instance config file). Use this if you want to override some settings on a
@@ -160,8 +177,7 @@ class Application(Flask, ServiceManager, PluginManager):
     private_site = ConfigAttribute('PRIVATE_SITE')
 
     #: instance of :class:`.web.views.registry.Registry`.
-    # type: web.views.registry.Registry
-    default_view = None
+    default_view = None  # type: abilian.web.views.registry.Registry
 
     #: json serializable dict to land in Javascript under Abilian.api
     js_api = None
@@ -174,13 +190,20 @@ class Application(Flask, ServiceManager, PluginManager):
     celery_app_cls = FlaskCelery
 
     def __init__(self, name=None, config=None, *args, **kwargs):
-        kwargs.setdefault('instance_relative_config', True)
         name = name or __name__
 
+        instance_path = os.environ.get('FLASK_INSTANCE_PATH')
+        if instance_path:
+            kwargs['instance_path'] = instance_path
+        else:
+            kwargs.setdefault('instance_relative_config', True)
+
         # used by make_config to determine if we try to load config from instance /
         # environment variable /...
-        self._ABILIAN_INIT_TESTING_FLAG = (getattr(config, 'TESTING', False)
-                                           if config else False)
+        self._ABILIAN_INIT_TESTING_FLAG = (
+            getattr(config, 'TESTING', False)
+            if config else False
+        )
         Flask.__init__(self, name, *args, **kwargs)
         del self._ABILIAN_INIT_TESTING_FLAG
 
@@ -219,8 +242,8 @@ class Application(Flask, ServiceManager, PluginManager):
         if configured:
             with self.app_context():
                 try:
-                    settings = self.services['settings'].namespace(
-                        'config').as_dict()
+                    settings = self.services['settings']
+                    config = settings.namespace('config').as_dict()
                 except sa.exc.DatabaseError as exc:
                     # we may get here if DB is not initialized and "settings" table is
                     # missing. Command "initdb" must be run to initialize db, but first we
@@ -228,53 +251,20 @@ class Application(Flask, ServiceManager, PluginManager):
                     if not self.testing:
                         # durint tests this message will show up on every test, since db is
                         # always recreated
-                        logging.error(exc.message)
+                        logging.error(exc)
                     self.db.session.rollback()
                 else:
-                    self.config.update(settings)
+                    self.config.update(config)
 
         if not self.config.get('FAVICO_URL'):
             self.config['FAVICO_URL'] = self.config.get('LOGO_URL')
 
-        languages = self.config.get('BABEL_ACCEPT_LANGUAGES')
-        if languages is None:
-            languages = abilian.i18n.VALID_LANGUAGES_CODE
-        else:
-            languages = tuple(lang for lang in languages
-                              if lang in abilian.i18n.VALID_LANGUAGES_CODE)
-        self.config['BABEL_ACCEPT_LANGUAGES'] = languages
-
         self._jinja_loaders = list()
         self.register_jinja_loaders(
-            jinja2.PackageLoader('abilian.web', 'templates'))
+            jinja2.PackageLoader('abilian.web', 'templates'),
+        )
 
-        js_filters = (('closure_js',)
-                      if self.config.get('PRODUCTION', False) else None)
-
-        self._assets_bundles = {
-            'css': {
-                'options': dict(
-                    filters=('less', 'cssmin'),
-                    output='style-%(version)s.min.css')
-            },
-            'js-top': {
-                'options': dict(
-                    output='top-%(version)s.min.js', filters=js_filters)
-            },
-            'js': {
-                'options': dict(
-                    output='app-%(version)s.min.js', filters=js_filters)
-            },
-        }
-
-        # bundles for JS translations
-        for lang in languages:
-            code = 'js-i18n-' + lang
-            filename = 'lang-' + lang + '-%(version)s.min.js'
-            self._assets_bundles[code] = {
-                'options': dict(
-                    output=filename, filters=js_filters),
-            }
+        self.init_assets()
 
         for http_error_code in (403, 404, 500):
             self.install_default_handler(http_error_code)
@@ -283,19 +273,26 @@ class Application(Flask, ServiceManager, PluginManager):
             self.init_extensions()
             self.register_plugins()
             self.add_access_controller(
-                'static', allow_access_for_roles(Anonymous), endpoint=True)
+                'static',
+                allow_access_for_roles(Anonymous),
+                endpoint=True,
+            )
             # debugtoolbar: this is needed to have it when not authenticated on a
             # private site. We cannot do this in init_debug_toolbar, since auth
             # service is not yet installed
-            self.add_access_controller('debugtoolbar',
-                                       allow_access_for_roles(Anonymous))
+            self.add_access_controller(
+                'debugtoolbar',
+                allow_access_for_roles(Anonymous),
+            )
             self.add_access_controller(
                 '_debug_toolbar.static',
                 allow_access_for_roles(Anonymous),
-                endpoint=True)
+                endpoint=True,
+            )
 
         self.maybe_register_setup_wizard()
         self._finalize_assets_setup()
+
         # At this point all models should have been imported: time to configure
         # mappers. Normally Sqlalchemy does it when needed but mappers may be
         # configured inside sa.orm.class_mapper() which hides a misconfiguration: if
@@ -312,11 +309,60 @@ class Application(Flask, ServiceManager, PluginManager):
 
         # Initialize Abilian core services.
         # Must come after all entity classes have been declared.
-        # Inherited from ServiceManager. Will need some configuration love later.
+        # Inherited from ServiceManager. Will need some configuration love
+        # later.
         if not self.config.get('TESTING', False):
             with self.app_context():
                 self.start_services()
 
+        if os.environ.get("FLASK_VALIDATE_HTML"):
+            self.after_request(self.validate_response)
+
+    def init_assets(self):
+        languages = self.config.get('BABEL_ACCEPT_LANGUAGES')
+        if languages is None:
+            languages = abilian.i18n.VALID_LANGUAGES_CODE
+        else:
+            languages = tuple(
+                lang for lang in languages
+                if lang in abilian.i18n.VALID_LANGUAGES_CODE
+            )
+        self.config['BABEL_ACCEPT_LANGUAGES'] = languages
+        js_filters = (
+            ('closure_js',)
+            if self.config.get('PRODUCTION', False) else None
+        )
+        self._assets_bundles = {
+            'css': {
+                'options':
+                dict(
+                    filters=('less', 'cssmin'),
+                    output='style-%(version)s.min.css',
+                ),
+            },
+            'js-top': {
+                'options':
+                dict(
+                    output='top-%(version)s.min.js',
+                    filters=js_filters,
+                ),
+            },
+            'js': {
+                'options':
+                dict(
+                    output='app-%(version)s.min.js',
+                    filters=js_filters,
+                ),
+            },
+        }
+        # bundles for JS translations
+        for lang in languages:
+            code = 'js-i18n-' + lang
+            filename = 'lang-' + lang + '-%(version)s.min.js'
+            self._assets_bundles[code] = {
+                'options': dict(output=filename, filters=js_filters),
+            }
+
     def _setup_script_manager(self):
         manager = self.script_manager
 
@@ -336,7 +382,9 @@ class Application(Flask, ServiceManager, PluginManager):
                     '\n' + ('*' * 79) + '\n'
                     'Could not find command manager at %r, using a default one\n'
                     'Some commands might not be available\n' +
-                    ('*' * 79) + '\n', manager_import_path)
+                    ('*' * 79) + '\n',
+                    manager_import_path,
+                )
                 from abilian.core.commands import setup_abilian_commands
                 manager = ScriptManager()
                 setup_abilian_commands(manager)
@@ -349,8 +397,8 @@ class Application(Flask, ServiceManager, PluginManager):
     def _set_current_celery_app(self):
         """Listener for `before_first_request`.
 
-        Set our celery app as current, so that task use the correct config.
-        Without that tasks may use their default set app.
+        Set our celery app as current, so that task use the correct
+        config. Without that tasks may use their default set app.
         """
         self.extensions['celery'].set_current()
 
@@ -367,19 +415,20 @@ class Application(Flask, ServiceManager, PluginManager):
     def init_breadcrumbs(self):
         """Insert the first element in breadcrumbs.
 
-        This happens during `request_started` event, which is triggered before any
-        url_value_preprocessor and `before_request` handlers.
+        This happens during `request_started` event, which is triggered
+        before any url_value_preprocessor and `before_request` handlers.
         """
         g.breadcrumb.append(
-            BreadcrumbItem(
-                icon='home', url='/' + request.script_root))
+            BreadcrumbItem(icon='home', url='/' + request.script_root),
+        )
 
     def check_instance_folder(self, create=False):
-        """Verify instance folder exists, is a directory, and has necessary permissions.
+        """Verify instance folder exists, is a directory, and has necessary
+        permissions.
 
         :param:create: if `True`, creates directory hierarchy
 
-        :raises: OSError with relevant errno
+        :raises: OSError with relevant errno if something is wrong.
         """
         path = Path(self.instance_path)
         err = None
@@ -428,7 +477,11 @@ class Application(Flask, ServiceManager, PluginManager):
         except IOError:
             return config
 
-        config.from_envvar(self.CONFIG_ENVVAR, silent=True)
+        # If the env var specifies a configuration file, it must exist
+        # (and execute with no exceptions) - we don't want the application
+        # to run with an unprecised or insecure configuration.
+        if self.CONFIG_ENVVAR in os.environ:
+            config.from_envvar(self.CONFIG_ENVVAR, silent=False)
 
         if 'WTF_CSRF_ENABLED' not in config:
             config['WTF_CSRF_ENABLED'] = config.get('CSRF_ENABLED', True)
@@ -447,29 +500,36 @@ class Application(Flask, ServiceManager, PluginManager):
         logging_file = self.config.get('LOGGING_CONFIG_FILE')
         if logging_file:
             logging_file = os.path.abspath(
-                os.path.join(self.instance_path, logging_file))
+                os.path.join(self.instance_path, logging_file),
+            )
         else:
             logging_file = resource_filename(__name__, 'default_logging.yml')
 
         if logging_file.endswith('.conf'):
             # old standard 'ini' file config
             logging.config.fileConfig(
-                logging_file, disable_existing_loggers=False)
+                logging_file,
+                disable_existing_loggers=False,
+            )
         elif logging_file.endswith('.yml'):
             # yml config file
-            logging_cfg = yaml.load(open(logging_file, 'r'))
+            logging_cfg = yaml.safe_load(open(logging_file, 'r'))
             logging_cfg.setdefault('version', 1)
             logging_cfg.setdefault('disable_existing_loggers', False)
             logging.config.dictConfig(logging_cfg)
 
     def init_debug_toolbar(self):
-        if (not self.testing and self.config.get('DEBUG_TB_ENABLED') and
-                'debugtoolbar' not in self.blueprints):
+        if (
+            not self.testing and self.config.get('DEBUG_TB_ENABLED') and
+            'debugtoolbar' not in self.blueprints
+        ):
             try:
                 from flask_debugtoolbar import DebugToolbarExtension
             except ImportError:
-                logger.warning('DEBUG_TB_ENABLED is on but flask_debugtoolbar '
-                               'is not installed.')
+                logger.warning(
+                    'DEBUG_TB_ENABLED is on but flask_debugtoolbar '
+                    'is not installed.',
+                )
             else:
                 dbt = DebugToolbarExtension()
                 default_config = dbt._default_config(self)
@@ -477,10 +537,8 @@ class Application(Flask, ServiceManager, PluginManager):
 
                 if 'DEBUG_TB_PANELS' not in self.config:
                     # add our panels to default ones
-                    self.config['DEBUG_TB_PANELS'] = list(default_config[
-                        'DEBUG_TB_PANELS'])
-                    self.config['DEBUG_TB_PANELS'].append(
-                        'abilian.services.indexing.debug_toolbar.IndexedTermsDebugPanel'
+                    self.config['DEBUG_TB_PANELS'] = list(
+                        default_config['DEBUG_TB_PANELS'],
                     )
                 init_dbt(self)
                 for view_name in self.view_functions:
@@ -488,8 +546,7 @@ class Application(Flask, ServiceManager, PluginManager):
                         extensions.csrf.exempt(self.view_functions[view_name])
 
     def init_extensions(self):
-        """Initialize flask extensions, helpers and services.
-        """
+        """Initialize flask extensions, helpers and services."""
         self.init_debug_toolbar()
         redis.Extension(self)
         extensions.mail.init_app(self)
@@ -517,7 +574,10 @@ class Application(Flask, ServiceManager, PluginManager):
 
         babel.init_app(self)
         babel.add_translations(
-            'wtforms', translations_dir='locale', domain='wtforms')
+            'wtforms',
+            translations_dir='locale',
+            domain='wtforms',
+        )
         babel.add_translations('abilian')
         babel.localeselector(abilian.i18n.localeselector)
         babel.timezoneselector(abilian.i18n.timezoneselector)
@@ -573,14 +633,13 @@ class Application(Flask, ServiceManager, PluginManager):
 
             @http_error_pages.route('/<int:code>')
             def error_page(code):
-                """ Helper for development to show 403, 404, 500..."""
+                """Helper for development to show 403, 404, 500..."""
                 abort(code)
 
             self.register_blueprint(http_error_pages, url_prefix='/http_error')
 
     def register_plugins(self):
-        """Load plugins listed in config variable 'PLUGINS'.
-        """
+        """Load plugins listed in config variable 'PLUGINS'."""
         registered = set()
         for plugin_fqdn in chain(self.APP_PLUGINS, self.config['PLUGINS']):
             if plugin_fqdn not in registered:
@@ -604,12 +663,17 @@ class Application(Flask, ServiceManager, PluginManager):
         Role instances.
         """
         roles = options.pop('roles', None)
-        super(Application, self).add_url_rule(rule, endpoint, view_func,
-                                              **options)
+        super(Application, self).add_url_rule(
+            rule, endpoint, view_func,
+            **options
+        )
 
         if roles:
             self.add_access_controller(
-                endpoint, allow_access_for_roles(roles), endpoint=True)
+                endpoint,
+                allow_access_for_roles(roles),
+                endpoint=True,
+            )
 
     def add_access_controller(self, name, func, endpoint=False):
         """Add an access controller.
@@ -624,7 +688,9 @@ class Application(Flask, ServiceManager, PluginManager):
         if endpoint:
             adder = auth_state.add_endpoint_access_controller
             if not isinstance(name, string_types):
-                raise ValueError('{} is not a valid endpoint name', repr(name))
+                raise ValueError(
+                    '{} is not a valid endpoint name'.format(repr(name)),
+                )
 
         adder(name, func)
 
@@ -649,11 +715,14 @@ class Application(Flask, ServiceManager, PluginManager):
         self.add_url_rule(
             url_path,
             endpoint=endpoint,
-            view_func=partial(
-                send_file_from_directory, directory=directory),
-            roles=roles)
+            view_func=partial(send_file_from_directory, directory=directory),
+            roles=roles,
+        )
         self.add_access_controller(
-            endpoint, allow_access_for_roles(Anonymous), endpoint=True)
+            endpoint,
+            allow_access_for_roles(Anonymous),
+            endpoint=True,
+        )
 
     #
     # Templating and context injection setup
@@ -669,7 +738,8 @@ class Application(Flask, ServiceManager, PluginManager):
             url_for=url_for,
             user_photo_url=user_photo_url,
             NO_VALUE=NO_VALUE,
-            NEVER_SET=NEVER_SET)
+            NEVER_SET=NEVER_SET,
+        )
         init_filters(env)
         return env
 
@@ -688,7 +758,9 @@ class Application(Flask, ServiceManager, PluginManager):
                 cache_dir.mkdir(0o775, parents=True)
 
             options['bytecode_cache'] = jinja2.FileSystemBytecodeCache(
-                str(cache_dir), '%s.cache')
+                str(cache_dir),
+                '%s.cache',
+            )
 
         if (self.config.get('DEBUG', False) and
                 self.config.get('TEMPLATE_DEBUG', False)):
@@ -711,16 +783,15 @@ class Application(Flask, ServiceManager, PluginManager):
         """
         if not hasattr(self, '_jinja_loaders'):
             raise ValueError(
-                'Cannot register new jinja loaders after first template rendered'
+                'Cannot register new jinja loaders after first template rendered',
             )
 
         self._jinja_loaders.extend(loaders)
 
     @locked_cached_property
     def jinja_loader(self):
-        """Search templates in custom app templates dir (default flask behaviour),
-        fallback on abilian templates.
-        """
+        """Search templates in custom app templates dir (default Flask
+        behaviour), fallback on abilian templates."""
         loaders = self._jinja_loaders
         del self._jinja_loaders
         loaders.append(Flask.jinja_loader.func(self))
@@ -752,10 +823,8 @@ class Application(Flask, ServiceManager, PluginManager):
         return Flask.handle_exception(self, e)
 
     def _remove_session_save_objects(self):
-        """
-        Used during exception handling in case we need to remove() session: keep
-        instances and merge them in the new session.
-        """
+        """Used during exception handling in case we need to remove() session:
+        keep instances and merge them in the new session."""
         if self.testing:
             return
         # Before destroying the session, get all instances to be attached to the
@@ -773,7 +842,8 @@ class Application(Flask, ServiceManager, PluginManager):
         session = db.session()
 
         for key, obj, load in g_objs:
-            # replace obj instance in bad session by new instance in fresh session
+            # replace obj instance in bad session by new instance in fresh
+            # session
             setattr(g, key, session.merge(obj, load=load))
 
         # refresh `current_user`
@@ -782,22 +852,21 @@ class Application(Flask, ServiceManager, PluginManager):
             _request_ctx_stack.top.user = session.merge(user, load=load)
 
     def log_exception(self, exc_info):
-        """Log exception only if sentry is not installed (this avoids getting error
-        twice in sentry).
-        """
+        """Log exception only if sentry is not installed (this avoids getting
+        error twice in sentry)."""
         if 'sentry' not in self.extensions:
             super(Application, self).log_exception(exc_info)
 
     def init_sentry(self):
-        """Install Sentry handler if config defines 'SENTRY_DSN'.
-        """
+        """Install Sentry handler if config defines 'SENTRY_DSN'."""
         if self.config.get('SENTRY_DSN'):
             try:
                 from abilian.core.sentry import Sentry
             except ImportError:
                 logger.error(
                     'SENTRY_DSN is defined in config but package "raven" is not '
-                    'installed.')
+                    'installed.',
+                )
                 return
 
             ext = Sentry(self, logging=True, level=logging.ERROR)
@@ -823,7 +892,8 @@ class Application(Flask, ServiceManager, PluginManager):
                 id=0,
                 last_name='SYSTEM',
                 email='system@example.com',
-                can_login=False)
+                can_login=False,
+            )
             db.session.add(root)
             db.session.commit()
 
@@ -846,7 +916,8 @@ class Application(Flask, ServiceManager, PluginManager):
 
         # set up load_path for application static dir. This is required since we are
         # setting Environment.load_path for other assets (like core_bundle below),
-        # in this case Flask-Assets uses webasssets resolvers instead of Flask's one
+        # in this case Flask-Assets uses webasssets resolvers instead of
+        # Flask's one
         assets.append_path(self.static_folder, self.static_url_path)
 
         # filters options
@@ -867,7 +938,8 @@ class Application(Flask, ServiceManager, PluginManager):
             'min',
             str(assets_dir),
             endpoint='webassets_static',
-            roles=Anonymous)
+            roles=Anonymous,
+        )
 
     def _finalize_assets_setup(self):
         assets = self.extensions['webassets']
@@ -902,7 +974,7 @@ class Application(Flask, ServiceManager, PluginManager):
 
         :param type_: `"css"`, `"js-top"` or `"js""`.
 
-        :param \*asset:
+        :param assets:
             a path to file, a :ref:`webassets.Bundle <webassets:bundles>` instance
             or a callable that returns a :ref:`webassets.Bundle <webassets:bundles>`
             instance.
@@ -911,8 +983,11 @@ class Application(Flask, ServiceManager, PluginManager):
         """
         supported = self._assets_bundles.keys()
         if type_ not in supported:
-            raise KeyError("Invalid type: %s. Valid types: ",
-                           repr(type_), ', '.join(sorted(supported)))
+            raise KeyError(
+                "Invalid type: %s. Valid types: ",
+                repr(type_),
+                ', '.join(sorted(supported)),
+            )
 
         for asset in assets:
             if not isinstance(asset, Bundle) and callable(asset):
@@ -921,7 +996,8 @@ class Application(Flask, ServiceManager, PluginManager):
             self._assets_bundles[type_].setdefault('bundles', []).append(asset)
 
     def register_i18n_js(self, *paths):
-        """Register templates path translations files, like `select2/select2_locale_{lang}.js`.
+        """Register templates path translations files, like
+        `select2/select2_locale_{lang}.js`.
 
         Only existing files are registered.
         """
@@ -941,7 +1017,8 @@ class Application(Flask, ServiceManager, PluginManager):
     def _register_base_assets(self):
         """Register assets needed by Abilian.
 
-        This is done in a separate method in order to allow applications to redefine it at will.
+        This is done in a separate method in order to allow applications
+        to redefine it at will.
         """
         from abilian.web import assets as bundles
 
@@ -953,11 +1030,13 @@ class Application(Flask, ServiceManager, PluginManager):
     def install_default_handler(self, http_error_code):
         """Install a default error handler for `http_error_code`.
 
-        The default error handler renders a template named error404.html for
-        http_error_code 404.
+        The default error handler renders a template named error404.html
+        for http_error_code 404.
         """
-        logger.debug('Set Default HTTP error handler for status code %d',
-                     http_error_code)
+        logger.debug(
+            'Set Default HTTP error handler for status code %d',
+            http_error_code,
+        )
         handler = partial(self.handle_http_error, http_error_code)
         self.errorhandler(http_error_code)(handler)
 
@@ -979,6 +1058,50 @@ class Application(Flask, ServiceManager, PluginManager):
         template = 'error{:d}.html'.format(code)
         return render_template(template, error=error), code
 
+    def validate_response(self, response):
+        SKIPPED_URLS = [
+            # FIXME: later
+            'http://localhost/admin/settings',
+        ]
+        if response.direct_passthrough:
+            return response
+
+        data = response.data
+        assert isinstance(data, bytes)
+        # assert response.status_code in [200, 302, 401]
+
+        if response.status_code == 302:
+            return response
+
+        if request.url in SKIPPED_URLS:
+            return response
+
+        if response.mimetype == 'text/html':
+            with NamedTemporaryFile() as tmpfile:
+                tmpfile.write(data)
+                tmpfile.flush()
+                try:
+                    subprocess.check_output(["htmlhint", tmpfile.name])
+                except subprocess.CalledProcessError as e:
+                    print("htmllhint output:")
+                    print(e.output)
+                    raise AssertionError(
+                        "HTML was not valid for URL: {}".format(request.url),
+                    )
+
+        elif response.mimetype == 'application/json':
+            try:
+                json.loads(response.data)
+            except BaseException:
+                raise AssertionError(
+                    "JSON was not valid for URL: {}".format(request.url),
+                )
+
+        # else:
+        #     raise AssertionError("Unknown mime type: " + response.mimetype)
+
+        return response
+
 
 def create_app(config=None):
     return Application(config)
