@@ -8,6 +8,7 @@ import runpy
 from pprint import pformat
 
 import sqlalchemy as sa
+import sqlalchemy.exc
 from flask import current_app
 from flask_script import Manager, prompt_pass
 from six import text_type
@@ -56,7 +57,7 @@ def _log_config(config):
     lines = ["Application configuration:"]
 
     if config.get('CONFIGURED'):
-        settings = current_app.services['settings']
+        settings = get_service("settings")
         try:
             db_settings = set(settings.namespace('config').keys())
         except sa.exc.ProgrammingError:
@@ -81,7 +82,8 @@ def _log_config(config):
                 "Version: {version}".format(
                     configured_path=unoconv,
                     abspath=os.path.abspath(unoconv),
-                    version=conversion._unoconv_handler.unoconv_version))
+                    version=conversion._unoconv_handler.unoconv_version,
+                ))
 
 
 def log_config(config):
@@ -94,23 +96,32 @@ def log_config(config):
 
 
 @manager.option(
-    '-p', '--port', dest='port', help='listening port', default=5000)
+    '-p',
+    '--port',
+    dest='port',
+    help='listening port',
+    default=5000,
+)
 @manager.option(
     '--show-config',
     dest='show_config',
     action='store_const',
     const=True,
     default=False,
-    help='show application configuration on startup')
+    help='show application configuration on startup',
+)
 @manager.option(
     '--ssl',
     dest='ssl',
     action='store_const',
     default=False,
     const=True,
-    help='Enable werkzeug SSL')
+    help='Enable werkzeug SSL',
+)
 def run(port, show_config, ssl):
-    """Like runserver. May also print application configuration if used with
+    """Like runserver.
+
+    May also print application configuration if used with
     --show-config.
     """
     app = current_app
@@ -131,16 +142,14 @@ def run(port, show_config, ssl):
 
 @manager.command
 def initdb():
-    """Create application DB.
-    """
+    """Create application DB."""
     print("Creating DB using engine: {}".format(db))
     current_app.create_db()
 
 
 @manager.command
 def dropdb():
-    """Drop the application DB.
-    """
+    """Drop the application DB."""
     confirm = input("Are you sure you want to drop the database? (Y/N) ")
     print("Dropping DB using engine: {}".format(db))
     if confirm.lower() == 'y':
@@ -150,13 +159,11 @@ def dropdb():
 
 @manager.command
 def routes():
-    """Show all the routes registered in Flask.
-    """
+    """Show all the routes registered in Flask."""
     output = []
     for rule in current_app.url_map.iter_rules():
         methods = ','.join(rule.methods)
         path = urllib.parse.unquote(rule.rule)
-        # line = urllib.parse.unquote()
         output.append((rule.endpoint, methods, path))
 
     for endpoint, methods, path in sorted(output):
@@ -170,20 +177,28 @@ password_opt = manager.option(
     '--password',
     dest='password',
     default=None,
-    help='If absent, a prompt will ask for password',)
+    help='If absent, a prompt will ask for password',
+)
 role_opt = manager.option(
     '-r',
     '--role',
     dest='role',
-    choices=[r.name for r in Role.assignable_roles()],)
+    choices=[r.name for r in Role.assignable_roles()],
+)
 name_opt = manager.option(
-    '-n', '--name', dest='name', default=None, help='Last name (e.g "Smith")')
+    '-n',
+    '--name',
+    dest='name',
+    default=None,
+    help='Last name (e.g "Smith")',
+)
 firstname_opt = manager.option(
     '-f',
     '--firstname',
     dest='first_name',
     default=None,
-    help='Fist name (e.g. "John")')
+    help='Fist name (e.g. "John")',
+)
 
 
 @email_opt
@@ -192,22 +207,22 @@ firstname_opt = manager.option(
 @name_opt
 @firstname_opt
 def createuser(email, password, role=None, name=None, first_name=None):
-    """Create new user.
-    """
+    """Create new user."""
     email = text_type(email)
     if User.query.filter(User.email == email).count() > 0:
         print("A user with email '{}' already exists, aborting.".format(email))
         return
 
     if password is None:
-        password = prompt_pass(u'Password')
+        password = prompt_pass('Password')
 
     user = User(
         email=email,
         password=password,
         last_name=name,
         first_name=first_name,
-        can_login=True)
+        can_login=True,
+    )
     db.session.add(user)
 
     if role in ('admin',):
@@ -234,11 +249,10 @@ def createadmin(email, password, name=None, first_name=None):
 @email_opt
 @password_opt
 def passwd(email, password=None):
-    """Change the password for the given user.
-    """
+    """Change the password for the given user."""
     user = User.query.filter(User.email == email).one()
     if password is None:
-        password = prompt_pass(u'New password: ')
+        password = prompt_pass('New password: ')
 
     user.set_password(password)
     db.session.commit()
@@ -247,6 +261,5 @@ def passwd(email, password=None):
 
 @manager.command
 def script(path):
-    """Run given script in the app context.
-    """
+    """Run given script in the app context."""
     runpy.run_path(path, run_name='__main__')
