@@ -1,20 +1,21 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import time
 from collections import deque
 
-import progressbar
 import sqlalchemy as sa
 import whoosh
 from flask import current_app
 from six import string_types
 from sqlalchemy.orm.session import Session
+from tqdm import tqdm
 from whoosh.writing import CLEAR, AsyncWriter
 
+from abilian.services import get_service
+
 from .base import manager
 
 STOP = object()
@@ -33,13 +34,15 @@ def reindex(clear=False, progressive=False, batch_size=None):
                      index. Unused in single transaction mode. If `None` then
                      all documents of same content type are written at once.
     """
-    svc = current_app.services['indexing']
-    adapted = svc.adapted
-    index = svc.app_state.indexes['default']
+    index_service = get_service('indexing')
+    adapted = index_service.adapted
+    index = index_service.app_state.indexes['default']
     session = Session(
-        bind=current_app.db.session.get_bind(None, None), autocommit=True)
+        bind=current_app.db.session.get_bind(None, None),
+        autocommit=True,
+    )
 
-    setattr(session, '_model_changes', {})  # please flask-sqlalchemy <= 1.0
+    session._model_changes = {}  # please flask-sqlalchemy <= 1.0
     indexed = set()
     cleared = set()
     if batch_size is not None:
@@ -47,11 +50,17 @@ def reindex(clear=False, progressive=False, batch_size=None):
 
     strategy = progressive_mode if progressive else single_transaction
     strategy = strategy(
-        index, clear=clear, progressive=progressive, batch_size=batch_size)
+        index,
+        clear=clear,
+        progressive=progressive,
+        batch_size=batch_size,
+    )
     next(strategy)  # starts generator
-    count_indexed = 0
 
-    for cls in sorted(svc.app_state.indexed_classes, key=lambda c: c.__name__):
+    for cls in sorted(
+            index_service.app_state.indexed_classes,
+            key=lambda c: c.__name__,
+    ):
         current_object_type = cls._object_type()
 
         if not clear and current_object_type not in cleared:
@@ -71,50 +80,48 @@ def reindex(clear=False, progressive=False, batch_size=None):
                 count = query.count()
             except Exception as e:
                 current_app.logger.error(
-                    "Indexing error on class {}: {}".format(name, repr(e)))
+                    "Indexing error on class {}: {}".format(name, repr(e)),
+                )
                 continue
 
+            print("*" * 79)
+            print("{}".format(name))
             if count == 0:
-                print("{}: 0".format(name))
+                print("*" * 79)
+                print("{}".format(name))
                 continue
 
-            widgets = [
-                name, ': ', progressbar.Counter(), '/{}'.format(count), ' ',
-                progressbar.Timer(), ' ', progressbar.Percentage(), ' ',
-                progressbar.Bar(), ' ', progressbar.ETA()
-            ]
-            progress = progressbar.ProgressBar(widgets=widgets, maxval=count)
-            progress.start()
+            print("*" * 79)
+            print("{}".format(name))
             count_current = 0
+            with tqdm(total=count) as bar:
+                for obj in query.yield_per(1000):
+                    if obj.object_type != current_object_type:
+                        # may happen if obj is a subclass and its parent class is also
+                        # indexable
+                        bar.update(1)
+                        continue
 
-            for obj in query.yield_per(1000):
-                if obj.object_type != current_object_type:
-                    # may happen if obj is a subclass and its parent class is also
-                    # indexable
-                    continue
+                    object_key = obj.object_key
 
-                object_key = obj.object_key
+                    if object_key in indexed:
+                        bar.update(1)
+                        continue
+                    document = index_service.get_document(obj, adapter)
+                    strategy.send(document)
+                    indexed.add(object_key)
 
-                if object_key in indexed:
-                    continue
-                document = svc.get_document(obj, adapter)
-                strategy.send(document)
-                indexed.add(object_key)
-                count_indexed += 1
-                count_current += 1
-                try:
-                    progress.update(count_current)
-                except ValueError:
-                    pass
+                    if batch_size is not None and (
+                            count_current % batch_size
+                    ) == 0:
+                        bar.update(1)
+                        strategy.send(COMMIT)
 
-                if batch_size is not None and (count_current % batch_size) == 0:
-                    strategy.send(COMMIT)
+                    bar.update(1)
 
             if batch_size is None:
                 strategy.send(COMMIT)
 
-            progress.finish()
-
         strategy.send(COMMIT)
 
     try:
