@@ -1,8 +1,6 @@
 # coding=utf-8
-"""
-Base class for entities, objects that are managed by the Abilian framwework
-(unlike SQLAlchemy models which are considered lower-level).
-"""
+"""Base class for entities, objects that are managed by the Abilian framwework
+(unlike SQLAlchemy models which are considered lower-level)."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -69,29 +67,26 @@ event.listen(mapper, 'before_delete', before_delete_listener)
 
 
 def auto_slug_on_insert(mapper, connection, target):
-    """
-    Generate a slug from :prop:`Entity.auto_slug` for new entities, unless slug
-    is already set.
-    """
+    """Generate a slug from :prop:`Entity.auto_slug` for new entities, unless
+    slug is already set."""
     if target.slug is None and target.name:
         target.slug = target.auto_slug
 
 
 def auto_slug_after_insert(mapper, connection, target):
-    """
-    Generate a slug from entity_type and id, unless slug is already set.
-    """
+    """Generate a slug from entity_type and id, unless slug is already set."""
     if target.slug is None:
-        target.slug = u'{name}{sep}{id}'.format(
+        target.slug = '{name}{sep}{id}'.format(
             name=target.entity_class.lower(),
             sep=target.SLUG_SEPARATOR,
-            id=target.id)
+            id=target.id,
+        )
 
 
 @event.listens_for(Session, 'after_attach')
 def setup_default_permissions(session, instance):
-    """
-    Setup default permissions on newly created entities according to
+    """Setup default permissions on newly created entities according to.
+
     :attr:`Entity.__default_permissions__`.
     """
     if instance not in session.new or not isinstance(instance, Entity):
@@ -105,11 +100,12 @@ def setup_default_permissions(session, instance):
 
 
 def _setup_default_permissions(instance):
-    """eparate method to conveniently call it from scripts for example.
-    """
-    security = current_app.services['security']
+    """Separate method to conveniently call it from scripts for example."""
+    from abilian.services import get_service
+
+    security = get_service('security')
     for permission, roles in instance.__default_permissions__:
-        if permission == u'create':
+        if permission == 'create':
             # use str for comparison instead of `abilian.services.security.CREATE`
             # symbol to avoid imports that quickly become circular.
             #
@@ -120,8 +116,9 @@ def _setup_default_permissions(instance):
 
 
 class _EntityInherit(object):
-    """Mixin for Entity subclasses. Entity meta-class takes care of inserting it in
-    base classes.
+    """Mixin for Entity subclasses.
+
+    Entity meta-class takes care of inserting it in base classes.
     """
     __indexable__ = True
 
@@ -130,15 +127,19 @@ class _EntityInherit(object):
         return Column(
             Integer,
             ForeignKey(
-                'entity.id', use_alter=True, name='fk_inherited_entity_id'),
+                'entity.id',
+                use_alter=True,
+                name='fk_inherited_entity_id',
+            ),
             primary_key=True,
-            info=SYSTEM | SEARCHABLE)
+            info=SYSTEM | SEARCHABLE,
+        )
 
     @declared_attr
     def __mapper_args__(cls):
         return {
             'polymorphic_identity': cls.entity_type,
-            'inherit_condition': cls.id == Entity.id
+            'inherit_condition': cls.id == Entity.id,
         }
 
 
@@ -148,7 +149,9 @@ BaseMeta = db.Model.__class__
 class EntityQuery(db.Model.query_class):
 
     def with_permission(self, permission, user=None):
-        security = current_app.services['security']
+        from abilian.services import get_service
+
+        security = get_service('security')
         if hasattr(self, '_query_entity_zero'):
             # SQLAlchemy 1.1+
             model = self._query_entity_zero().entity_zero.entity
@@ -156,13 +159,15 @@ class EntityQuery(db.Model.query_class):
             # SQLAlchemy 1.0
             model = self._entity_zero().entity_zero.entity
         expr = security.query_entity_with_permission(
-            permission, user, Model=model)
+            permission,
+            user,
+            Model=model,
+        )
         return self.filter(expr)
 
 
 class EntityMeta(BaseMeta):
-    """
-    Metaclass for Entities. It properly sets-up subclasses by adding
+    """Metaclass for Entities. It properly sets up subclasses by adding
     _EntityInherit to `__bases__`.
 
     `_EntityInherit` provides `id` attibute and `__mapper_args__`
@@ -178,8 +183,11 @@ class EntityMeta(BaseMeta):
                 entity_type_base = d.get('ENTITY_TYPE_BASE')
                 if not entity_type_base:
                     for base in bases:
-                        entity_type_base = getattr(base, 'ENTITY_TYPE_BASE',
-                                                   None)
+                        entity_type_base = getattr(
+                            base,
+                            'ENTITY_TYPE_BASE',
+                            None,
+                        )
                         if entity_type_base:
                             break
                     else:
@@ -195,16 +203,19 @@ class EntityMeta(BaseMeta):
                 elif not isinstance(default_permissions, collections.Set):
                     raise TypeError(
                         '__default_permissions__ is neither a dict or set, '
-                        'cannot create class {}'.format(classname))
+                        'cannot create class {}'.format(classname),
+                    )
 
                 # also ensure that `roles` set is immutable, too
                 default_permissions = frozenset(
                     (permission, frozenset(roles))
-                    for permission, roles in default_permissions)
+                    for permission, roles in default_permissions
+                )
                 d['__default_permissions__'] = default_permissions
 
             d['SLUG_SEPARATOR'] = text_type(
-                d.get('SLUG_SEPARATOR', Entity.SLUG_SEPARATOR))
+                d.get('SLUG_SEPARATOR', Entity.SLUG_SEPARATOR),
+            )
 
         cls = BaseMeta.__new__(mcs, classname, bases, d)
 
@@ -252,11 +263,19 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
     index_to = __indexation_args__.setdefault('index_to', ())
     index_to += BaseMixin.__indexation_args__.setdefault('index_to', ())
     index_to += (
-        ('_indexable_roles_and_users', ('allowed_roles_and_users',)),
-        ('_indexable_tag_ids', ('tag_ids',)),
-        ('_indexable_tag_text', (
-            'tag_text',
-            'text',)),)
+        (
+            '_indexable_roles_and_users',
+            ('allowed_roles_and_users',),
+        ),
+        (
+            '_indexable_tag_ids',
+            ('tag_ids',),
+        ),
+        (
+            '_indexable_tag_text',
+            ('tag_text', 'text'),
+        ),
+    )
     __indexation_args__['index_to'] = index_to
     del index_to
 
@@ -289,7 +308,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
          del dp
     """
 
-    SLUG_SEPARATOR = u'-'  # \x2d \u002d HYPHEN-MINUS
+    SLUG_SEPARATOR = '-'  # \x2d \u002d HYPHEN-MINUS
 
     query_class = EntityQuery
 
@@ -301,7 +320,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
         else:
             return {
                 'polymorphic_identity': cls.entity_type,
-                'inherit_condition': cls.id == Entity.id
+                'inherit_condition': cls.id == Entity.id,
             }
 
     #: The name is a string that is shown to the user; it could be a title
@@ -325,7 +344,11 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
     _entity_type = Column('entity_type', String(1000), nullable=False)
     entity_type = None
 
-    meta = Column(JSONDict(), nullable=False, default=dict, server_default='{}')
+    meta = Column(
+        JSONDict(),
+        nullable=False,
+        default=dict,
+        server_default='{}')
     """
     A dictionnary of simple values (JSON-serializable) to conveniently annotate
     the entity.
@@ -361,8 +384,9 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
 
     @property
     def auto_slug(self):
-        """
-        This property is used to auto-generate a slug from the name attribute.
+        """This property is used to auto-generate a slug from the name
+        attribute.
+
         It can be customized by subclasses.
         """
         slug = self.name
@@ -384,21 +408,25 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
 
             max_id = max(-1, -1, *results) + 1
             if max_id:
-                slug = u'{}-{}'.format(slug, max_id)
+                slug = '{}-{}'.format(slug, max_id)
         return slug
 
     @property
     def _indexable_roles_and_users(self):
         """Return a string made for indexing roles having :any:`READ`
-        permission on this object.
-        """
+        permission on this object."""
         from abilian.services.indexing import indexable_role
         from abilian.services.security import READ, Admin, Anonymous, Creator, Owner
+        from abilian.services import get_service
+
         result = []
-        svc = current_app.services['security']
+        security = get_service('security')
 
         # roles - required to match when user has a global role
-        assignments = svc.get_permissions_assignments(permission=READ, obj=self)
+        assignments = security.get_permissions_assignments(
+            permission=READ,
+            obj=self,
+        )
         allowed_roles = assignments.get(READ, set())
         allowed_roles.add(Admin)
 
@@ -407,7 +435,8 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
 
         for role, attr in (
             (Creator, 'creator'),
-            (Owner, 'owner'),):
+            (Owner, 'owner'),
+        ):
             if role in allowed_roles:
                 user = getattr(self, attr)
                 if user:
@@ -415,7 +444,7 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
 
         # users and groups
         principals = set()
-        for user, role in svc.get_role_assignements(self):
+        for user, role in security.get_role_assignements(self):
             if role in allowed_roles:
                 principals.add(user)
 
@@ -427,28 +456,48 @@ class Entity(with_metaclass(EntityMeta, Indexable, BaseMixin, db.Model)):
         for p in principals:
             result.append(indexable_role(p))
 
-        return u' '.join(result)
+        return ' '.join(result)
 
     @property
     def _indexable_tags(self):
         """Index tag ids for tags defined in this Entity's default tags
-        namespace.
-        """
+        namespace."""
         tags = current_app.extensions['tags']
 
         if not tags.is_support_tagging(self):
-            return u''
+            return ''
 
         default_ns = tags.entity_default_ns(self)
         return [t for t in tags.entity_tags(self) if t.ns == default_ns]
 
     @property
     def _indexable_tag_ids(self):
-        return u' '.join(text_type(t.id) for t in self._indexable_tags)
+        return ' '.join(text_type(t.id) for t in self._indexable_tags)
 
     @property
     def _indexable_tag_text(self):
-        return u' '.join(text_type(t.label) for t in self._indexable_tags)
+        return ' '.join(text_type(t.label) for t in self._indexable_tags)
+
+    def clone(self):
+        """Copy an entity: copy every field, except the id and sqlalchemy
+        internals, without forgetting about the n-n relationships.
+
+        - return: the newly created entity
+
+        Example::
+
+            def clone(self):
+                old_attrs = self.__dict__.copy()
+                del old_attrs['_sa_instance_state']
+                if 'id' in old_attrs:
+                    del old_attrs['id']
+                new = AnEntity(**old_attrs)
+                # Needs special treatment for n-n relationship
+                new.related_projects = self.related_projects
+                new.ancestor = self
+                return new
+        """
+        raise NotImplementedError
 
 
 # TODO: make this unecessary
@@ -489,11 +538,11 @@ def polymorphic_update_timestamp(session, flush_context, instances):
 
 @memoized
 def all_entity_classes():
-    """Return the list of all concrete persistent classes that are subclasses of
-    Entity.
-    """
+    """Return the list of all concrete persistent classes that are subclasses
+    of Entity."""
     persistent_classes = Entity._decl_class_registry.values()
-    # with sqlalchemy 0.8 _decl_class_registry holds object that are not classes
+    # with sqlalchemy 0.8 _decl_class_registry holds object that are not
+    # classes
     return [
         cls for cls in persistent_classes
         if isclass(cls) and issubclass(cls, Entity)
