@@ -1,7 +1,5 @@
 # coding=utf-8
-"""
-Jinja2 extensions
-"""
+"""Jinja2 extensions."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -12,7 +10,7 @@ from flask import current_app
 from flask.globals import _lookup_req_object, _request_ctx_stack
 from flask.signals import got_request_exception, request_started
 from jinja2 import nodes
-from jinja2.ext import Extension
+from jinja2.ext import Extension as JinjaExtension
 from werkzeug.local import LocalProxy
 
 
@@ -20,8 +18,7 @@ deferred_js = LocalProxy(partial(_lookup_req_object, 'deferred_js'))
 
 
 class DeferredJS(object):
-    """Flask extentions for use with DeferredJSExtension for jinja
-    """
+    """Flask extension for use with DeferredJSExtension for jinja."""
     name = 'deferred_js'
 
     def __init__(self, app=None):
@@ -43,11 +40,11 @@ class DeferredJS(object):
         _request_ctx_stack.top.deferred_js = []
 
 
-class DeferredJSExtension(Extension):
+class DeferredJSExtension(JinjaExtension):
     """Put JS fragment at the end of the document in a script tag.
 
-    The JS fragment can contains <script> tag so that your favorite editor
-    keeps doing proper indentation, syntax highlighting...
+    The JS fragment can contains <script> tag so that your favorite
+    editor keeps doing proper indentation, syntax highlighting...
     """
     tags = {'deferJS', 'deferredJS'}
 
@@ -58,11 +55,17 @@ class DeferredJSExtension(Extension):
 
         # now we parse body of the block
         body = parser.parse_statements(
-            ['name:enddeferJS', 'name:enddeferredJS'], drop_needle=True)
+            ['name:enddeferJS', 'name:enddeferredJS'],
+            drop_needle=True,
+        )
 
         method = 'defer_nodes' if tag == 'deferJS' else 'collect_deferred'
-        return nodes.CallBlock(self.call_method(method, []), [], [],
-                               body).set_lineno(lineno)
+        return nodes.CallBlock(
+            self.call_method(method, []),
+            [],
+            [],
+            body,
+        ).set_lineno(lineno)
 
     def defer_nodes(self, caller):
         body = '<div>{}</div>'.format(caller().strip())
@@ -81,13 +84,15 @@ class DeferredJSExtension(Extension):
         for child in fragment:
             body.append(lxml.html.tostring(child))
             body.append(child.tail)
-        body = u''.join(body)
+        body = ''.join(body)
 
         deferred_js.append(body)
-        return u''
+        return ''
 
     def collect_deferred(self, caller):
-        result = '\n'.join('(function(){{\n{}\n}})();'.format(js)
-                           for js in deferred_js)
+        result = '\n'.join(
+            '(function(){{\n{}\n}})();'.format(js)
+            for js in deferred_js
+        )
         current_app.extensions[DeferredJS.name].reset_deferred()
         return result
