@@ -1,7 +1,7 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, print_function, division
+
 from datetime import datetime
 import json
 
@@ -9,9 +9,21 @@ from six import python_2_unicode_compatible
 from sqlalchemy.orm.util import class_mapper
 from sqlalchemy.ext.declarative import declared_attr
 
-from .base import (Model, IdMixin, TimestampedMixin, EDITABLE, NOT_EDITABLE,
-                   AUDITABLE, AUDITABLE_HIDDEN, NOT_AUDITABLE, SEARCHABLE,
-                   NOT_SEARCHABLE, EXPORTABLE, NOT_EXPORTABLE, SYSTEM)  # noqa
+from .base import (
+    Model,
+    IdMixin,
+    TimestampedMixin,
+    EDITABLE,
+    NOT_EDITABLE,
+    AUDITABLE,
+    AUDITABLE_HIDDEN,
+    NOT_AUDITABLE,
+    SEARCHABLE,
+    NOT_SEARCHABLE,
+    EXPORTABLE,
+    NOT_EXPORTABLE,
+    SYSTEM,
+)
 
 from .owned import OwnedMixin
 
@@ -28,11 +40,16 @@ class BaseMixin(IdMixin, TimestampedMixin, OwnedMixin):
 
     def __repr__(self):
         return '<{} instance at 0x{:x} name={!r} id={}>'.format(
-            self.__class__.__name__, id(self), self.name, str(self.id))
+            self.__class__.__name__,
+            id(self),
+            self.name,
+            str(self.id),
+        )
 
     @property
     def column_names(self):
-        return [col.name for col in class_mapper(self.__class__).mapped_table.c]
+        return [col.name for col in class_mapper(
+            self.__class__).mapped_table.c]
 
     def to_dict(self):
         if hasattr(self, "__exportable__"):
@@ -42,7 +59,7 @@ class BaseMixin(IdMixin, TimestampedMixin, OwnedMixin):
         d = {}
         for k in exported:
             v = getattr(self, k)
-            if type(v) == datetime:
+            if isinstance(v, datetime):
                 v = v.isoformat()
             d[k] = v
         return d
@@ -51,10 +68,10 @@ class BaseMixin(IdMixin, TimestampedMixin, OwnedMixin):
         return json.dumps(self.to_dict())
 
     def _icon(self, size=12):
-        return "/static/icons/%s-%d.png" % (self.__class__.__name__.lower(),
-                                            size)
+        class_name = self.__class__.__name__.lower()
+        return "/static/icons/{}-{}.png".format(class_name, size)
 
-    #FIXME: we can do better than that
+    # FIXME: we can do better than that
     @property
     def _name(self):
         if hasattr(self, 'title'):
