@@ -1,14 +1,15 @@
 # coding=utf-8
-"""
-Blob. References to files stored in a on-disk repository
+"""Blob.
+
+References to files stored in a on-disk repository
 """
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import hashlib
 import uuid
+from typing import Optional
 
-import six
 import sqlalchemy as sa
 from flask_sqlalchemy import BaseQuery
 from six import text_type
@@ -22,15 +23,14 @@ from abilian.core.sqlalchemy import UUID, JSONDict
 
 
 class BlobQuery(BaseQuery):
-    """Query class for :class:`Blob` objects
-    """
+    """Query class for :class:`Blob` objects."""
 
     def by_uuid(self, uuid):
+        # type: (str) -> Optional[Blob]
         """Like `.get()` but by uuid.
 
         :param uuid: a `string` or an `uuid`.
         """
-        # type: (str) -> Blob
         try:
             return self.filter_by(uuid=uuid).one()
         except NoResultFound:
@@ -40,9 +40,10 @@ class BlobQuery(BaseQuery):
 class Blob(Model):
     """Model for storing large file content.
 
-    Files are stored on-disk, named after their uuid. Repository is located in
-    instance folder/data/files.
+    Files are stored on-disk, named after their uuid. Repository is
+    located in instance folder/data/files.
     """
+
     __tablename__ = "blob"
     query_class = BlobQuery
 
@@ -63,22 +64,19 @@ class Blob(Model):
 
     @property
     def file(self):
-        """Return :class:`pathlib.Path` object used for storing value.
-        """
+        """Return :class:`pathlib.Path` object used for storing value."""
         from abilian.services.repository import session_repository as repository
         return repository.get(self, self.uuid)
 
     @property
     def size(self):
-        """Return size in bytes of value.
-        """
+        """Return size in bytes of value."""
         f = self.file
         return f.stat().st_size if f is not None else 0
 
     @property
     def value(self):
-        """Binary value content.
-        """
+        """Binary value content."""
         v = self.file
         return v.open('rb').read() if v is not None else v
 
@@ -88,7 +86,7 @@ class Blob(Model):
         `self.meta['md5']`.
 
         :param:content: string, bytes, or any object with a `read()` method
-        :param:encoding: encoding to use when content is unicode
+        :param:encoding: encoding to use when content is Unicode
         """
         from abilian.services.repository import session_repository as repository
         repository.set(self, self.uuid, value)
@@ -105,28 +103,25 @@ class Blob(Model):
 
     @value.deleter
     def value(self):
-        """Remove value from repository.
-        """
+        """Remove value from repository."""
         from abilian.services.repository import session_repository as repository
         repository.delete(self, self.uuid)
 
     @property
     def md5(self):
-        """Return md5 from meta, or compute it if absent.
-        """
+        """Return md5 from meta, or compute it if absent."""
         md5 = self.meta.get('md5')
         if md5 is None:
             md5 = text_type(hashlib.md5(self.value).hexdigest())
 
         return md5
 
-    def __nonzero__(self):
-        """A blob is considered null if it has no file.
-        """
+    def __bool__(self):
+        """A blob is considered falsy if it has no file."""
         return self.file is not None and self.file.exists()
 
     # Py3k compat
-    __bool__ = __nonzero__
+    __nonzero__ = __bool__
 
 
 @listens_for(sa.orm.Session, 'after_flush')
