@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -21,7 +20,8 @@ class OwnedMixin(object):
             ('creator', ('creator',)),
             ('creator_name', (('creator_name', STORED),)),
             ('owner', ('owner',)),
-            ('owner_name', (('owner_name', STORED),)),)
+            ('owner_name', (('owner_name', STORED),)),
+        ),
     }
 
     def __init__(self, *args, **kwargs):
@@ -40,17 +40,18 @@ class OwnedMixin(object):
 
     @declared_attr
     def creator(cls):
-        pj = "User.id == %s.creator_id" % cls.__name__
+        primary_join = "User.id == {}.creator_id".format(cls.__name__)
         return relationship(
             User,
-            primaryjoin=pj,
+            primaryjoin=primary_join,
             lazy='joined',
             uselist=False,
-            info=SYSTEM | SEARCHABLE)
+            info=SYSTEM | SEARCHABLE,
+        )
 
     @property
     def creator_name(self):
-        return text_type(self.creator) if self.creator else u''
+        return text_type(self.creator) if self.creator else ''
 
     @declared_attr
     def owner_id(cls):
@@ -58,14 +59,15 @@ class OwnedMixin(object):
 
     @declared_attr
     def owner(cls):
-        pj = "User.id == %s.owner_id" % cls.__name__
+        primary_join = "User.id == {}.owner_id".format(cls.__name__)
         return relationship(
             User,
-            primaryjoin=pj,
+            primaryjoin=primary_join,
             lazy='joined',
             uselist=False,
-            info=EDITABLE | AUDITABLE | SEARCHABLE)
+            info=EDITABLE | AUDITABLE | SEARCHABLE,
+        )
 
     @property
     def owner_name(self):
-        return text_type(self.owner) if self.owner else u''
+        return text_type(self.owner) if self.owner else ''
