@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-Subject classes (i.e. people, groups, etc.).
+"""Subject classes (i.e. people, groups, etc.).
 
 See ICOM-ics-v1.0 "Subject Branch".
 
@@ -17,8 +16,8 @@ from datetime import datetime, timedelta
 
 import bcrypt
 import sqlalchemy as sa
-from flask_login import UserMixin, current_app
-from six import python_2_unicode_compatible, text_type
+from flask_login import UserMixin
+from six import add_metaclass, python_2_unicode_compatible, text_type
 from sqlalchemy.event import listens_for
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, deferred, relationship
@@ -27,6 +26,7 @@ from sqlalchemy.types import Boolean, DateTime, Integer, LargeBinary, \
     UnicodeText
 
 from abilian.core import sqlalchemy as sa_types
+from abilian.core.util import fqcn
 
 from .base import SEARCHABLE, SYSTEM, IdMixin, Indexable, TimestampedMixin, db
 
@@ -38,21 +38,24 @@ following = Table(
     db.Model.metadata,
     Column('follower_id', Integer, ForeignKey('user.id')),
     Column('followee_id', Integer, ForeignKey('user.id')),
-    UniqueConstraint('follower_id', 'followee_id'),)
+    UniqueConstraint('follower_id', 'followee_id'),
+)
+
 membership = Table(
     'membership',
     db.Model.metadata,
     Column(
         'user_id',
         Integer,
-        ForeignKey(
-            'user.id', onupdate='CASCADE', ondelete='CASCADE')),
+        ForeignKey('user.id', onupdate='CASCADE', ondelete='CASCADE'),
+    ),
     Column(
         'group_id',
         Integer,
-        ForeignKey(
-            'group.id', onupdate='CASCADE', ondelete='CASCADE')),
-    UniqueConstraint('user_id', 'group_id'),)
+        ForeignKey('group.id', onupdate='CASCADE', ondelete='CASCADE'),
+    ),
+    UniqueConstraint('user_id', 'group_id'),
+)
 
 # Should not be needed (?)
 administratorship = Table(
@@ -61,49 +64,47 @@ administratorship = Table(
     Column(
         'user_id',
         Integer,
-        ForeignKey(
-            'user.id', onupdate='CASCADE', ondelete='CASCADE')),
+        ForeignKey('user.id', onupdate='CASCADE', ondelete='CASCADE'),
+    ),
     Column(
         'group_id',
         Integer,
-        ForeignKey(
-            'group.id', onupdate='CASCADE', ondelete='CASCADE')),
-    UniqueConstraint('user_id', 'group_id'),)
+        ForeignKey('group.id', onupdate='CASCADE', ondelete='CASCADE'),
+    ),
+    UniqueConstraint('user_id', 'group_id'),
+)
 
 _RANDOM_PASSWORD_CHARS = (
-    string.ascii_letters + string.digits + string.punctuation)
+    string.ascii_letters + string.digits + string.punctuation
+)
 
 
 def gen_random_password(length=15):
     rg = random.SystemRandom()
-    return u''.join(rg.choice(_RANDOM_PASSWORD_CHARS) for i in range(length))
+    return ''.join(rg.choice(_RANDOM_PASSWORD_CHARS) for i in range(length))
 
 
+@add_metaclass(ABCMeta)
 class PasswordStrategy(object):
 
-    __metaclass__ = ABCMeta
-
     @abstractproperty
     def name(self):
-        """Strategy name.
-        """
+        """Strategy name."""
 
     @abstractmethod
     def authenticate(self, user, password):
-        """Predicate to tell wether password match user's or not.
-        """
+        """Predicate to tell wether password match user's or not."""
 
     @abstractmethod
     def process(self, user, password):
-        """Return a string to be stored as user password
-        """
+        """Return a string to be stored as user password."""
 
 
 class ClearPasswordStrategy(PasswordStrategy):
     """Don't encrypt at all.
 
-    This strategy should not ever be used elsewhere than in tests. It's useful
-    in tests since a hash like bcrypt is designed to be slow.
+    This strategy should not ever be used elsewhere than in tests. It's
+    useful in tests since a hash like bcrypt is designed to be slow.
     """
 
     @property
@@ -120,8 +121,7 @@ class ClearPasswordStrategy(PasswordStrategy):
 
 
 class BcryptPasswordStrategy(PasswordStrategy):
-    """Hash passwords using bcrypt.
-    """
+    """Hash passwords using bcrypt."""
 
     @property
     def name(self):
@@ -129,7 +129,7 @@ class BcryptPasswordStrategy(PasswordStrategy):
 
     def authenticate(self, user, password):
         current_passwd = user.password
-        # crypt work only on str, not unicode
+        # crypt work only on bytes, not str (Unicode)
         if isinstance(current_passwd, text_type):
             current_passwd = current_passwd.encode('utf-8')
         if isinstance(password, text_type):
@@ -155,15 +155,34 @@ class Principal(IdMixin, TimestampedMixin, Indexable):
     __indexation_args__ = {}
     __indexation_args__.update(Indexable.__indexation_args__)
     index_to = __indexation_args__.setdefault('index_to', ())
-    __indexation_args__['index_to'] += (('name',
-                                         ('name', 'name_prefix', 'text')),)
+    __indexation_args__['index_to'] += (
+        (
+            'name',
+            ('name', 'name_prefix', 'text'),
+        ),
+    )
     del index_to
 
-    def has_role(self, role):
-        return current_app.services['security'].has_role(self, role)
+    def has_role(self, role, context=None):
+        from abilian.services import get_service
+
+        security = get_service('security')
+        return security.has_role(self, role, context)
+
+
+def set_entity_type(cls):
+    """Decorator used to set the class' entity_type after the class has been
+    declared.
+
+    Actually, it works using __module__ during class declaration, but
+    linters (Flake8, PyCharm) complain.
+    """
+    cls.entity_type = fqcn(cls)
+    return cls
 
 
 @python_2_unicode_compatible
+@set_entity_type
 class User(Principal, UserMixin, db.Model):
     __tablename__ = 'user'
     __editable__ = ['first_name', 'last_name', 'email', 'password']
@@ -171,8 +190,6 @@ class User(Principal, UserMixin, db.Model):
 
     __password_strategy__ = BcryptPasswordStrategy()
 
-    entity_type = u'{}.{}'.format(__module__, 'User')
-
     query_class = UserQuery
 
     # Basic information
@@ -184,7 +201,10 @@ class User(Principal, UserMixin, db.Model):
     email = Column(UnicodeText, nullable=False)
     can_login = Column(Boolean, nullable=False, default=True)
     password = Column(
-        UnicodeText, default="*", info={'audit_hide_content': True})
+        UnicodeText,
+        default="*",
+        info={'audit_hide_content': True},
+    )
 
     photo = deferred(Column(LargeBinary))
 
@@ -197,9 +217,10 @@ class User(Principal, UserMixin, db.Model):
     followers = relationship(
         "User",
         secondary=following,
-        primaryjoin=('User.id == following.c.follower_id'),
-        secondaryjoin=('User.id == following.c.followee_id'),
-        backref='followees')
+        primaryjoin='User.id == following.c.follower_id',
+        secondaryjoin='User.id == following.c.followee_id',
+        backref='followees',
+    )
 
     def __init__(self, password=None, **kwargs):
         Principal.__init__(self)
@@ -260,16 +281,18 @@ class User(Principal, UserMixin, db.Model):
     #
     @property
     def name(self):
-        name = u'{first_name} {last_name}'.format(
-            first_name=self.first_name or u'', last_name=self.last_name or u'')
-        return name.strip() or u'Unknown'
+        name = '{first_name} {last_name}'.format(
+            first_name=self.first_name or '',
+            last_name=self.last_name or '',
+        )
+        return name.strip() or 'Unknown'
 
     @property
     def short_name(self):
-        first_name = self.first_name or u''
-        last_name = self.last_name[0:1] + "." if self.last_name else u''
-        name = u'{} {}'.format(first_name, last_name)
-        return name.strip() or u'Unknown'
+        first_name = self.first_name or ''
+        last_name = self.last_name[0:1] + "." if self.last_name else ''
+        name = '{} {}'.format(first_name, last_name)
+        return name.strip() or 'Unknown'
 
     def __str__(self):
         return self.name
@@ -281,7 +304,8 @@ class User(Principal, UserMixin, db.Model):
             cls=cls.__name__,
             id=self.id,
             email=self.email,
-            addr=id(self))
+            addr=id(self),
+        )
 
 
 @listens_for(User, "mapper_configured", propagate=True)
@@ -293,18 +317,18 @@ def _add_user_indexes(mapper, class_):
     idx = sa.schema.Index(
         'user_unique_lowercase_email',
         sa.sql.func.lower(class_.email),
-        unique=True)
+        unique=True,
+    )
     idx.info['engines'] = ('postgresql',)
 
 
+@set_entity_type
 class Group(Principal, db.Model):
     __indexable__ = False
     __tablename__ = 'group'
     __editable__ = ['name', 'description']
     __exportable__ = __editable__ + ['created_at', 'updated_at', 'id']
 
-    entity_type = u'{}.{}'.format(__module__, 'Group')
-
     name = Column(UnicodeText, nullable=False, info=SEARCHABLE)
     description = Column(UnicodeText, info=SEARCHABLE)
 
@@ -312,10 +336,13 @@ class Group(Principal, db.Model):
         "User",
         collection_class=set,
         secondary=membership,
-        backref=backref(
-            'groups', lazy='select', collection_class=set))
+        backref=backref('groups', lazy='select', collection_class=set),
+    )
     admins = relationship(
-        "User", collection_class=set, secondary=administratorship)
+        "User",
+        collection_class=set,
+        secondary=administratorship,
+    )
 
     photo = deferred(Column(LargeBinary))
 
