@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -25,7 +24,7 @@ def test_singleton():
 def test_equality():
     val = NS1('val')
     assert val == 'val'
-    assert val == u'val'
+    assert val == 'val'
 
 
 def test_namespaces():
