@@ -1,11 +1,10 @@
 # coding=utf-8
-"""
-Various tools that don't belong some place specific.
-"""
+"""Various tools that don't belong some place specific."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import functools
+import hashlib
 import logging
 import re
 import sys
@@ -30,20 +29,21 @@ except ImportError:
 def pdb_on_error(fn):
     """Decorator to trigger (i)pdb on exception inside decorated function.
 
-    Active only in DEBUG mode.
-    Useful to debug POST only views for example.
+    Active only in DEBUG mode. Useful to debug POST only views for
+    example.
     """
 
     @functools.wraps(fn)
     def decorator(*args, **kwargs):
         try:
             return fn(*args, **kwargs)
-        except:
+        except BaseException:
             if current_app and current_app.debug:
                 type_, value, tb = sys.exc_info()
                 if tb.tb_next is not None:
                     # error has happened inside decorated function, remove us from top
-                    # stack: better readability in logs, accurate label in sentry
+                    # stack: better readability in logs, accurate label in
+                    # sentry
                     tb = tb.tb_next
 
                 pdb.post_mortem(tb)
@@ -63,8 +63,7 @@ def noproxy(obj):
 
 
 def fqcn(cls):
-    """Fully Qualified Class Name.
-    """
+    """Fully Qualified Class Name."""
     return text_type(cls.__module__ + '.' + cls.__name__)
 
 
@@ -80,8 +79,7 @@ def friendly_fqcn(cls_name):
 
 
 def utcnow():
-    """Return a new aware datetime with current date and time, in UTC TZ.
-    """
+    """Return a new aware datetime with current date and time, in UTC TZ."""
     return datetime.now(pytz.utc)
 
 
@@ -109,8 +107,8 @@ def utc_dt(dt):
 def get_params(names):
     """Return a dictionary with params from request.
 
-    TODO: I think we don't use it anymore and it should be removed before
-    someone gets hurt.
+    TODO: I think we don't use it anymore and it should be removed
+    before someone gets hurt.
     """
     params = {}
     for name in names:
@@ -121,9 +119,7 @@ def get_params(names):
 
 
 class timer(object):
-    """Decorator that mesures the time it takes to run a function.
-    """
-    __instances = {}
+    """Decorator that mesures the time it takes to run a function."""
 
     def __init__(self, f):
         self.__f = f
@@ -133,7 +129,7 @@ class timer(object):
         self.__start = time.time()
         result = self.__f(*args, **kwargs)
         value = time.time() - self.__start
-        self.log.info('elapsed time: {0:.2f}ms'.format(value * 1000))
+        self.log.info('elapsed time: {:.2f}ms'.format(value * 1000))
         return result
 
 
@@ -141,8 +137,8 @@ class timer(object):
 class memoized(object):
     """Decorator that caches a function's return value each time it is called.
 
-    If called later with the same arguments, the cached value is returned
-    (not reevaluated).
+    If called later with the same arguments, the cached value is
+    returned (not reevaluated).
     """
 
     def __init__(self, func):
@@ -195,16 +191,20 @@ class Pagination(object):
     def next(self):
         return self.page + 1 if self.has_next else None
 
-    def iter_pages(self,
-                   left_edge=2,
-                   left_current=2,
-                   right_current=5,
-                   right_edge=2):
+    def iter_pages(
+            self,
+            left_edge=2,
+            left_current=2,
+            right_current=5,
+            right_edge=2,
+    ):
         last = 0
         for num in range(1, self.pages + 1):
-            if (num <= left_edge or
+            if (
+                num <= left_edge or
                 (self.page - left_current - 1 < num < self.page + right_current)
-                    or num > self.pages - right_edge):
+                    or num > self.pages - right_edge
+            ):
                 if last + 1 != num:
                     yield None
                 yield num
@@ -215,23 +215,23 @@ _NOT_WORD_RE = re.compile(r'[^\w\s]+', flags=re.UNICODE)
 
 
 def slugify(value, separator="-"):
-    """Slugify an unicode string, to make it URL friendly.
-    """
+    """Slugify an Unicode string, to make it URL friendly."""
     if six.PY2:
         value = text_type(value)
     if not isinstance(value, text_type):
-        raise ValueError("value must be a unicode string")
-    value = _NOT_WORD_RE.sub(u' ', value)
+        raise ValueError("value must be a Unicode string")
+    value = _NOT_WORD_RE.sub(' ', value)
     value = unicodedata.normalize('NFKD', value)
     value = value.encode('ascii', 'ignore')
     value = value.decode('ascii')
     value = value.strip().lower()
-    value = re.sub(r'[%s_\s]+' % separator, separator, value)
+    value = re.sub(r'[{}_\s]+'.format(separator), separator, value)
     return value
 
 
 class BasePresenter(object):
-    """A presenter wraps a model an adds specific (often, web-centric) accessors.
+    """A presenter wraps a model an adds specific (often, web-centric)
+    accessors.
 
     Subclass to make it useful. Presenters are immutable.
     """
@@ -243,8 +243,7 @@ class BasePresenter(object):
         return getattr(self._model, key)
 
     def __setattr__(self, key, value):
-        """Make presenter immutable.
-        """
+        """Make presenter immutable."""
         if key == '_model':
             self.__dict__[key] = value
         else:
@@ -253,3 +252,24 @@ class BasePresenter(object):
     @classmethod
     def wrap_collection(cls, models):
         return [cls(model) for model in models]
+
+
+def encode_string(string):
+    """Encode a string to bytes, if it isn't already.
+
+    :param string: The string to encode
+    """
+    # from pysecurity
+
+    if isinstance(string, text_type):
+        return string.encode('utf-8')
+    else:
+        return string
+
+
+def md5(data):
+    """md5 function, as in flask-security."""
+    # flask-security is not needed anywhere else and as of 1.7.5 has
+    # strong dependency requirements that prevent us from upgrading a
+    # few packages (flask-login 0.4).
+    return hashlib.md5(encode_string(data)).hexdigest()
