@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-I18n.
+"""I18n.
 
 To mark strings for translation::
 
@@ -43,8 +42,6 @@ And just type:
 .. code-block:: bash
 
     $ python setup.py extract_messages
-
-
 """
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
@@ -71,8 +68,17 @@ from flask_babel import LazyString, force_locale, gettext, lazy_gettext, \
 from six import string_types, text_type
 
 __all__ = [
-    'babel', 'gettext', '_', 'lazy_gettext', '_l', 'localeselector', 'ngettext',
-    '_n', 'timezoneselector', 'VALID_LANGUAGES_CODE', 'render_template_i18n'
+    'babel',
+    'gettext',
+    '_',
+    'lazy_gettext',
+    '_l',
+    'localeselector',
+    'ngettext',
+    '_n',
+    'timezoneselector',
+    'VALID_LANGUAGES_CODE',
+    'render_template_i18n',
 ]
 
 #: gettext alias
@@ -84,8 +90,10 @@ _l = lazy_gettext
 _n = ngettext
 
 #: accepted languages codes
-VALID_LANGUAGES_CODE = frozenset(lang for lang in locale_identifiers()
-                                 if len(lang) == 2)
+VALID_LANGUAGES_CODE = frozenset(
+    lang for lang in locale_identifiers()
+    if len(lang) == 2
+)
 
 
 def get_default_locale():
@@ -120,23 +128,24 @@ def default_country():
 
 
 def country_choices(first=None, default_country_first=True):
-    """
-    Return a list of (code, countries), alphabetically sorted on localized
+    """Return a list of (code, countries), alphabetically sorted on localized
     country name.
 
     :param first: Country code to be placed at the top
     """
     locale = _get_locale()
-    territories = [(code, name)
-                   for code, name in six.iteritems(locale.territories)
-                   if len(code) == 2]  # skip 3-digit regions
+    territories = [
+        (code, name)
+        for code, name in six.iteritems(locale.territories)
+        if len(code) == 2
+    ]  # skip 3-digit regions
 
     if first is None and default_country_first:
         first = default_country()
 
     def sortkey(item):
         if first is not None and item[0] == first:
-            return u'0'
+            return '0'
         return to_lower_ascii(item[1])
 
     territories.sort(key=sortkey)
@@ -151,8 +160,10 @@ def supported_app_locales():
     """
     locale = _get_locale()
     codes = current_app.config['BABEL_ACCEPT_LANGUAGES']
-    return ((Locale.parse(code), locale.languages.get(code, code))
-            for code in codes)
+    return (
+        (Locale.parse(code), locale.languages.get(code, code))
+        for code in codes
+    )
 
 
 def timezones_choices():
@@ -166,14 +177,12 @@ def timezones_choices():
     for tz in sorted(pytz.common_timezones):
         tz = get_timezone(tz)
         now = tz.normalize(utcnow.astimezone(tz))
-        label = u'({}) {}'.format(get_timezone_gmt(now, locale=locale), tz.zone)
+        label = '({}) {}'.format(get_timezone_gmt(now, locale=locale), tz.zone)
         yield (tz, label)  # get_timezone_name(tz, locale=locale))
 
 
 class Babel(BabelBase):
-    """
-    Allow to load translations from other modules
-    """
+    """Allow to load translations from other modules."""
     _translations_paths = None
 
     def __init__(self, *args, **kwargs):
@@ -182,15 +191,16 @@ class Babel(BabelBase):
     def init_app(self, app):
         super(Babel, self).init_app(app)
         self._translations_paths = [
-            (os.path.join(app.root_path, 'translations'), 'messages')
+            (os.path.join(app.root_path, 'translations'), 'messages'),
         ]
 
-    def add_translations(self,
-                         module_name,
-                         translations_dir='translations',
-                         domain='messages'):
-        """
-        Add translations from external module.
+    def add_translations(
+            self,
+            module_name,
+            translations_dir='translations',
+            domain='messages',
+    ):
+        """Add translations from external module.
 
         For example::
 
@@ -206,7 +216,8 @@ class Babel(BabelBase):
             if not os.access(text_type(path), os.R_OK):
                 self.app.logger.warning(
                     "Babel translations: read access not allowed {}, skipping."
-                    "".format(repr(text_type((path)).encode('utf-8'))))
+                    "".format(repr(text_type(path).encode('utf-8'))),
+                )
                 continue
 
             self._translations_paths.append((text_type(path), domain))
@@ -215,8 +226,8 @@ class Babel(BabelBase):
 class Translations(BaseTranslations):
     """Merge only non-empty translations.
 
-    This avoids having uncomplete catalog that "clear" existing translations, when
-    used with :func:`_get_translations_multi_paths`.
+    This avoids having uncomplete catalog that "clear" existing
+    translations, when used with :func:`_get_translations_multi_paths`.
     """
 
     def merge(self, translations):
@@ -235,7 +246,7 @@ class Translations(BaseTranslations):
                     # string: skip it.
 
                     # logger.debug('Catalog: %r, skip msgkey: %r, existing: %r',
-                    #                translations, msgkey, self._catalog[msgkey])
+                    # translations, msgkey, self._catalog[msgkey])
                     continue
 
                 self._catalog[msgkey] = msgstr
@@ -250,8 +261,8 @@ def _get_translations_multi_paths():
     """Return the correct gettext translations that should be used for this
     request.
 
-    This will never fail and return a dummy translation object
-    if used outside of the request or if a translation cannot be found.
+    This will never fail and return a dummy translation object if used
+    outside of the request or if a translation cannot be found.
     """
     ctx = _request_ctx_stack.top
     if ctx is None:
@@ -267,7 +278,10 @@ def _get_translations_multi_paths():
         # translations from libraries can be overriden
         for (dirname, domain) in reversed(babel_ext._translations_paths):
             trs = Translations.load(
-                dirname, locales=[flask_babel.get_locale()], domain=domain)
+                dirname,
+                locales=[flask_babel.get_locale()],
+                domain=domain,
+            )
 
             # babel.support.Translations is a subclass of
             # babel.support.NullTranslations, so we test if object has a 'merge'
@@ -276,7 +290,7 @@ def _get_translations_multi_paths():
             if not trs or not hasattr(trs, 'merge'):
                 # got None or NullTranslations instance
                 continue
-            elif (translations is not None and hasattr(translations, 'merge')):
+            elif translations is not None and hasattr(translations, 'merge'):
                 translations.merge(trs)
             else:
                 translations = trs
@@ -298,8 +312,7 @@ babel = Babel()
 
 
 def localeselector():
-    """Default locale selector used in abilian applications.
-    """
+    """Default locale selector used in abilian applications."""
     # if a user is logged in, use the locale from the user settings
     user = getattr(g, 'user', None)
     if user is not None:
@@ -309,19 +322,18 @@ def localeselector():
 
     # Otherwise, try to guess the language from the user accept header the browser
     # transmits.  By default we support en/fr. The best match wins.
-    return request.accept_languages.best_match(current_app.config[
-        'BABEL_ACCEPT_LANGUAGES'])
+    return request.accept_languages.best_match(
+        current_app.config['BABEL_ACCEPT_LANGUAGES'],
+    )
 
 
 def timezoneselector():
-    """Default timezone selector used in abilian applications.
-    """
+    """Default timezone selector used in abilian applications."""
     return LOCALTZ
 
 
 def get_template_i18n(template_name, locale):
-    """Build template list with preceding locale if found.
-    """
+    """Build template list with preceding locale if found."""
     if locale is None:
         return [template_name]
 
@@ -332,10 +344,10 @@ def get_template_i18n(template_name, locale):
 
     if locale.territory is not None:
         locale_string = '_'.join([locale.language, locale.territory])
-        localized_template_path = u'.'.join([root, locale_string, suffix])
+        localized_template_path = '.'.join([root, locale_string, suffix])
         template_list.append(localized_template_path)
 
-    localized_template_path = u'.'.join([root, locale.language, suffix])
+    localized_template_path = '.'.join([root, locale.language, suffix])
     template_list.append(localized_template_path)
 
     # append the default
@@ -344,8 +356,7 @@ def get_template_i18n(template_name, locale):
 
 
 class ensure_request_context(object):
-    """Context manager that ensures a request context is set up.
-    """
+    """Context manager that ensures a request context is set up."""
     _rq_ctx = None
 
     def __enter__(self):
@@ -362,8 +373,8 @@ class ensure_request_context(object):
 
 
 def render_template_i18n(template_name_or_list, **context):
-    """Try to build an ordered list of template to satisfy the current locale.
-    """
+    """Try to build an ordered list of template to satisfy the current
+    locale."""
     template_list = []
     # Use locale if present in **context
     if 'locale' in context:
@@ -388,10 +399,10 @@ _NOT_WORD_RE = re.compile(r'[^\w\s]+', flags=re.UNICODE)
 
 def to_lower_ascii(value):
     value = text_type(value)
-    value = _NOT_WORD_RE.sub(u' ', value)
+    value = _NOT_WORD_RE.sub(' ', value)
     value = unicodedata.normalize('NFKD', value)
     value = value.encode('ascii', 'ignore')
     value = value.decode('ascii')
     value = value.strip().lower()
-    value = re.sub(r'[_\s]+', u' ', value)
+    value = re.sub(r'[_\s]+', ' ', value)
     return value
