@@ -1,16 +1,16 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
 import io
 import logging
 import os
-
 import pathlib
+
 import six
 
 from abilian.core.models.blob import Blob
+
 from ..base import Service
 
 logger = logging.getLogger(__name__)
@@ -22,7 +22,7 @@ try:
 except ImportError:
     CLAMD_AVAILABLE = False
 
-CLAMD_CONF = {'StreamMaxLength': u'25M', 'MaxFileSize': u'25M'}
+CLAMD_CONF = {'StreamMaxLength': '25M', 'MaxFileSize': '25M'}
 CLAMD_STREAMMAXLENGTH = 26214400
 CLAMD_MAXFILESIZE = 26214400
 
@@ -31,7 +31,8 @@ if CLAMD_AVAILABLE:
     if conf_path.exists():
         conf_lines = [l.strip() for l in conf_path.open('rt').readlines()]
         CLAMD_CONF = dict(
-            l.split(u' ', 1) for l in conf_lines if not l.startswith('#'))
+            l.split(u' ', 1) for l in conf_lines if not l.startswith('#')
+        )
 
         def _size_to_int(size_str):
             multiplier = 0
@@ -60,8 +61,7 @@ if CLAMD_AVAILABLE:
 
 
 class AntiVirusService(Service):
-    """Antivirus service.
-    """
+    """Antivirus service."""
     name = 'antivirus'
 
     def scan(self, file_or_stream):
@@ -105,7 +105,8 @@ class AntiVirusService(Service):
                     size,
                     CLAMD_STREAMMAXLENGTH,
                     CLAMD_CONF['StreamMaxLength'].encode('utf-8'),
-                    extra={'stack': True},)
+                    extra={'stack': True},
+                )
                 return None
 
         # use stream scan. When using scan by filename, clamd runnnig user must have
