@@ -1,5 +1,5 @@
-"""
-Audit Service: logs modifications to audited objects.
+# coding=utf-8
+"""Audit Service: logs modifications to audited objects.
 
 Only subclasses of Entity are auditable, at this point.
 
@@ -15,10 +15,11 @@ import pickle
 from datetime import datetime
 
 from flask import current_app
-from six import text_type
+from six import binary_type, text_type
+from sqlalchemy import LargeBinary
 from sqlalchemy.orm import relationship
 from sqlalchemy.schema import Column, ForeignKey
-from sqlalchemy.types import Binary, DateTime, Integer, String, UnicodeText
+from sqlalchemy.types import DateTime, Integer, String, UnicodeText
 
 from abilian.core.entities import Entity
 from abilian.core.extensions import db
@@ -31,9 +32,7 @@ RELATED = 1 << 7
 
 
 class Changes(object):
-    """
-    Trace object modifications
-    """
+    """Trace object modifications."""
 
     def __init__(self):
         self.columns = {}
@@ -85,9 +84,7 @@ class Changes(object):
 
 
 class AuditEntry(db.Model):
-    """
-    Logs modifications to auditable classes.
-    """
+    """Logs modifications to auditable classes."""
     id = Column(Integer, primary_key=True)
     happened_at = Column(DateTime, default=datetime.utcnow, index=True)
     type = Column(Integer)  # CREATION / UPDATE / DELETION
@@ -105,16 +102,21 @@ class AuditEntry(db.Model):
     user_id = Column(Integer, ForeignKey(User.id))
     user = relationship(User, foreign_keys=user_id)
 
-    changes_pickle = Column(Binary)
+    changes_pickle = Column(LargeBinary)
 
     def __repr__(self):
         return '<AuditEntry id={} op={} user={} {}entity=<{} id={}>>'.format(
             repr(self.id),
-            {CREATION: "CREATION",
-             DELETION: "DELETION",
-             UPDATE: "UPDATE"}[self.op],
-            repr(text_type(self.user)), 'related '
-            if self.related else '', self.entity_type, self.entity_id)
+            {
+                CREATION: "CREATION",
+                DELETION: "DELETION",
+                UPDATE: "UPDATE",
+            }[self.op],
+            repr(text_type(self.user)),
+            'related ' if self.related else '',
+            self.entity_type,
+            self.entity_id,
+        )
 
     @property
     def op(self):
@@ -124,10 +126,10 @@ class AuditEntry(db.Model):
     def related(self):
         return self.type & RELATED
 
-    #noinspection PyTypeChecker
     def get_changes(self):
         # Using Pickle here instead of JSON because we need to pickle values
-        # such as dates. This could make schema migration more difficult, though.
+        # such as dates. This could make schema migration more difficult,
+        # though.
         if self.changes_pickle:
             changes = pickle.loads(self.changes_pickle)
             if isinstance(changes, dict):
@@ -156,16 +158,17 @@ class AuditEntry(db.Model):
                 uv = self._format_changes(v)
             else:
                 for val in v:
-                    if isinstance(val, str):
+                    if isinstance(val, binary_type):
                         # TODO: Temp fix for errors that happen during
                         # migration
                         try:
                             val = val.decode('utf-8')
-                        except:
+                        except BaseException:
                             current_app.logger.error(
                                 "A Unicode error happened on changes %s",
-                                repr(changes))
-                            val = u"[[Somme error occurred. Working on it]]"
+                                repr(changes),
+                            )
+                            val = "[[Somme error occurred. Working on it]]"
                     uv.append(val)
                 uv = tuple(uv)
             uchanges.columns[k] = uv
