@@ -1,5 +1,5 @@
-"""
-audit Service: logs modifications to audited objects.
+# coding=utf-8
+"""audit Service: logs modifications to audited objects.
 
 TODO: In the future, we may decide to:
 
@@ -15,7 +15,7 @@ from inspect import isclass
 import sqlalchemy as sa
 from flask import current_app, g
 from six import text_type
-from sqlalchemy import event
+from sqlalchemy import event, extract
 from sqlalchemy.orm.attributes import NEVER_SET
 from sqlalchemy.orm.session import Session
 
@@ -116,7 +116,11 @@ class AuditService(Service):
             if info.get('auditable', True):
                 entity_class.__auditable__.audited_attrs.add(attr)
                 event.listen(
-                    attr, "set", self.set_attribute, active_history=True)
+                    attr,
+                    "set",
+                    self.set_attribute,
+                    active_history=True,
+                )
 
         for relation in mapper.relationships:
             if relation.direction is not sa.orm.interfaces.MANYTOMANY:
@@ -124,9 +128,17 @@ class AuditService(Service):
             attr = getattr(entity_class, relation.key)
             entity_class.__auditable__.collection_attrs.add(attr)
             event.listen(
-                attr, "append", self.collection_append, active_history=True)
+                attr,
+                "append",
+                self.collection_append,
+                active_history=True,
+            )
             event.listen(
-                attr, "remove", self.collection_remove, active_history=True)
+                attr,
+                "remove",
+                self.collection_remove,
+                active_history=True,
+            )
 
     def setup_auditable_entity(self, entity_class):
         meta = AuditableMeta(entity_class.__name__, 'id')
@@ -144,7 +156,8 @@ class AuditService(Service):
             if not relation:
                 raise ValueError(
                     'Invalid relation: "{}", invalid attribute is "{}"'
-                    ''.format(related_attr, attr))
+                    ''.format(related_attr, attr),
+                )
 
             mapper = relation.mapper
             if inferred_backref is not None:
@@ -166,7 +179,10 @@ class AuditService(Service):
                     'Audit setup class<{cls}: Could not guess backref name'
                     ' of relationship "{related_attr}", please use tuple annotation '
                     'on __auditable_entity__'.format(
-                        cls=entity_class.__name__, related_attr=related_attr))
+                        cls=entity_class.__name__,
+                        related_attr=related_attr,
+                    ),
+                )
 
         meta.related = related_path
         meta.backref_attr = backref_attr
@@ -194,8 +210,8 @@ class AuditService(Service):
         # Hide content if needed (like password columns)
         # FIXME: we can only handle the simplest case: 1 attribute => 1 column
         columns = initiator.parent_token.columns
-        if (len(columns) == 1 and columns[0].info.get('audit_hide_content')):
-            old_value = new_value = u'******'
+        if len(columns) == 1 and columns[0].info.get('audit_hide_content'):
+            old_value = new_value = '******'
 
         old_value = format_large_value(old_value)
         new_value = format_large_value(new_value)
@@ -219,20 +235,25 @@ class AuditService(Service):
             # the application, and db session should be left clean. Only the developper
             # (and raven/sentry/whatever) should know
             entries = []
-            for identity_set, op in ((session.new, CREATION),
-                                     (session.deleted, DELETION),
-                                     (session.dirty, UPDATE)):
+            for identity_set, op in (
+                (session.new, CREATION),
+                (session.deleted, DELETION),
+                (session.dirty, UPDATE),
+            ):
                 for model in identity_set:
                     try:
                         entry = self.log(session, model, op)
                         if entry:
                             entries.append(entry)
-                    except:
+                    except BaseException:
                         if current_app.config.get(
-                                'DEBUG') or current_app.config.get('TESTING'):
+                                'DEBUG',
+                        ) or current_app.config.get('TESTING'):
                             raise
                         log.error(
-                            'Exception during entry creation', exc_info=True)
+                            'Exception during entry creation',
+                            exc_info=True,
+                        )
 
                 session.add_all(entries)
         finally:
@@ -245,7 +266,7 @@ class AuditService(Service):
         entity = model
         try:
             user_id = g.user.id
-        except:
+        except BaseException:
             user_id = 0
 
         meta = model.__auditable__
@@ -266,7 +287,7 @@ class AuditService(Service):
         entry.entity_id = entity.id
         entry.entity_type = entity.entity_type
 
-        entity_name = u''
+        entity_name = ''
         for attr_name in ('name', 'path', '__path_before_delete'):
             if hasattr(entity, attr_name):
                 entity_name = getattr(entity, attr_name)
@@ -277,8 +298,12 @@ class AuditService(Service):
         if op == CREATION:
             for instrumented_attr in meta.audited_attrs:
                 value = getattr(model, instrumented_attr.key)
-                self.set_attribute(model, value, NEVER_SET,
-                                   instrumented_attr.impl)
+                self.set_attribute(
+                    model,
+                    value,
+                    NEVER_SET,
+                    instrumented_attr.impl,
+                )
 
             for instrumented_attr in meta.collection_attrs:
                 for obj in getattr(model, instrumented_attr.key):
@@ -301,8 +326,10 @@ class AuditService(Service):
                     item = getattr(item, attr)
                 enduser_ids.append(text_type(item))
 
-            related_name = u'{} {}'.format(meta.backref_attr,
-                                           u' '.join(enduser_ids))
+            related_name = '{} {}'.format(
+                meta.backref_attr,
+                ' '.join(enduser_ids),
+            )
             related_changes = changes
             log.debug('related changes: %s', repr(related_changes))
             changes = Changes()
@@ -333,3 +360,60 @@ def format_large_value(value):
         # object of type '...' has no len()
         pass
     return value
+
+
+def get_model_changes(
+        entity_type,
+        year=None,
+        month=None,
+        day=None,
+        hour=None,
+        since=None,
+):
+    """Get models modified at the given date with the Audit service.
+
+    :param entity_type: string like "extranet_medicen.apps.crm.models.Compte".
+      Beware the typo, there won't be a warning message.
+    :param since: datetime
+    :param year: int
+    :param month: int
+    :param day: int
+    :param hour: int
+
+    :returns: a query object
+    """
+    query = AuditEntry.query
+
+    if since:
+        query = query.filter(AuditEntry.happened_at >= since)
+
+    if year:
+        query = query.filter(extract('year', AuditEntry.happened_at) == year)
+    if month:
+        query = query.filter(extract('month', AuditEntry.happened_at) == month)
+    if day:
+        query = query.filter(extract('day', AuditEntry.happened_at) == day)
+    if hour:
+        query = query.filter(extract('hour', AuditEntry.happened_at) == hour)
+
+    query = query.filter(AuditEntry.entity_type.like(entity_type)) \
+                 .order_by(AuditEntry.happened_at)
+
+    return query
+
+
+def get_columns_diff(changes):
+    """Add the changed columns as a diff attribute.
+
+    - changes: a list of changes (get_model_changes query.all())
+
+    Return: the same list, to which elements we added a "diff"
+    attribute containing the changed columns. Diff defaults to [].
+    """
+    for change in changes:
+        change.diff = []
+        elt_changes = change.get_changes()
+        if elt_changes:
+            change.diff = elt_changes.columns
+
+    return changes
