@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -46,7 +45,8 @@ class DummyAccount(Entity):
             db.Model.metadata,
             Column('integer_id', ForeignKey(IntegerCollection.id)),
             Column('account_id', ForeignKey(cls.id)),
-            sa.schema.UniqueConstraint('account_id', 'integer_id'),)
+            sa.schema.UniqueConstraint('account_id', 'integer_id'),
+        )
 
         return sa.orm.relationship(IntegerCollection, secondary=secondary_tbl)
 
@@ -60,15 +60,22 @@ class AccountRelated(db.Model):
     account = relationship(
         DummyAccount,
         backref=backref(
-            'data', order_by='AccountRelated.id', cascade='all, delete-orphan'))
+            'data',
+            order_by='AccountRelated.id',
+            cascade='all, delete-orphan',
+        ),
+    )
 
     text = Column(UnicodeText, default="")
 
 
 class CommentRelated(db.Model):
     __tablename__ = 'account_related_comment'
-    __auditable_entity__ = ('related.account', 'data.comments',
-                            ('related.id', 'id'))
+    __auditable_entity__ = (
+        'related.account',
+        'data.comments',
+        ('related.id', 'id'),
+    )
     id = Column(Integer, primary_key=True)
 
     related_id = Column(Integer, ForeignKey(AccountRelated.id), nullable=False)
@@ -77,7 +84,9 @@ class CommentRelated(db.Model):
         backref=backref(
             'comments',
             order_by='CommentRelated.id',
-            cascade='all, delete-orphan'))
+            cascade='all, delete-orphan',
+        ),
+    )
     text = Column(UnicodeText, default="")
 
 
@@ -118,7 +127,7 @@ class TestAudit(BaseTestCase):
         assert entry.entity_id == account.id
         assert entry.entity == account
         assert entry.changes.columns == {
-            'website': ('', 'http://www.john.com/')
+            'website': ('', 'http://www.john.com/'),
         }
 
         account.birthday = datetime.date(2012, 12, 25)
@@ -130,12 +139,13 @@ class TestAudit(BaseTestCase):
         assert entry.entity_id == account.id
         assert entry.entity == account
         assert entry.changes.columns == {
-            'birthday': (None, datetime.date(2012, 12, 25))
+            'birthday': (None, datetime.date(2012, 12, 25)),
         }
 
         # content hiding
         account.password = 'new super secret password'
-        assert account.__changes__.columns == {'password': ('******', '******')}
+        assert account.__changes__.columns == {
+            'password': ('******', '******')}
         db.session.commit()
 
         entry = AuditEntry.query.order_by(AuditEntry.happened_at).all()[3]
@@ -154,7 +164,8 @@ class TestAudit(BaseTestCase):
         assert entry.entity_id == account.id
         assert entry.entity is None
 
-        # check all entries are still present (but have lost reference to entity)
+        # check all entries are still present (but have lost reference to
+        # entity)
         entries = AuditEntry.query.all()
         assert len(entries) == 5
         assert all(e.entity_id == account.id for e in entries)
@@ -194,9 +205,9 @@ class TestAudit(BaseTestCase):
         assert 'data 1' in changes
         changes = changes['data 1']
         assert changes.columns == {
-            'text': (NEVER_SET, u'text 1'),
+            'text': (NEVER_SET, 'text 1'),
             'account_id': (NEVER_SET, 1),
-            'id': (NEVER_SET, 1)
+            'id': (NEVER_SET, 1),
         }
 
         comment = CommentRelated(related=data, text='comment')
@@ -213,9 +224,9 @@ class TestAudit(BaseTestCase):
         assert 'data.comments 1 1' in changes
         changes = changes['data.comments 1 1']
         assert changes.columns == {
-            'text': (NEVER_SET, u'comment'),
+            'text': (NEVER_SET, 'comment'),
             'related_id': (NEVER_SET, 1),
-            'id': (NEVER_SET, 1)
+            'id': (NEVER_SET, 1),
         }
 
         comment = CommentRelated(related=data, text='comment 2')
@@ -233,9 +244,9 @@ class TestAudit(BaseTestCase):
 
         changes = changes['data.comments 1 2']
         assert changes.columns == {
-            'text': (NEVER_SET, u'comment 2'),
+            'text': (NEVER_SET, 'comment 2'),
             'related_id': (NEVER_SET, 1),
-            'id': (NEVER_SET, 2)
+            'id': (NEVER_SET, 2),
         }
 
         # deletion
