@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -54,31 +53,36 @@ user_menu = NavGroup(
         endpoint=_user_photo_endpoint,
         css='avatar',
         size=20,
-        url_args=_user_photo_icon_args),
+        url_args=_user_photo_icon_args,
+    ),
     condition=is_authenticated,
-    items=(NavItem(
-        'user',
-        'logout',
-        title=_l(u'Logout'),
-        icon='log-out',
-        url=lambda context: url_for('login.logout'),
-        divider=True),))
+    items=(
+        NavItem(
+            'user',
+            'logout',
+            title=_l('Logout'),
+            icon='log-out',
+            url=lambda context: url_for('login.logout'),
+            divider=True,
+        ),
+    ),
+)
 
 _ACTIONS = (
     NavItem(
         'user',
         'login',
-        title=_l(u'Login'),
+        title=_l('Login'),
         icon='log-in',
         url=lambda context: url_for('login.login_form'),
-        condition=is_anonymous),
-    user_menu,)
+        condition=is_anonymous,
+    ),
+    user_menu,
+)
 
 
 class AuthServiceState(ServiceState):
-    """
-    State class for :class:`AuthService`
-    """
+    """State class for :class:`AuthService`"""
 
     def __init__(self, *args, **kwargs):
         super(AuthServiceState, self).__init__(*args, **kwargs)
@@ -118,11 +122,12 @@ class AuthService(Service):
                 # if a user is edited and should not have access any more, this will
                 # ensure he cannot continue if he had an active session
                 return None
-        except:
+        except BaseException:
             logger.warning("Error during login.", exc_info=True)
             session = current_app.db.session()
             if not session.is_active:
-                # session is not usable, rollback should restore a usable session
+                # session is not usable, rollback should restore a usable
+                # session
                 session.rollback()
 
             return None
@@ -142,9 +147,9 @@ class AuthService(Service):
         g.user = g.logged_user = user
         is_anonymous = user is None or user.is_anonymous
         security = app.services.get('security')
-        g.is_manager = (user and not is_anonymous and (
-            (security.has_role(user, 'admin') or
-             security.has_role(user, 'manager'))))
+        g.is_manager = (user and not is_anonymous and
+                        ((security.has_role(user, 'admin') or
+                          security.has_role(user, 'manager'))))
 
     def user_logged_out(self, app, user):
         if hasattr(g, 'user'):
@@ -160,10 +165,10 @@ class AuthService(Service):
         return redirect(url_for(login_manager.login_view, **kw))
 
     def do_access_control(self):
-        """
-        `before_request` handler to check if user should be redirected to login
-        page.
-        """
+        """`before_request` handler to check if user should be redirected to
+        login page."""
+        from abilian.services import get_service
+
         if current_app.testing and current_app.config.get("NO_LOGIN"):
             # Special case for tests
             user = User.query.get(0)
@@ -172,7 +177,8 @@ class AuthService(Service):
 
         state = self.app_state
         user = current_user._get_current_object()
-        roles = frozenset(current_app.services['security'].get_roles(user))
+        security = get_service('security')
+        roles = frozenset(security.get_roles(user))
         endpoint = request.endpoint
         bp = request.blueprint
 
@@ -209,7 +215,7 @@ class AuthService(Service):
         # too much.
         now = datetime.utcnow()
         if (user.last_active is None or
-            (now - user.last_active) > timedelta(minutes=1)):
+                (now - user.last_active) > timedelta(minutes=1)):
             user.last_active = now
             db.session.add(user)
             db.session.commit()
