@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -37,12 +36,14 @@ class TestAuth(BaseTestCase):
             url_root = request.url_root[:-1]
 
         with self.app.test_request_context(form_url(next='/')):
-            assert get_redirect_target() == url_root + u'/'
+            assert get_redirect_target() == url_root + '/'
 
         # test "next" from referer
-        referrer = url_root + u'/some/path'
+        referrer = url_root + '/some/path'
         with self.app.test_request_context(
-                form_url(), headers=[('Referer', referrer)]):
+                form_url(),
+                headers=[('Referer', referrer)],
+        ):
             assert get_redirect_target() == referrer
 
         # don't cycle if coming from 'login.*' page, like this kind of cycle:
@@ -50,43 +51,53 @@ class TestAuth(BaseTestCase):
         # -> redirect(next = forgot password form) -> ...
         referrer = url_root + url_for('login.forgotten_pw')
         with self.app.test_request_context(
-                form_url(), headers=[('Referer', referrer)]):
+                form_url(),
+                headers=[('Referer', referrer)],
+        ):
             assert get_redirect_target() is None
 
         # test open redirect is forbidden
         with self.app.test_request_context(
-                form_url(next='http://google.com/test')):
+                form_url(next='http://google.com/test'),
+        ):
             assert get_redirect_target() is None
 
-        # open redirect through malicious construct and browser not checking Location
+        # open redirect through malicious construct and browser not checking
+        # Location
         with self.app.test_request_context(form_url(next='/////google.com')):
-            assert get_redirect_target() == url_root + u'///google.com'
+            assert get_redirect_target() == url_root + '///google.com'
 
     def test_login_post(self):
         kwargs = dict(
-            email='User@domain.tld', password='azerty', can_login=True)
+            email='User@domain.tld',
+            password='azerty',
+            can_login=True,
+        )
         u = User(**kwargs)
         self.session.add(u)
         self.session.commit()
 
         rv = self.client.post('/user/login', data=kwargs)
-        self.assertEqual(rv.status_code, 302, "expected 302, got:" + rv.status)
+        assert rv.status_code == 302
 
         # wrong password
         d = dict(kwargs)
         d['password'] = 'wrong one'
         rv = self.client.post('/user/login', data=d)
-        self.assertEqual(rv.status_code, 401, "expected 401, got:" + rv.status)
+        assert rv.status_code == 401
 
         # login disabled
         u.can_login = False
         self.session.commit()
         rv = self.client.post('/user/login', data=kwargs)
-        self.assertEqual(rv.status_code, 401, "expected 401, got:" + rv.status)
+        assert rv.status_code == 401
 
     def test_api_post(self):
         kwargs = dict(
-            email='User@domain.tld', password='azerty', can_login=True)
+            email='User@domain.tld',
+            password='azerty',
+            can_login=True,
+        )
         u = User(**kwargs)
         self.session.add(u)
         self.session.commit()
@@ -94,23 +105,26 @@ class TestAuth(BaseTestCase):
         rv = self.client.post(
             '/user/api/login',
             data=json.dumps(kwargs),
-            content_type='application/json')
-        self.assertEqual(rv.status_code, 200, "expected 200, got:" + rv.status)
-        self.assertEqual(
-            rv.json,
-            dict(
-                email='User@domain.tld',
-                username='user@domain.tld',
-                fullname='Unknown',
-                next_url=''))
+            content_type='application/json',
+        )
+        assert rv.status_code == 200
+        assert rv.json == {
+            'email': 'User@domain.tld',
+            'username': 'user@domain.tld',
+            'fullname': 'Unknown',
+            'next_url': '',
+        }
 
         rv = self.client.post('/user/api/logout')
-        self.assertEqual(rv.status_code, 200, "expected 200, got:" + rv.status)
+        assert rv.status_code == 200
 
     def test_forgotten_pw(self):
         mail = self.app.extensions['mail']
         kwargs = dict(
-            email='User@domain.tld', password='azerty', can_login=True)
+            email='User@domain.tld',
+            password='azerty',
+            can_login=True,
+        )
         u = User(**kwargs)
         self.session.add(u)
         self.session.commit()
@@ -121,11 +135,10 @@ class TestAuth(BaseTestCase):
 
         with mail.record_messages() as outbox:
             rv = self.client.post('/user/forgotten_pw', data=kwargs)
-            self.assertEqual(rv.status_code, 302,
-                             "expected 302, got:" + rv.status)
-            self.assertEqual(len(outbox), 1)
+            assert rv.status_code == 302
+            assert len(outbox) == 1
+
             msg = outbox[0]
-            self.assertEqual(msg.subject,
-                             u'Password reset instruction for Abilian Test')
-            self.assertEqual(msg.recipients, [u'User@domain.tld'])
-            self.assertEqual(msg.cc, [])
+            assert msg.subject == 'Password reset instruction for Abilian Test'
+            assert msg.recipients == ['User@domain.tld']
+            assert msg.cc == []
