@@ -1,7 +1,5 @@
 # coding=utf-8
-"""
-Objects to schema adapters
-"""
+"""Objects to schema adapters."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -11,7 +9,7 @@ from operator import attrgetter
 
 import sqlalchemy as sa
 from flask import current_app
-from six import string_types
+from six import add_metaclass, string_types
 from whoosh.fields import TEXT
 
 from abilian.core.extensions import db
@@ -23,12 +21,13 @@ __all__ = ['SchemaAdapter', 'SAAdapter']
 logger = logging.getLogger(__name__)
 
 
+@add_metaclass(ABCMeta)
 class SchemaAdapter(object):
+    """Abstract base class for objects to schema adapter.
+
+    The purpose of adapters is that given an object they return kwargs
+    for document.
     """
-    Abstract base class for objects to schema adapter. The purpose of adapters is
-    that given an object they return kwargs for document.
-    """
-    __metaclass__ = ABCMeta
 
     def __init__(self, Model, schema):
         """
@@ -39,8 +38,7 @@ class SchemaAdapter(object):
 
     @staticmethod
     def can_adapt(obj_cls):
-        """Return True if this class can adapt objects of class `obj_cls`.
-        """
+        """Return True if this class can adapt objects of class `obj_cls`."""
         raise NotImplementedError
 
     @abstractmethod
@@ -112,8 +110,10 @@ class SAAdapter(SchemaAdapter):
                 field_name, field_def = field_name
 
             if field_name not in schema:
-                if (field_name not in field_definitions or
-                        field_definitions[field_name] is False):
+                if (
+                    field_name not in field_definitions or
+                    field_definitions[field_name] is False
+                ):
                     field_definitions[field_name] = field_def
 
             # attrgetter offers dotted name support. Useful for attributes on related
@@ -150,10 +150,14 @@ class SAAdapter(SchemaAdapter):
             if field_def is False:
                 field_def = TEXT(stored=True, analyzer=accent_folder)
 
-            logger.debug('Adding field to schema:\n'
-                         '  Model: %s\n'
-                         '  Field: "%s" %s',
-                         Model._object_type(), field_name, field_def)
+            logger.debug(
+                'Adding field to schema:\n'
+                '  Model: %s\n'
+                '  Field: "%s" %s',
+                Model._object_type(),
+                field_name,
+                field_def,
+            )
             schema.add(field_name, field_def)
 
     def retrieve(self, pk, _session=None, **data):
@@ -191,7 +195,7 @@ class SAAdapter(SchemaAdapter):
                 val = cached[a]
                 if val is not None:
                     if isinstance(val, (list, tuple)):
-                        val = u' '.join(val).strip()
+                        val = ' '.join(val).strip()
                     values.append(val)
 
             values = [v for v in values if v]
@@ -200,6 +204,6 @@ class SAAdapter(SchemaAdapter):
                 if len(values) == 1:
                     kwargs[field] = values[0]
                 else:
-                    kwargs[field] = u' '.join(values)
+                    kwargs[field] = ' '.join(values)
 
         return kwargs
