@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-Indexing service for Abilian.
+"""Indexing service for Abilian.
 
 Adds Whoosh indexing capabilities to SQLAlchemy models.
 
@@ -71,9 +70,7 @@ if not _PATCHED:
 
 
 def url_for_hit(hit, default='#'):
-    """
-    Helper for building URLs from results
-    """
+    """Helper for building URLs from results."""
     try:
         object_type = hit['object_type']
         object_id = int(hit['id'])
@@ -123,9 +120,7 @@ class IndexServiceState(ServiceState):
 
 
 class WhooshIndexService(Service):
-    """
-    Index documents using whoosh
-    """
+    """Index documents using whoosh."""
     name = 'indexing'
     AppStateClass = IndexServiceState
 
@@ -167,7 +162,8 @@ class WhooshIndexService(Service):
         """Register a function that returns a query used for filtering search
         results. This query is And'ed with other filters.
 
-        If no filtering should be performed the function must return None.
+        If no filtering should be performed the function must return
+        None.
         """
         self.app_state.search_filter_funcs.append(func)
 
@@ -192,8 +188,7 @@ class WhooshIndexService(Service):
         self.clear_update_queue()
 
     def init_indexes(self):
-        """Create indexes for schemas.
-        """
+        """Create indexes for schemas."""
         state = self.app_state
 
         for name, schema in self.schemas.items():
@@ -215,13 +210,13 @@ class WhooshIndexService(Service):
     def clear(self):
         """Remove all content from indexes, and unregister all classes.
 
-        After clear() the service is stopped. It must be started again to create
-        new indexes and register classes.
+        After clear() the service is stopped. It must be started again
+        to create new indexes and register classes.
         """
         logger.info('Resetting indexes')
         state = self.app_state
 
-        for name, idx in state.indexes.items():
+        for _name, idx in state.indexes.items():
             writer = AsyncWriter(idx)
             writer.commit(merge=True, optimize=True, mergetype=CLEAR)
 
@@ -238,9 +233,9 @@ class WhooshIndexService(Service):
 
     @property
     def default_search_fields(self):
-        """
-        Return default field names and boosts to be used for searching. Can be
-        configured with `SEARCH_DEFAULT_BOOSTS`
+        """Return default field names and boosts to be used for searching.
+
+        Can be configured with `SEARCH_DEFAULT_BOOSTS`
         """
         config = current_app.config.get('SEARCH_DEFAULT_BOOSTS')
         if not config:
@@ -248,30 +243,34 @@ class WhooshIndexService(Service):
             return config
 
     def searchable_object_types(self):
-        """List of (object_types, friendly name) present in the index.
-        """
+        """List of (object_types, friendly name) present in the index."""
         try:
             idx = self.index()
         except KeyError:
-            # index does not exists: service never started, may happens during tests
+            # index does not exists: service never started, may happens during
+            # tests
             return []
 
         with idx.reader() as r:
             indexed = sorted(set(r.field_terms('object_type')))
         app_indexed = self.app_state.indexed_fqcn
 
-        return [(name, friendly_fqcn(name)) for name in indexed
-                if name in app_indexed]
+        return [
+            (name, friendly_fqcn(name)) for name in indexed
+            if name in app_indexed
+        ]
 
-    def search(self,
-               q,
-               index='default',
-               fields=None,
-               Models=(),
-               object_types=(),
-               prefix=True,
-               facet_by_type=None,
-               **search_args):
+    def search(
+        self,
+        q,
+        index='default',
+        fields=None,
+        Models=(),
+        object_types=(),
+        prefix=True,
+        facet_by_type=None,
+        **search_args
+    ):
         """Interface to search indexes.
 
         :param q: unparsed search string.
@@ -290,9 +289,11 @@ class WhooshIndexService(Service):
         if not fields:
             fields = self.default_search_fields
 
-        valid_fields = set(
-            f for f in index.schema.names(check_names=fields)
-            if prefix or not f.endswith('_prefix'))
+        valid_fields = {
+            f
+            for f in index.schema.names(check_names=fields)
+            if prefix or not f.endswith('_prefix')
+        }
 
         for invalid in set(fields) - valid_fields:
             del fields[invalid]
@@ -311,11 +312,11 @@ class WhooshIndexService(Service):
             if not user.is_anonymous:
                 roles.add(indexable_role(Anonymous))
                 roles.add(indexable_role(Authenticated))
-                roles |= set(
-                    indexable_role(r) for r in security.get_roles(user))
+                roles |= {indexable_role(r) for r in security.get_roles(user)}
 
             filter_q = wq.Or(
-                [wq.Term('allowed_roles_and_users', role) for role in roles])
+                [wq.Term('allowed_roles_and_users', role) for role in roles],
+            )
             filters.append(filter_q)
 
         object_types = set(object_types)
@@ -343,7 +344,7 @@ class WhooshIndexService(Service):
 
         if filters:
             filter_q = wq.And(filters) if len(filters) > 1 else filters[0]
-            #search_args['filter'] = filter_q
+            # search_args['filter'] = filter_q
             query = filter_q & query
 
         if facet_by_type:
@@ -356,7 +357,9 @@ class WhooshIndexService(Service):
             search_args['collapse'] = 'object_type'
             search_args['collapse_limit'] = collapse_limit
             search_args['limit'] = (search_args['collapse_limit'] * max(
-                len(object_types), 1))
+                len(object_types),
+                1,
+            ))
 
         with index.searcher(closereader=False) as searcher:
             # 'closereader' is needed, else results cannot by used outside 'with'
@@ -379,21 +382,22 @@ class WhooshIndexService(Service):
 
     def search_for_class(self, query, cls, index='default', **search_args):
         return self.search(
-            query, Models=(fqcn(cls),), index=index, **search_args)
+            query, Models=(fqcn(cls),), index=index, **search_args
+        )
 
     def register_classes(self):
         state = self.app_state
         classes = (
             cls for cls in db.Model._decl_class_registry.values()
-            if isclass(cls) and issubclass(cls, Indexable) and cls.__indexable__
+            if isclass(cls) and issubclass(cls, Indexable) and
+            cls.__indexable__
         )
         for cls in classes:
             if cls not in state.indexed_classes:
                 self.register_class(cls, app_state=state)
 
     def register_class(self, cls, app_state=None):
-        """Register a model class.
-        """
+        """Register a model class."""
         state = app_state if app_state is not None else self.app_state
 
         for Adapter in self.adapters_cls:
@@ -415,7 +419,8 @@ class WhooshIndexService(Service):
         session_objs = (
             ('new', session.new),
             ('deleted', session.deleted),
-            ('changed', session.dirty),)
+            ('changed', session.dirty),
+        )
         for key, objs in session_objs:
             for obj in objs:
                 model_name = fqcn(obj.__class__)
@@ -427,11 +432,13 @@ class WhooshIndexService(Service):
                 to_update.append((key, obj))
 
     def after_commit(self, session):
-        """
-        Any db updates go through here. We check if any of these models have
-        ``__searchable__`` fields, indicating they need to be indexed. With these
-        we update the whoosh index for the model. If no index exists, it will be
-        created here; this could impose a penalty on the initial commit of a model.
+        """Any db updates go through here.
+
+        We check if any of these models have ``__searchable__`` fields,
+        indicating they need to be indexed. With these we update the
+        whoosh index for the model. If no index exists, it will be
+        created here; this could impose a penalty on the initial commit
+        of a model.
         """
         if (not self.running or
                 session.transaction.nested  # inside a sub-transaction:
@@ -489,8 +496,7 @@ class WhooshIndexService(Service):
         return document
 
     def index_objects(self, objects, index='default'):
-        """Bulk index a list of objects.
-        """
+        """Bulk index a list of objects."""
         if not objects:
             return
 
@@ -513,9 +519,13 @@ class WhooshIndexService(Service):
                     writer.add_document(**document)
                 except ValueError:
                     # logger is here to give us more infos in order to catch a weird bug
-                    # that happens regularly on CI but is not reliably reproductible.
+                    # that happens regularly on CI but is not reliably
+                    # reproductible.
                     logger.error(
-                        'writer.add_document(%r)', document, exc_info=True)
+                        'writer.add_document(%r)',
+                        document,
+                        exc_info=True,
+                    )
                     raise
                 indexed.add(object_key)
 
@@ -543,7 +553,7 @@ def index_update(index, items):
 
             # always delete. Whoosh manual says that 'update' is actually delete + add
             # operation
-            object_key = u'{}:{}'.format(cls_name, pk)
+            object_key = '{}:{}'.format(cls_name, pk)
             writer.delete_by_term('object_key', object_key)
 
             adapter = adapted.get(cls_name)
@@ -570,12 +580,16 @@ def index_update(index, items):
                     writer.add_document(**document)
                 except ValueError:
                     # logger is here to give us more infos in order to catch a weird bug
-                    # that happens regularly on CI but is not reliably reproductible.
+                    # that happens regularly on CI but is not reliably
+                    # reproductible.
                     logger.error(
-                        'writer.add_document(%r)', document, exc_info=True)
+                        'writer.add_document(%r)',
+                        document,
+                        exc_info=True,
+                    )
                     raise
                 updated.add(object_key)
-    except:
+    except BaseException:
         writer.cancel()
         raise
 
@@ -591,8 +605,7 @@ def index_update(index, items):
 
 
 class TestingStorage(RamStorage):
-    """
-    RamStorage whoses temp_storage method returns another TestingStorage
+    """RamStorage whoses temp_storage method returns another TestingStorage
     instead of a FileStorage.
 
     Reason is that FileStorage.temp_storage() creates temp file in
