@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -12,6 +11,6 @@ from abilian.services.security.models import Anonymous, Reader
 
 def test_indexable_role():
 
-    assert indexable_role(Anonymous) == u'role:anonymous'
-    assert indexable_role(AnonymousUserMixin()) == u'role:anonymous'
-    assert indexable_role(Reader) == u'role:reader'
+    assert indexable_role(Anonymous) == 'role:anonymous'
+    assert indexable_role(AnonymousUserMixin()) == 'role:anonymous'
+    assert indexable_role(Reader) == 'role:reader'
