@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-User preference service.
+"""User preference service.
 
 Notes:
 
@@ -28,10 +27,11 @@ from .models import UserPreference
 _PREF_NAV_ITEM = NavItem(
     'user',
     'preferences',
-    title=_l(u'Preferences'),
+    title=_l('Preferences'),
     icon='cog',
     url=lambda context: request.url_root + 'preferences',
-    condition=lambda context: not current_user.is_anonymous)
+    condition=lambda context: not current_user.is_anonymous,
+)
 
 user_menu.insert(0, _PREF_NAV_ITEM)
 
@@ -49,10 +49,8 @@ class PreferenceState(ServiceState):
 
 
 class PreferenceService(Service):
-    """
-    Flask extension for a user-level preference service, with pluggable
-    panels.
-    """
+    """Flask extension for a user-level preference service, with pluggable
+    panels."""
     name = 'preferences'
     AppStateClass = PreferenceState
 
@@ -75,8 +73,7 @@ class PreferenceService(Service):
         return {pref.key: pref.value for pref in user.preferences}
 
     def set_preferences(self, user=None, **kwargs):
-        """Set preferences from keyword arguments.
-        """
+        """Set preferences from keyword arguments."""
         if user is None:
             user = current_user
 
@@ -89,8 +86,7 @@ class PreferenceService(Service):
                 db.session.add(d[k])
 
     def clear_preferences(self, user=None):
-        """Clear the user preferences.
-        """
+        """Clear the user preferences."""
         if user is None:
             user = current_user
 
@@ -102,8 +98,10 @@ class PreferenceService(Service):
     def register_panel(self, panel, app=None):
         state = self.app_state if app is None else app.extensions[self.name]
         if state.blueprint_registered:
-            raise ValueError("Extension already initialized for app, "
-                             "cannot add more panel")
+            raise ValueError(
+                "Extension already initialized for app, "
+                "cannot add more panel",
+            )
 
         state.panels.append(panel)
         panel.preferences = self
@@ -116,19 +114,25 @@ class PreferenceService(Service):
         if hasattr(panel, 'post'):
             endpoint += "_post"
             state.blueprint.add_url_rule(
-                rule, endpoint, panel.post, methods=['POST'])
+                rule,
+                endpoint,
+                panel.post,
+                methods=['POST'],
+            )
 
         state.breadcrumb_items[abs_endpoint] = BreadcrumbItem(
             label=panel.label,
             icon=None,
-            url=Endpoint(abs_endpoint),)
+            url=Endpoint(abs_endpoint),
+        )
 
     def setup_blueprint(self, app):
         bp = self.app_state.blueprint = Blueprint(
             "preferences",
             __name__,
             template_folder='templates',
-            url_prefix="/preferences")
+            url_prefix="/preferences",
+        )
 
         # we need to delay blueprint registration to allow adding more panels during
         # initialization
@@ -138,8 +142,9 @@ class PreferenceService(Service):
             app.extensions[self.name].blueprint_registered = True
 
         self.app_state.root_breadcrumb_item = BreadcrumbItem(
-            label=_(u'Preferences'),
-            url=Endpoint('preferences.index'))
+            label=_('Preferences'),
+            url=Endpoint('preferences.index'),
+        )
 
         bp.url_value_preprocessor(self.build_breadcrumbs)
 
@@ -155,15 +160,14 @@ class PreferenceService(Service):
                     'endpoint': endpoint,
                     'label': panel.label,
                     'url': url_for(endpoint),
-                    'active': active
+                    'active': active,
                 }
                 menu.append(entry)
             return dict(menu=menu)
 
         @bp.route("/")
         def index():
-            """Index redirects to the first accessible panel.
-            """
+            """Index redirects to the first accessible panel."""
 
             # Work around unit test failure. FIXME.
             if current_user.is_anonymous:
