@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -22,25 +21,42 @@ from abilian.core.singleton import UniqueName, UniqueNameType
 from abilian.i18n import _l
 
 __all__ = [
-    'RoleAssignment', 'PermissionAssignment', 'SecurityAudit',
-    'InheritSecurity', 'Permission', 'MANAGE', 'READ', 'WRITE', 'CREATE',
-    'DELETE', 'Role', 'Anonymous', 'Authenticated', 'Admin', 'Manager',
-    'Creator', 'Owner', 'Reader', 'Writer', 'RoleType'
+    'RoleAssignment',
+    'PermissionAssignment',
+    'SecurityAudit',
+    'InheritSecurity',
+    'Permission',
+    'MANAGE',
+    'READ',
+    'WRITE',
+    'CREATE',
+    'DELETE',
+    'Role',
+    'Anonymous',
+    'Authenticated',
+    'Admin',
+    'Manager',
+    'Creator',
+    'Owner',
+    'Reader',
+    'Writer',
+    'RoleType',
 ]
 
 
 @total_ordering
 @python_2_unicode_compatible
 class Permission(UniqueName):
-    """
-    Defines permission by name. Permission instances are unique by name.
+    """Defines permission by name.
+
+    Permission instances are unique by name.
     """
     __slots__ = ('label',)
 
     def __init__(self, name, label=None, assignable=True):
         UniqueName.__init__(self, name)
         if label is None:
-            label = u'permission_' + text_type(name)
+            label = 'permission_' + text_type(name)
         if isinstance(label, text_type):
             label = _l(label)
         self.label = label
@@ -55,8 +71,7 @@ class Permission(UniqueName):
 class PermissionType(UniqueNameType):
     """Store :class:`Permission`
 
-    Usage::
-    RoleType()
+    Usage:: RoleType()
     """
     Type = Permission
 
@@ -75,7 +90,7 @@ class Role(UniqueName):
     def __init__(self, name, label=None, assignable=True):
         UniqueName.__init__(self, name)
         if label is None:
-            label = u'role_' + text_type(name)
+            label = 'role_' + text_type(name)
         if isinstance(label, text_type):
             label = _l(label)
         self.label = label
@@ -85,35 +100,37 @@ class Role(UniqueName):
         return text_type(self.name)
 
     def __repr__(self):
-        return "{}({}, {})".format(self.__class__.__name__, self.name,
-                                   self.label)
+        return "{}({}, {})".format(
+            self.__class__.__name__,
+            self.name,
+            self.label,
+        )
 
     def __lt__(self, other):
         return text_type(self.label).__lt__(text_type(other.label))
 
     @classmethod
     def assignable_roles(cls):
-        roles = [r for r in cls.__instances__.values() if r.assignable]
-        roles.sort()
-        return roles
+        return sorted(r for r in cls.__instances__.values() if r.assignable)
 
 
 class RoleType(UniqueNameType):
-    """
-    Store :class:`Role`
+    """Store :class:`Role`
 
-    Usage::
-    RoleType()
+    Usage:: RoleType()
     """
     Type = Role
 
 
 #: marker for role assigned to 'Anonymous'
-Anonymous = Role('anonymous', _l(u'role_anonymous'), assignable=False)
+Anonymous = Role('anonymous', _l('role_anonymous'), assignable=False)
 
 #: marker for role assigned to 'Authenticated'
 Authenticated = Role(
-    'authenticated', _l('role_authenticated'), assignable=False)
+    'authenticated',
+    _l('role_authenticated'),
+    assignable=False,
+)
 
 #: marker for `admin` role
 Admin = Role('admin', _l('role_administrator'))
@@ -146,7 +163,8 @@ class RoleAssignment(db.Model):
             " ((user_id IS NOT NULL AND group_id IS NULL)"
             "  OR "
             "  (user_id IS NULL AND group_id IS NOT NULL)))",
-            name="roleassignment_ck_user_xor_group"),
+            name="roleassignment_ck_user_xor_group",
+        ),
         #
         UniqueConstraint(
             'anonymous',
@@ -154,7 +172,9 @@ class RoleAssignment(db.Model):
             'group_id',
             'role',
             'object_id',
-            name='assignment_mapped_role_unique'))
+            name='assignment_mapped_role_unique',
+        ),
+    )
 
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
     role = Column(RoleType, index=True, nullable=False)
@@ -164,19 +184,26 @@ class RoleAssignment(db.Model):
         index=True,
         nullable=True,
         default=False,
-        server_default=sql.false())
+        server_default=sql.false(),
+    )
     user_id = Column(
-        Integer, ForeignKey(
-            'user.id', ondelete='CASCADE'), index=True)
+        Integer,
+        ForeignKey('user.id', ondelete='CASCADE'),
+        index=True,
+    )
     user = relationship(User, lazy='joined')
     group_id = Column(
-        Integer, ForeignKey(
-            'group.id', ondelete='CASCADE'), index=True)
+        Integer,
+        ForeignKey('group.id', ondelete='CASCADE'),
+        index=True,
+    )
     group = relationship(Group, lazy='joined')
 
     object_id = Column(
-        Integer, ForeignKey(
-            Entity.id, ondelete='CASCADE'), index=True)
+        Integer,
+        ForeignKey(Entity.id, ondelete='CASCADE'),
+        index=True,
+    )
     object = relationship(Entity, lazy='select')
 
 
@@ -207,20 +234,23 @@ def _postgres_indexes():
             role,
             unique=True,
             postgresql_where=((anonymous == False) & (group_id == None) &
-                              (obj == None))),
+                              (obj == None)),
+        ),
         Index(
             name('group_role'),
             group_id,
             role,
             unique=True,
             postgresql_where=((anonymous == False) & (user_id == None) &
-                              (obj == None))),
+                              (obj == None)),
+        ),
         Index(
             name('anonymous_role'),
             role,
             unique=True,
             postgresql_where=((anonymous == True) & (user_id == None) &
-                              (group_id == None) & (obj == None))),
+                              (group_id == None) & (obj == None)),
+        ),
         Index(
             name('user_role_object'),
             user_id,
@@ -228,7 +258,8 @@ def _postgres_indexes():
             obj,
             unique=True,
             postgresql_where=((anonymous == False) & (group_id == None) &
-                              (obj != None))),
+                              (obj != None)),
+        ),
         Index(
             name('group_role_object'),
             group_id,
@@ -236,14 +267,16 @@ def _postgres_indexes():
             obj,
             unique=True,
             postgresql_where=((anonymous == False) & (user_id == None) &
-                              (obj != None))),
+                              (obj != None)),
+        ),
         Index(
             name('anonymous_role_object'),
             role,
             obj,
             unique=True,
             postgresql_where=((anonymous == True) & (user_id == None) &
-                              (group_id == None) & (obj != None))),
+                              (group_id == None) & (obj != None)),
+        ),
     ]
 
     for idx in indexes:
@@ -260,18 +293,24 @@ PERMISSIONS_ATTR = '__permissions__'
 
 class PermissionAssignment(db.Model):
     __tablename__ = 'permission_assignment'
-    __table_args__ = (UniqueConstraint(
-        'permission', 'role', 'object_id', name='assignments_unique'),)
+    __table_args__ = (
+        UniqueConstraint(
+            'permission',
+            'role',
+            'object_id',
+            name='assignments_unique',
+        ),
+    )
 
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
     permission = Column(PermissionType, index=True, nullable=False)
     role = Column(RoleType, index=True, nullable=False)
     object_id = Column(
         Integer,
-        ForeignKey(
-            Entity.id, ondelete='CASCADE'),
+        ForeignKey(Entity.id, ondelete='CASCADE'),
         index=True,
-        nullable=True)
+        nullable=True,
+    )
     object = relationship(
         Entity,
         lazy='select',
@@ -280,7 +319,9 @@ class PermissionAssignment(db.Model):
             lazy='select',
             collection_class=set,
             cascade='all, delete-orphan',
-            passive_deletes=True))
+            passive_deletes=True,
+        ),
+    )
 
     def __hash__(self):
         return hash((self.permission, self.role, self.object))
@@ -289,8 +330,10 @@ class PermissionAssignment(db.Model):
         if not isinstance(other, PermissionAssignment):
             return False
 
-        return (self.permission == other.permission and
-                self.role == other.role and self.object == other.object)
+        return (
+            self.permission == other.permission and
+            self.role == other.role and self.object == other.object
+        )
 
     def __neq__(self, other):
         return not self.__eq__(other)
@@ -301,8 +344,7 @@ class PermissionAssignment(db.Model):
         return ('<{cls} instance at 0x{id:x} '
                 'permission={self.permission.name!r} '
                 'role={self.role.name!r} object={self.object!r}>'
-                ''.format(
-                    cls=classname, id=id(self), self=self))
+                ''.format(cls=classname, id=id(self), self=self))
 
 
 def _postgres_indexes():
@@ -317,7 +359,8 @@ def _postgres_indexes():
             PA.permission,
             PA.role,
             unique=True,
-            postgresql_where=(PA.object_id == None))
+            postgresql_where=(PA.object_id == None),
+        ),
     ]
 
     for idx in indexes:
@@ -331,13 +374,11 @@ del _postgres_indexes
 
 
 class SecurityAudit(db.Model):
-    """
-    Logs changes on security.
-    """
-    GRANT = u'GRANT'
-    REVOKE = u'REVOKE'
-    SET_INHERIT = u'SET_INHERIT'
-    UNSET_INHERIT = u'UNSET_INHERIT'
+    """Logs changes on security."""
+    GRANT = 'GRANT'
+    REVOKE = 'REVOKE'
+    SET_INHERIT = 'SET_INHERIT'
+    UNSET_INHERIT = 'UNSET_INHERIT'
 
     __tablename__ = "securityaudit"
     __table_args__ = (
@@ -360,9 +401,10 @@ class SecurityAudit(db.Model):
             "   AND ((user_id IS NOT NULL AND group_id IS NULL)"
             "  OR "
             "  (user_id IS NULL AND group_id IS NOT NULL)))"
-            "))".format(
-                grant=SET_INHERIT, revoke=UNSET_INHERIT),
-            name="securityaudit_ck_user_xor_group"),)
+            "))".format(grant=SET_INHERIT, revoke=UNSET_INHERIT),
+            name="securityaudit_ck_user_xor_group",
+        ),
+    )
 
     id = Column(Integer, primary_key=True)
     happened_at = Column(DateTime, default=datetime.utcnow, index=True)
@@ -372,7 +414,9 @@ class SecurityAudit(db.Model):
             REVOKE,
             SET_INHERIT,
             UNSET_INHERIT,
-            name='securityaudit_enum_op'))
+            name='securityaudit_enum_op',
+        ),
+    )
     role = Column(RoleType)
 
     manager_id = Column(Integer, ForeignKey(User.id))
@@ -392,8 +436,10 @@ class SecurityAudit(db.Model):
 
 
 class InheritSecurity(object):
-    """
-    Mixin for objects with a parent relation and security inheritance.
-    """
+    """Mixin for objects with a parent relation and security inheritance."""
     inherit_security = Column(
-        Boolean, default=True, nullable=False, info={'auditable': False})
+        Boolean,
+        default=True,
+        nullable=False,
+        info={'auditable': False},
+    )
