@@ -1,13 +1,10 @@
 # coding=utf-8
-"""
-Security service, manages roles and permissions.
-"""
+"""Security service, manages roles and permissions."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 from functools import wraps
 from itertools import chain
-from typing import Dict, Set
 
 import sqlalchemy as sa
 from flask import current_app, g
@@ -32,18 +29,21 @@ from abilian.services.security.models import CREATE, DELETE, MANAGE, \
 PERMISSIONS = frozenset(['read', 'write', 'manage'])
 
 __all__ = [
-    'security', 'SecurityError', 'SecurityService', 'InheritSecurity',
-    'SecurityAudit'
+    'security',
+    'SecurityError',
+    'SecurityService',
+    'InheritSecurity',
+    'SecurityAudit',
 ]
 
 #: default security matrix
 DEFAULT_PERMISSION_ROLE = dict()
 prm = DEFAULT_PERMISSION_ROLE
-prm[MANAGE] = frozenset((Admin, Manager))
-prm[WRITE] = frozenset((Admin, Manager, Writer))
-prm[CREATE] = frozenset((Admin, Manager, Writer))
-prm[DELETE] = frozenset((Admin, Manager, Writer))
-prm[READ] = frozenset((Admin, Manager, Writer, Reader))
+prm[MANAGE] = frozenset({Admin, Manager})
+prm[WRITE] = frozenset({Admin, Manager, Writer})
+prm[CREATE] = frozenset({Admin, Manager, Writer})
+prm[DELETE] = frozenset({Admin, Manager, Writer})
+prm[READ] = frozenset({Admin, Manager, Writer, Reader})
 del prm
 
 
@@ -58,8 +58,10 @@ class SecurityServiceState(ServiceState):
 
 
 def require_flush(fun):
-    """ Decorator for methods that need to query security. It ensures all security
-    related operations are flushed to DB, but avoids unneeded flushes.
+    """Decorator for methods that need to query security.
+
+    It ensures all security related operations are flushed to DB, but
+    avoids unneeded flushes.
     """
 
     @wraps(fun)
@@ -69,7 +71,8 @@ def require_flush(fun):
             if (not session._flushing and any(
                     isinstance(m, (RoleAssignment, SecurityAudit))
                     for models in (session.new, session.dirty, session.deleted)
-                    for m in models)):
+                    for m in models
+            )):
                 session.flush()
             service.app_state.needs_db_flush = False
 
@@ -105,8 +108,10 @@ def query_pa_no_flush(session, permission, role, obj):
                        if isinstance(p, PermissionAssignment))
 
         for instance in permissions:
-            if (instance.permission == permission and instance.role == role and
-                    instance.object == obj):
+            if (
+                instance.permission == permission and instance.role == role and
+                instance.object == obj
+            ):
                 return instance
 
         # last chance: perform a filtered query. If obj is not None, sometimes
@@ -117,9 +122,11 @@ def query_pa_no_flush(session, permission, role, obj):
             obj = None
 
         return session.query(PermissionAssignment) \
-            .filter(PermissionAssignment.permission == permission,
-                    PermissionAssignment.role == role,
-                    PermissionAssignment.object == obj) \
+            .filter(
+                PermissionAssignment.permission == permission,
+                PermissionAssignment.role == role,
+                PermissionAssignment.object == obj,
+        ) \
             .first()
 
 
@@ -134,29 +141,29 @@ class SecurityService(Service):
         state.use_cache = True
 
     def _needs_flush(self):
-        """Mark next security queries needs DB flush to have up to date information
-        """
+        """Mark next security queries needs DB flush to have up to date
+        information."""
         self.app_state.needs_db_flush = True
 
     def clear(self):
         pass
 
     def _current_user_manager(self, session=None):
-        """Return the current user, or SYSTEM user.
-        """
+        """Return the current user, or SYSTEM user."""
         if session is None:
             session = db.session()
 
         try:
             user = g.user
-        except:
+        except BaseException:
             return session.query(User).get(0)
 
         if sa.orm.object_session(user) is not session:
             # this can happen when called from a celery task during development (with
             # CELERY_ALWAYS_EAGER=True): the task SA session is not app.db.session,
             # and we should not attach this object to the other session, because it
-            # can make weird, hard-to-debug errors related to session.identity_map.
+            # can make weird, hard-to-debug errors related to
+            # session.identity_map.
             return session.query(User).get(user.id)
         else:
             return user
@@ -180,15 +187,18 @@ class SecurityService(Service):
         session.add(obj)
 
         manager = self._current_user_manager(session=session)
-        op = (SecurityAudit.SET_INHERIT
-              if inherit_security else SecurityAudit.UNSET_INHERIT)
+        op = (
+            SecurityAudit.SET_INHERIT
+            if inherit_security else SecurityAudit.UNSET_INHERIT
+        )
         audit = SecurityAudit(
             manager=manager,
             op=op,
             object=obj,
             object_id=obj.id,
             object_type=obj.entity_type,
-            object_name=obj.name)
+            object_name=obj.name,
+        )
         session.add(audit)
         self._needs_flush()
 
@@ -197,7 +207,8 @@ class SecurityService(Service):
     #
     @require_flush
     def get_roles(self, principal, object=None, no_group_roles=False):
-        """Get all the roles attached to given `principal`, on a given `object`.
+        """Get all the roles attached to given `principal`, on a given
+        `object`.
 
         :param principal: a :class:`User` or :class:`Group`
 
@@ -235,15 +246,16 @@ class SecurityService(Service):
         return list(roles)
 
     @require_flush
-    def get_principals(self,
-                       role,
-                       anonymous=True,
-                       users=True,
-                       groups=True,
-                       object=None,
-                       as_list=True):
-        """Return all users which are assigned given role.
-        """
+    def get_principals(
+            self,
+            role,
+            anonymous=True,
+            users=True,
+            groups=True,
+            object=None,
+            as_list=True,
+    ):
+        """Return all users which are assigned given role."""
         if not isinstance(role, Role):
             role = Role(role)
         assert role
@@ -293,7 +305,7 @@ class SecurityService(Service):
             if object_id is None:
                 object_key = None
             else:
-                object_key = u'{}:{}'.format(object_type, object_id)
+                object_key = '{}:{}'.format(object_type, object_id)
             all_roles.setdefault(object_key, set()).add(role)
 
         return all_roles
@@ -327,19 +339,18 @@ class SecurityService(Service):
     @require_flush
     def _fill_role_cache_batch(self, principals, overwrite=False):
         """Fill role cache for `principals` (Users and/or Groups), in order to
-        avoid too many queries when checking role access with 'has_role'.
-        """
+        avoid too many queries when checking role access with 'has_role'."""
         if not self.app_state.use_cache:
             return
 
         query = db.session.query(RoleAssignment)
-        users = set((u for u in principals if isinstance(u, User)))
-        groups = set((g for g in principals if isinstance(g, Group)))
-        groups |= set((g for u in users for g in u.groups))
+        users = {u for u in principals if isinstance(u, User)}
+        groups = {g for g in principals if isinstance(g, Group)}
+        groups |= {g for u in users for g in u.groups}
 
         if not overwrite:
-            users = set((u for u in users if not self._has_role_cache(u)))
-            groups = set((g for g in groups if not self._has_role_cache(g)))
+            users = {u for u in users if not self._has_role_cache(u)}
+            groups = {g for g in groups if not self._has_role_cache(g)}
 
         if not (users or groups):
             return
@@ -347,16 +358,18 @@ class SecurityService(Service):
         # ensure principals processed here will have role cache. Thus users or
         # groups without any role will have an empty role cache, to avoid unneeded
         # individual DB query when calling self._fill_role_cache(p).
-        map(lambda p: self._set_role_cache(p, {}),
-            (p for p in chain(users, groups)))
+        for p in chain(users, groups):
+            self._set_role_cache(p, {})
 
         filter_cond = []
         if users:
             filter_cond.append(
-                RoleAssignment.user_id.in_((u.id for u in users)))
+                RoleAssignment.user_id.in_((u.id for u in users)),
+            )
         if groups:
             filter_cond.append(
-                RoleAssignment.group_id.in_((g.id for g in groups)))
+                RoleAssignment.group_id.in_((g.id for g in groups)),
+            )
 
         query = query.filter(sql.or_(*filter_cond))
         ra_users = {}
@@ -367,8 +380,10 @@ class SecurityService(Service):
             else:
                 all_roles = ra_groups.setdefault(ra.group, {})
 
-            object_key = (u'{}:{:d}'.format(ra.object.entity_type, ra.object_id)
-                          if ra.object is not None else None)
+            object_key = (
+                '{}:{:d}'.format(ra.object.entity_type, ra.object_id)
+                if ra.object is not None else None
+            )
             all_roles.setdefault(object_key, set()).add(ra.role)
 
         for group, all_roles in ra_groups.items():
@@ -393,8 +408,8 @@ class SecurityService(Service):
                     del u.__roles_cache__
 
     def has_role(self, principal, role, object=None):
-        """True if `principal` has `role` (either globally, if `object`
-        is None, or on the specific `object`).
+        """True if `principal` has `role` (either globally, if `object` is
+        None, or on the specific `object`).
 
         :param:role:  can be a list or tuple of strings or a :class:`Role` instance
 
@@ -422,12 +437,14 @@ class SecurityService(Service):
             # everybody has the role 'Anonymous'
             return True
 
-        if (Authenticated in valid_roles and isinstance(principal, User) and
-                not principal.is_anonymous):
+        if (
+            Authenticated in valid_roles and isinstance(principal, User) and
+            not principal.is_anonymous
+        ):
             return True
 
         if (principal is AnonymousRole or
-            (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
+                (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
             # anonymous user, and anonymous role isn't in valid_roles
             return False
 
@@ -437,8 +454,10 @@ class SecurityService(Service):
 
         if object:
             assert isinstance(object, Entity)
-            object_key = u"{}:{}".format(object.object_type,
-                                         text_type(object.id))
+            object_key = "{}:{}".format(
+                object.object_type,
+                text_type(object.id),
+            )
             if Creator in role:
                 if object.creator == principal:
                     return True
@@ -457,18 +476,22 @@ class SecurityService(Service):
         return len(valid_roles & roles) > 0
 
     def grant_role(self, principal, role, obj=None):
-        """Grant `role` to `user` (either globally, if `obj` is None, or on
-        the specific `obj`).
-        """
+        """Grant `role` to `user` (either globally, if `obj` is None, or on the
+        specific `obj`)."""
         assert principal
         principal = noproxy(principal)
         session = object_session(obj) if obj is not None else db.session
         manager = self._current_user_manager(session=session)
         args = dict(
-            role=role, object=obj, anonymous=False, user=None, group=None)
+            role=role,
+            object=obj,
+            anonymous=False,
+            user=None,
+            group=None,
+        )
 
         if (principal is AnonymousRole or
-            (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
+                (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
             args['anonymous'] = True
         elif isinstance(principal, User):
             args['user'] = principal
@@ -495,7 +518,7 @@ class SecurityService(Service):
         if obj is not None:
             audit.object_id = obj.id
             audit.object_type = obj.entity_type
-            object_name = u''
+            object_name = ''
             for attr_name in ('name', 'path', '__path_before_delete'):
                 if hasattr(obj, attr_name):
                     object_name = getattr(obj, attr_name)
@@ -508,26 +531,34 @@ class SecurityService(Service):
             del principal.__roles_cache__
 
     def ungrant_role(self, principal, role, object=None):
-        """Ungrant `role` to `user` (either globally, if `object` is None,
-        or on the specific `object`).
-        """
+        """Ungrant `role` to `user` (either globally, if `object` is None, or
+        on the specific `object`)."""
         assert principal
         principal = noproxy(principal)
         session = object_session(object) if object is not None else db.session
         manager = self._current_user_manager(session=session)
 
         args = dict(
-            role=role, object=object, anonymous=False, user=None, group=None)
+            role=role,
+            object=object,
+            anonymous=False,
+            user=None,
+            group=None,
+        )
         query = session.query(RoleAssignment)
-        query = query.filter(RoleAssignment.role == role,
-                             RoleAssignment.object == object)
+        query = query.filter(
+            RoleAssignment.role == role,
+            RoleAssignment.object == object,
+        )
 
         if (principal is AnonymousRole or
-            (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
+                (hasattr(principal, 'is_anonymous') and principal.is_anonymous)):
             args['anonymous'] = True
-            query.filter(RoleAssignment.anonymous == False,
-                         RoleAssignment.user == None,
-                         RoleAssignment.group == None)
+            query.filter(
+                RoleAssignment.anonymous == False,
+                RoleAssignment.user == None,
+                RoleAssignment.group == None,
+            )
 
         elif isinstance(principal, User):
             args['user'] = principal
@@ -568,18 +599,20 @@ class SecurityService(Service):
     #
     # Permission API, currently hardcoded
     #
-    def has_permission(self,
-                       user,
-                       permission,
-                       obj=None,
-                       inherit=False,
-                       roles=None):
+    def has_permission(
+            self,
+            user,
+            permission,
+            obj=None,
+            inherit=False,
+            roles=None,
+    ):
         """
-        @param `obj`: target object to check permissions.
-        @param `inherit`: check with permission inheritance. By default, check only
-        local roles.
-        @param `roles`: additional valid role or iterable of roles having
-                        `permission`.
+        :param obj: target object to check permissions.
+        :param inherit: check with permission inheritance. By default, check only
+                        local roles.
+        :param roles: additional valid role or iterable of roles having
+                      `permission`.
         """
         if not isinstance(permission, Permission):
             assert permission in PERMISSIONS
@@ -616,7 +649,7 @@ class SecurityService(Service):
         valid_roles |= {Admin}  # always have all permissions
         valid_roles |= DEFAULT_PERMISSION_ROLE.get(permission, set())
 
-        #FIXME: obj.__class__ could define default permisssion matrix too
+        # FIXME: obj.__class__ could define default permisssion matrix too
 
         if roles is not None:
             if isinstance(roles, (Role,) + string_types):
@@ -625,7 +658,7 @@ class SecurityService(Service):
             for r in roles:
                 valid_roles.add(Role(r))
 
-        #FIXME: query permission_role: global and on object
+        # FIXME: query permission_role: global and on object
 
         if AnonymousRole in valid_roles:
             return True
@@ -633,23 +666,24 @@ class SecurityService(Service):
         if Authenticated in valid_roles and not user.is_anonymous:
             return True
 
-        checked_objs = [None, obj]  # first test global roles, then object local
-        # roles
-
+        # first test global roles, then object local roles
+        checked_objs = [None, obj]
         if inherit and obj is not None:
-            while (obj.inherit_security and obj.parent is not None):
+            while obj.inherit_security and obj.parent is not None:
                 obj = obj.parent
                 checked_objs.append(obj)
 
         principals = [user] + list(user.groups)
         self._fill_role_cache_batch(principals)
 
-        return any((self.has_role(principal, valid_roles, item)
-                    for principal in principals for item in checked_objs))
+        return any((
+            self.has_role(principal, valid_roles, item)
+            for principal in principals for item in checked_objs
+        ))
 
-    def query_entity_with_permission(self, permission, user=None, Model=Entity):
-        """
-        Filter a query on an :class:`Entity` or on of its subclasses.
+    def query_entity_with_permission(
+            self, permission, user=None, Model=Entity):
+        """Filter a query on an :class:`Entity` or on of its subclasses.
 
         Usage::
 
@@ -665,7 +699,7 @@ class SecurityService(Service):
         :param permission: required :class:`Permission`
 
         :param Model: An :class:`Entity` based class. Useful when there is more than
-        on Entity based object in query, or if an alias should be used.
+        one Entity based object in query, or if an alias should be used.
 
         :returns: a `sqlalchemy.sql.exists()` expression.
         """
@@ -697,10 +731,12 @@ class SecurityService(Service):
         RA = sa.sql.select([RA], principal_filter).cte()
         permission_exists = \
             sa.sql.exists([1]) \
-                .where(sa.sql.and_(PA.permission == permission,
-                                   PA.object_id == id_column,
-                                   (RA.c.role == PA.role) | (PA.role == AnonymousRole),
-                                   (RA.c.object_id == PA.object_id) | (RA.c.object_id == None)))
+            .where(sa.sql.and_(
+                PA.permission == permission,
+                PA.object_id == id_column,
+                (RA.c.role == PA.role) | (PA.role == AnonymousRole),
+                (RA.c.object_id == PA.object_id) | (RA.c.object_id == None),
+            ))
 
         # is_admin: self-explanatory. It search for local or global admin
         # role, but PermissionAssignment is not involved, thus it can match on
@@ -708,19 +744,25 @@ class SecurityService(Service):
         # expressions cannot.
         is_admin = \
             sa.sql.exists([1]) \
-                .where(sa.sql.and_(RA.c.role == Admin,
-                                   (RA.c.object_id == id_column) | (RA.c.object_id == None),
-                                   principal_filter))
+            .where(sa.sql.and_(
+                RA.c.role == Admin,
+                (RA.c.object_id == id_column) | (RA.c.object_id == None),
+                principal_filter,
+            ))
 
         filter_expr = permission_exists | is_admin
 
         if user and not user.is_anonymous:
             is_owner_or_creator = sa.sql \
                 .exists([1]) \
-                .where(sa.sql.and_(PA.permission == permission,
-                                   PA.object_id == id_column,
-                                   sa.sql.or_((PA.role == Owner) & (owner == user),
-                                              (PA.role == Creator) & (creator == user))))
+                .where(sa.sql.and_(
+                    PA.permission == permission,
+                    PA.object_id == id_column,
+                    sa.sql.or_(
+                        (PA.role == Owner) & (owner == user),
+                        (PA.role == Creator) & (creator == user),
+                    ),
+                ))
             filter_expr |= is_owner_or_creator
 
         return filter_expr
@@ -743,8 +785,10 @@ class SecurityService(Service):
             session = current_app.db.session()
 
         pa = session \
-            .query(PermissionAssignment.permission,
-                   PermissionAssignment.role) \
+            .query(
+                PermissionAssignment.permission,
+                PermissionAssignment.role,
+            ) \
             .filter(PermissionAssignment.object == obj)
 
         if permission:
@@ -768,7 +812,10 @@ class SecurityService(Service):
 
         if not pa:
             pa = PermissionAssignment(
-                permission=permission, role=role, object=obj)
+                permission=permission,
+                role=role,
+                object=obj,
+            )
 
         # do it in any case: it could have been found in session.deleted
         session.add(pa)
@@ -789,7 +836,8 @@ class SecurityService(Service):
                 # this seems to be required with sqlalchemy > 0.9
                 session.expire(obj, [PERMISSIONS_ATTR])
 
-    def filter_with_permission(self, user, permission, obj_list, inherit=False):
+    def filter_with_permission(
+            self, user, permission, obj_list, inherit=False):
         user = noproxy(user)
         return [
             obj for obj in obj_list
