@@ -1,13 +1,11 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import json
 from datetime import timedelta
 
-import six
 import sqlalchemy as sa
 from six import text_type
 
@@ -27,9 +25,9 @@ class TransformerRegistry(object):
         return self.encoders.get(type_, bytes)(value)
 
     def decode(self, type_, value):
-        dec = self.decoders.get(type_)
-        if dec is not None:
-            value = dec(value)
+        decoder = self.decoders.get(type_)
+        if decoder is not None:
+            value = decoder(value)
         return value
 
     def register(self, type_, encoder=None, decoder=None):
@@ -46,11 +44,11 @@ _transformers = TransformerRegistry()
 
 class _EmptyValue(object):
 
-    def __nonzero__(self):
+    def __bool__(self):
         return False
 
-    # Py3k compat
-    __bool__ = __nonzero__
+    # Py2 compat
+    __nonzero__ = __bool__
 
     def __repr__(self):
         return '<Empty Value>'
@@ -69,7 +67,7 @@ class Setting(db.Model):
     transformers = _transformers
     key = sa.Column('key', sa.String(length=1000), primary_key=True)
 
-    #: Can be a string (unicode), int, bool, json... or even a long dotted name
+    #: Can be a string (Unicode), int, bool, json... or even a long dotted name
     #: if that's what you need. Type must be set before setting `value`
     _type = sa.Column('type', sa.String(length=1000), nullable=False)
 
@@ -79,11 +77,14 @@ class Setting(db.Model):
 
     @type.setter
     def type(self, type_):
-        if not (type_ in self.transformers.encoders and
-                type_ in self.transformers.decoders):
+        if not (
+            type_ in self.transformers.encoders and
+            type_ in self.transformers.decoders
+        ):
             raise ValueError(
-                'Invalid type "{}": not encoder and/or decoder registered'.
-                format(type_))
+                'Invalid type "{}": no encoder and/or decoder registered'.
+                format(type_),
+            )
         self._type = type_
 
     _value = sa.Column('value', sa.Text())
