@@ -1,13 +1,12 @@
 # coding=utf-8
-"""
-Admin panel for vocabularies
-"""
+"""Admin panel for vocabularies."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 from flask import current_app, g, redirect, render_template, request
 
 from abilian.i18n import _, _l
+from abilian.services import get_service
 from abilian.web import url_for, views
 from abilian.web.action import Glyphicon
 from abilian.web.admin import AdminPanel
@@ -19,7 +18,7 @@ _MARKER = object()
 
 
 class ViewBase(object):
-    title = _l(u'Vocabulary entry')
+    title = _l('Vocabulary entry')
     base_template = "admin/_base.html"
     Form = EditForm
     Model = None
@@ -45,7 +44,8 @@ class Edit(ViewBase, views.ObjectEdit):
         return url_for(
             '.vocabularies_model',
             group=self.Model.Meta.group or '_',
-            Model=self.Model.Meta.name,)
+            Model=self.Model.Meta.name,
+        )
 
 
 class Create(views.ObjectCreate, Edit):
@@ -61,37 +61,33 @@ class Delete(ViewBase, views.ObjectDelete):
 
 
 class VocabularyPanel(AdminPanel):
-    """
-    Vocabularies administration
-    """
+    """Vocabularies administration."""
     id = 'vocabularies'
-    label = _l(u'Vocabularies')
+    label = _l('Vocabularies')
     icon = 'list'
 
-    @property
-    def svc(self):
-        return current_app.services['vocabularies']
-
     def voc_edit_url(self, item):
         return url_for(
             '.' + self.id + '_edit',
-            group=item.Meta.group or u'_',
+            group=item.Meta.group or '_',
             Model=item.Meta.name,
-            object_id=item.id)
+            object_id=item.id,
+        )
 
     def get(self):
-        svc = self.svc
-        return render_template(
-            'admin/vocabularies.html',
-            service=svc,
-            url_for_voc_edit=self.voc_edit_url,
-            icon_checked=Glyphicon('check'),
-            vocabularies=svc.grouped_vocabularies,)
+        svc = get_service('vocabularies')
+        ctx = {
+            'service': svc,
+            'url_for_voc_edit': self.voc_edit_url,
+            'icon_checked': Glyphicon('check'),
+            'vocabularies': svc.grouped_vocabularies,
+        }
+        return render_template('admin/vocabularies.html', **ctx)
 
     def post(self):
         data = request.form
-        group = data.get('group', u'').strip()
-        Model = data.get('Model', u'').strip()
+        group = data.get('group', '').strip()
+        Model = data.get('Model', '').strip()
         return_to = data.get('return_to')
         return_endpoint = '.vocabularies'
         return_args = {}
@@ -105,11 +101,11 @@ class VocabularyPanel(AdminPanel):
         if not Model:
             return do_return()
 
-        if not group or group == u'_':
+        if not group or group == '_':
             # default group
             group = None
 
-        svc = self.svc
+        svc = get_service('vocabularies')
         Model = svc.get_vocabulary(name=Model, group=group)
         if not Model:
             return do_return()
@@ -158,25 +154,35 @@ class VocabularyPanel(AdminPanel):
         return do_return()
 
     def group_view(self, group):
-        groups = self.svc.grouped_vocabularies
+        svc = get_service('vocabularies')
+
+        groups = svc.grouped_vocabularies
         vocabularies = groups.get(group)
 
-        return render_template(
-            'admin/vocabularies.html',
-            service=self.svc,
-            url_for_voc_edit=self.voc_edit_url,
-            icon_checked=Glyphicon('check'),
-            vocabularies={group: vocabularies},
-            edit_return_to='group')
+        ctx = {
+            'service': svc,
+            'url_for_voc_edit': self.voc_edit_url,
+            'icon_checked': Glyphicon('check'),
+            'vocabularies': {
+                group: vocabularies,
+            },
+            'edit_return_to': 'group',
+        }
+        return render_template('admin/vocabularies.html', **ctx)
 
     def model_view(self, Model, group=None):
-        return render_template(
-            'admin/vocabularies.html',
-            service=self.svc,
-            url_for_voc_edit=self.voc_edit_url,
-            icon_checked=Glyphicon('check'),
-            vocabularies={Model.Meta.group: [Model]},
-            edit_return_to='model')
+        svc = get_service('vocabularies')
+
+        ctx = {
+            'service': svc,
+            'url_for_voc_edit': self.voc_edit_url,
+            'icon_checked': Glyphicon('check'),
+            'vocabularies': {
+                Model.Meta.group: [Model],
+            },
+            'edit_return_to': 'model',
+        }
+        return render_template('admin/vocabularies.html', **ctx)
 
     def install_additional_rules(self, add_url_rule):
         panel_endpoint = '.' + self.id
@@ -190,14 +196,14 @@ class VocabularyPanel(AdminPanel):
         add_url_rule(base + '<int:object_id>', view_func=edit_view)
         add_url_rule(
             base + 'new',
-            view_func=Create.as_view(
-                'new', view_endpoint=panel_endpoint))
+            view_func=Create.as_view('new', view_endpoint=panel_endpoint),
+        )
 
     def url_value_preprocess(self, endpoint, view_args):
         Model = view_args.pop('Model', None)
         group = view_args.pop('group', _MARKER)
 
-        if group == u'_':
+        if group == '_':
             # "General" group
             group = None
 
@@ -205,17 +211,20 @@ class VocabularyPanel(AdminPanel):
             view_args['group'] = group
 
         if Model is not None:
-            svc = self.svc
+            svc = get_service('vocabularies')
             Model = svc.get_vocabulary(name=Model, group=group)
             g.breadcrumb.append(BreadcrumbItem(
                 label=Model.Meta.group if group else _('Global'),
-                url=url_for('.vocabularies_group', group=group or u'_'),
+                url=url_for('.vocabularies_group', group=group or '_'),
             ))
             g.breadcrumb.append(
                 BreadcrumbItem(
                     label=Model.Meta.label,
                     url=url_for(
                         '.vocabularies_model',
-                        group=group or u'_',
-                        Model=Model.Meta.name),))
+                        group=group or '_',
+                        Model=Model.Meta.name,
+                    ),
+                ),
+            )
             view_args['Model'] = Model
