@@ -1,11 +1,14 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import six
 import sqlalchemy as sa
+import sqlalchemy.event
+import sqlalchemy.ext
+import sqlalchemy.ext.declarative
+import sqlalchemy.orm
 from flask_sqlalchemy import BaseQuery
 from sqlalchemy import Column
 
@@ -18,15 +21,11 @@ _BaseMeta = db.Model.__class__
 class VocabularyQuery(BaseQuery):
 
     def active(self):
-        """
-        Returns only valid vocabulary items
-        """
+        """Returns only valid vocabulary items."""
         return self.filter_by(active=True)
 
     def by_label(self, label):
-        """
-        Like `.get()`, but by label
-        """
+        """Like `.get()`, but by label."""
         # don't use .first(), so that MultipleResultsFound can be raised
         try:
             return self.filter_by(label=label).one()
@@ -34,9 +33,7 @@ class VocabularyQuery(BaseQuery):
             return None
 
     def by_position(self, position):
-        """
-        Like `.get()`, but by position number
-        """
+        """Like `.get()`, but by position number."""
         # don't use .first(), so that MultipleResultsFound can be raised
         try:
             return self.filter_by(position=position).one()
@@ -45,15 +42,16 @@ class VocabularyQuery(BaseQuery):
 
 
 class _VocabularyMeta(_BaseMeta):
-    """
-    Metaclass for vocabularies. Enforces `__tablename__`.
+    """Metaclass for vocabularies.
+
+    Enforces `__tablename__`.
     """
 
     def __new__(cls, name, bases, d):
         meta = d.get('Meta')
         tblprefix = 'vocabulary_'
 
-        group = slugify(meta.group or u'', u'_')
+        group = slugify(meta.group or '', '_')
         if group:
             tblprefix += group + '_'
 
@@ -67,9 +65,7 @@ class _VocabularyMeta(_BaseMeta):
 @six.python_2_unicode_compatible
 @six.add_metaclass(_VocabularyMeta)
 class BaseVocabulary(db.Model):
-    """
-    Base abstract class for vocabularies
-    """
+    """Base abstract class for vocabularies."""
     __abstract__ = True
     query_class = VocabularyQuery
 
@@ -79,22 +75,27 @@ class BaseVocabulary(db.Model):
         sa.Boolean(),
         nullable=False,
         server_default=sa.sql.true(),
-        default=True)
+        default=True,
+    )
     default = Column(
         sa.Boolean(),
         nullable=False,
         server_default=sa.sql.false(),
-        default=False)
+        default=False,
+    )
     position = Column(sa.Integer, nullable=False, unique=True)
 
     __table_args__ = (
-        sa.CheckConstraint(sa.sql.func.trim(sa.sql.text('label')) != u''),)
+        sa.CheckConstraint(
+            sa.sql.func.trim(sa.sql.text('label')) != '',
+        ),
+    )
 
     @sa.ext.declarative.declared_attr
     def __mapper_args__(cls):
         return {'order_by': [cls.__table__.c.position.asc()]}
 
-    class Meta:
+    class Meta(object):
         label = None
         group = None
 
@@ -102,10 +103,12 @@ class BaseVocabulary(db.Model):
         return self.label
 
     def __repr__(self):
-        fmt = ('<{module}.{cls} id={id} label={label} position={position} '
-               'active={active} default={default} at 0x{addr:x}')
+        tpl = (
+            '<{module}.{cls} id={id} label={label} position={position} '
+            'active={active} default={default} at 0x{addr:x}>'
+        )
         cls = self.__class__
-        return fmt.format(
+        return tpl.format(
             module=cls.__module__,
             cls=cls.__name__,
             id=self.id,
@@ -113,28 +116,26 @@ class BaseVocabulary(db.Model):
             position=repr(self.position),
             active=repr(self.active),
             default=repr(self.default),
-            addr=id(self),)
+            addr=id(self),
+        )
 
 
 @sa.event.listens_for(BaseVocabulary, "before_insert", propagate=True)
 @sa.event.listens_for(BaseVocabulary, "before_update", propagate=True)
 def strip_label(mapper, connection, target):
-    """
-    Strip labels at ORM level so the unique=True means something
-    """
+    """Strip labels at ORM level so the unique=True means something."""
     if target.label is not None:
         target.label = target.label.strip()
 
 
 @sa.event.listens_for(BaseVocabulary, "before_insert", propagate=True)
 def _before_insert(mapper, connection, target):
-    """
-    Set item to last position if position not defined
-    """
+    """Set item to last position if position not defined."""
     if target.position is None:
         func = sa.sql.func
         stmt = sa.select(
-            [func.coalesce(func.max(mapper.mapped_table.c.position), -1)])
+            [func.coalesce(func.max(mapper.mapped_table.c.position), -1)],
+        )
         target.position = connection.execute(stmt).scalar() + 1
 
 
