@@ -1,7 +1,5 @@
 # coding=utf-8
-"""
-Vocabularies service.
-"""
+"""Vocabularies service."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
