@@ -1,7 +1,5 @@
 # coding=utf-8
-"""
-Elements to build test cases for an :class:`abilian.app.Application`
-"""
+"""Elements to build test cases for an :class:`abilian.app.Application`"""
 from __future__ import absolute_import, print_function, division, unicode_literals
 
 import getpass
@@ -35,9 +33,9 @@ _DEFAULT_PWD = User.__password_strategy__
 
 
 class NullBundle(Bundle):
-    """
-    This bundle class emits no url, thus avoid any asset build. Saves a lot of
-    time during tests.
+    """This bundle class emits no url, thus avoid any asset build.
+
+    Saves a lot of time during tests.
     """
 
     def urls(self):
@@ -45,11 +43,10 @@ class NullBundle(Bundle):
 
 
 class TestConfig(object):
-    """
-    Base class config settings for test cases.
+    """Base class config settings for test cases.
 
-    The environment variable :envvar:`SQLALCHEMY_DATABASE_URI` can be set to easily
-    test against different databases.
+    The environment variable :envvar:`SQLALCHEMY_DATABASE_URI` can be
+    set to easily test against different databases.
     """
     SITE_NAME = 'Abilian Test'
     SQLALCHEMY_DATABASE_URI = "sqlite://"
@@ -87,8 +84,7 @@ class TestConfig(object):
 
 
 class BaseTestCase(TestCase):
-    """
-    Base test case to test an :class:`abilian.app.Application`.
+    """Base test case to test an :class:`abilian.app.Application`.
 
     It will create an instance path that will be used and shared for all tests
     defined in this test case.
@@ -116,8 +112,8 @@ class BaseTestCase(TestCase):
     #: By default sqlalchemy treats warnings as info. This settings makes
     #: sqlalchemy warnings treated as errors (and thus making test fail). The
     #: rationale is that it improves code quality (for example most frequent warnings
-    #: are non-unicode string assigned on a Unicode column; this setting force you to
-    #: be explicit and ensure unicode where appropriate)
+    #: are non-Unicode string assigned on a Unicode column; this setting force you to
+    #: be explicit and ensure Unicode where appropriate)
     SQLALCHEMY_WARNINGS_AS_ERROR = True
 
     #: list services names that should be started during setUp. 'repository' and
@@ -144,7 +140,9 @@ class BaseTestCase(TestCase):
         tmp_dir = Path(
             tempfile.mkdtemp(
                 prefix='tmp-py-unittest-',
-                suffix='-' + cls.__name__,))
+                suffix='-' + cls.__name__,
+            ),
+        )
         cls.TEST_INSTANCE_PATH = str(tmp_dir)
         for p in (tmp_dir / 'tmp', tmp_dir / 'cache', tmp_dir / 'data'):
             p.mkdir()
@@ -165,9 +163,8 @@ class BaseTestCase(TestCase):
         TestCase.tearDownClass()
 
     def get_setup_config(self):
-        """
-        Called by :meth:`create_app` Override this if you want to tweak the config
-        before :attr:`application_class` is instanciated.
+        """Called by :meth:`create_app` Override this if you want to tweak the
+        config before :attr:`application_class` is instanciated.
 
         :return: an instance of :attr:`config_class`, or anything that is a valid
                  config object for Flask.
@@ -178,7 +175,8 @@ class BaseTestCase(TestCase):
         config = self.get_setup_config()
         self.app = self.application_class(
             config=config,
-            instance_path=self.TEST_INSTANCE_PATH,)
+            instance_path=self.TEST_INSTANCE_PATH,
+        )
         return self.app
 
     def setUp(self):
@@ -204,43 +202,41 @@ class BaseTestCase(TestCase):
             with self.db.engine.connect() as conn:
                 with conn.begin():
                     conn.execute('DROP SCHEMA IF EXISTS {} CASCADE'.format(
-                        self.__pg_schema))
+                        self.__pg_schema,
+                    ))
                     conn.execute('CREATE SCHEMA {}'.format(self.__pg_schema))
-                    conn.execute('SET search_path TO {}'.format(
-                        self.__pg_schema))
+                    conn.execute(
+                        'SET search_path TO {}'.format(self.__pg_schema),
+                    )
                     conn.execute(
                         'ALTER ROLE {username} SET search_path TO {schema}'
-                        ''.format(
-                            username=username, schema=self.__pg_schema))
+                        ''.format(username=username, schema=self.__pg_schema),
+                    )
                 conn.execute('COMMIT')
 
         self.app.create_db()
 
-        for svc in self.SERVICES:
-            svc = self.app.services[svc]
-            if not svc.running:
-                svc.start()
+        self._start_services()
 
     def tearDown(self):
-        for svc in self.SERVICES:
-            svc = self.app.services[svc]
-            if svc.running:
-                svc.stop()
+        self._stop_services()
 
         self.db.session.remove()
 
         with self.db.engine.connect() as conn:
             if self.db.engine.name == 'postgresql':
                 username = self.db.engine.url.username or getpass.getuser()
-                with self.db.engine.connect() as conn:
-                    with conn.begin():
-                        conn.execute(
+                with self.db.engine.connect() as conn2:
+                    with conn2.begin():
+                        conn2.execute(
                             'ALTER ROLE {username} SET search_path TO public'
-                            ''.format(username=username))
-                        conn.execute('SET search_path TO public')
-                        conn.execute('DROP SCHEMA IF EXISTS {} CASCADE'.format(
-                            self.__pg_schema))
-                    conn.execute('COMMIT')
+                            ''.format(username=username),
+                        )
+                        conn2.execute('SET search_path TO public')
+                        conn2.execute('DROP SCHEMA IF EXISTS {} CASCADE'.format(
+                            self.__pg_schema,
+                        ))
+                    conn2.execute('COMMIT')
                 del self.__pg_schema
             else:
                 if self.db.engine.name == 'sqlite':
@@ -259,31 +255,45 @@ class BaseTestCase(TestCase):
 
         User.__password_strategy__ = _DEFAULT_PWD
 
-        # Resets babel extension
+        self._reset_babel_extension()
+
+        TestCase.tearDown(self)
+
+    def _reset_babel_extension(self):
         babel = self.app.extensions['babel']
         babel.locale_selector_func = None
         babel.timezone_selector_func = None
 
-        TestCase.tearDown(self)
+    def _start_services(self):
+        for svc in self.SERVICES:
+            svc = self.app.services[svc]
+            if not svc.running:
+                svc.start()
+
+    def _stop_services(self):
+        for svc in self.SERVICES:
+            svc = self.app.services[svc]
+            if svc.running:
+                svc.stop()
 
     def _login_tests_sanity_check(self):
-        """
-        For login methods: perform checks to avoid using login methods whereas
-        application will not perform auth or security checks.
-        """
+        """For login methods: perform checks to avoid using login methods
+        whereas application will not perform auth or security checks."""
         if self.app.config.get('NO_LOGIN'):
-            raise RuntimeError('login is useless when "NO_LOGIN" is set. '
-                               'Fix testcase.')
+            raise RuntimeError(
+                'login is useless when "NO_LOGIN" is set. '
+                'Fix testcase.',
+            )
 
         if not self.app.services['security'].running:
             raise RuntimeError(
                 'trying to use login in test but security service is '
-                'not running. Fix testcase.')
+                'not running. Fix testcase.',
+            )
 
     def login(self, user, remember=False, force=False):
-        """
-        Perform user login for `user`, so that code needing a logged-in user can
-        work.
+        """Perform user login for `user`, so that code needing a logged-in user
+        can work.
 
         This method can also be used as a context manager, so that logout is
         performed automatically::
@@ -297,7 +307,8 @@ class BaseTestCase(TestCase):
         success = login_user(user, remember, force)
         if not success:
             raise ValueError(
-                'User is not active, cannot login; or use force=True')
+                'User is not active, cannot login; or use force=True',
+            )
 
         class LoginContext(object):
 
@@ -313,24 +324,21 @@ class BaseTestCase(TestCase):
         return LoginContext(self)
 
     def logout(self):
-        """
-        Perform user logout.
+        """Perform user logout.
 
         .. seealso:: :meth:`login`
         """
         logout_user()
 
     def login_system(self):
-        """
-        Perform login with SYSTEM user. Can be used as a context manager.
+        """Perform login with SYSTEM user. Can be used as a context manager.
 
         .. seealso:: :meth:`login`, :meth:`logout`
         """
         return self.login(User.query.get(0), force=True)
 
     def client_login(self, email, password):
-        """
-        Like :meth:`login` but with a web login request. Can be used as
+        """Like :meth:`login` but with a web login request. Can be used as
         contextmanager.
 
         All subsequent request made with `self.client` will be authentifed until
@@ -340,9 +348,12 @@ class BaseTestCase(TestCase):
 
         r = self.client.post(
             url_for('login.login_post'),
-            data={'email': email,
-                  'password': password})
-        self.assertEqual(r.status_code, 302)
+            data={
+                'email': email,
+                'password': password,
+            },
+        )
+        assert r.status_code == 302
 
         class LoginContext(object):
 
@@ -358,25 +369,19 @@ class BaseTestCase(TestCase):
         return LoginContext(self)
 
     def client_logout(self):
-        """
-        Like :meth:`logout` but with a web logout
-        """
+        """Like :meth:`logout` but with a web logout."""
         self.client.post(url_for('login.logout'))
 
     @property
     def db(self):
-        """
-        Shortcut to the application db object.
-        """
+        """Shortcut to the application db object."""
         return self.app.extensions['sqlalchemy'].db
 
     def assert_302(self, response):
-        self.assert_status(response, 302)
+        assert response.status_code == 302
 
     def get(self, url, validate=True):
-        """
-        Validates HTML if asked by the config or the Unix environment.
-        """
+        """Validates HTML if asked by the config or the Unix environment."""
         response = self.client.get(url)
         if validate and response == 200:
             self.assert_valid(response)
@@ -386,10 +391,8 @@ class BaseTestCase(TestCase):
     # TODO: post(), put(), etc.
 
     def assert_valid(self, response):
-        """
-        Validate `response.data` as HTML using validator provided by
-        `config.VALIDATOR_URL`.
-        """
+        """Validate `response.data` as HTML using validator provided by
+        `config.VALIDATOR_URL`."""
         # FIXME: put this and document in TestConfig class
         validator_url = self.app.config.get('VALIDATOR_URL') \
             or os.environ.get('VALIDATOR_URL')
@@ -406,12 +409,16 @@ class BaseTestCase(TestCase):
         response = requests.post(
             validator_url + '?out=json',
             content,
-            headers={'Content-Type': content_type})
+            headers={'Content-Type': content_type},
+        )
 
         body = response.json()
 
         for message in body['messages']:
             if message['type'] == 'error':
-                detail = 'on line {0} [{1}]\n{2}'.format(
-                    message['lastLine'], message['extract'], message['message'])
+                detail = 'on line {} [{}]\n{}'.format(
+                    message['lastLine'],
+                    message['extract'],
+                    message['message'],
+                )
                 self.fail('Got a validation error for %r:\n%s' % (url, detail))
