@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -22,22 +21,19 @@ __all__ = ('Action', 'ModalActionMixin', 'actions')
 
 
 class Status(UniqueName):
-    """
-    Action UI status names
-    """
+    """Action UI status names."""
 
 
 #: default action status: show in UID, usable, not marked "current"
-ENABLED = Status(u'enabled')
+ENABLED = Status('enabled')
 #: action is "active" or "current". For example the current navigation item.
-ACTIVE = Status(u'active')
+ACTIVE = Status('active')
 #: action should be shown in a disabled state
-DISABLED = Status(u'disabled')
+DISABLED = Status('disabled')
 
 
 def getset(f):
-    """
-    Shortcut for a custom getter/ standard setter.
+    """Shortcut for a custom getter/ standard setter.
 
     Usage::
 
@@ -61,8 +57,7 @@ def getset(f):
 
 @python_2_unicode_compatible
 class Icon(object):
-    """Base abstract class for icons.
-    """
+    """Base abstract class for icons."""
 
     def __html__(self):
         raise NotImplementedError
@@ -72,8 +67,7 @@ class Icon(object):
 
 
 class NamedIconBase(Icon):
-    """Renders markup for named icons set.
-    """
+    """Renders markup for named icons set."""
     template = None
 
     def __init__(self, name=''):
@@ -84,26 +78,24 @@ class NamedIconBase(Icon):
 
 
 class Glyphicon(NamedIconBase):
-    """Renders markup for bootstrap's glyphicons.
-    """
-    template = Template(u'<i class="glyphicon glyphicon-{{ name }}"></i>')
+    """Renders markup for bootstrap's glyphicons."""
+    template = Template('<i class="glyphicon glyphicon-{{ name }}"></i>')
 
 
 class FAIcon(NamedIconBase):
-    """Renders markup for FontAwesome icons.
-    """
-    template = Template(u'<i class="fa fa-{{ name }}"></i>')
+    """Renders markup for FontAwesome icons."""
+    template = Template('<i class="fa fa-{{ name }}"></i>')
 
 
 class FAIconStacked(NamedIconBase):
-    """Stacked FA icons.
-    """
+    """Stacked FA icons."""
     template = Template(
-        u'<span class="fa-stack {%- if stack_class %} {{ stack_class }}'
-        u'{%- endif %}">\n'
-        u'  <i class="fa fa-{{ name }}"></i>\n'
-        u'  <i class="fa fa-{{ second }}"></i>\n'
-        u'</span>')
+        '<span class="fa-stack {%- if stack_class %} {{ stack_class }}'
+        '{%- endif %}">\n'
+        '  <i class="fa fa-{{ name }}"></i>\n'
+        '  <i class="fa fa-{{ second }}"></i>\n'
+        '</span>',
+    )
 
     def __init__(self, name, second, stack=''):
         """
@@ -114,10 +106,10 @@ class FAIconStacked(NamedIconBase):
 
         @param stack: additional class on top-level element, i.e 'fa-lg'.
         """
-        if u'fa-stack-' not in name:
-            name += u' fa-stack-1x'
-        if u'fa-stack-' not in second:
-            second += u' fa-stack-1x'
+        if 'fa-stack-' not in name:
+            name += ' fa-stack-1x'
+        if 'fa-stack-' not in second:
+            second += ' fa-stack-1x'
 
         super(FAIconStacked, self).__init__(name)
         self.second = second
@@ -125,22 +117,29 @@ class FAIconStacked(NamedIconBase):
 
     def __html__(self):
         return self.template.render(
-            name=self.name, second=self.second, stack_class=self.stack)
+            name=self.name,
+            second=self.second,
+            stack_class=self.stack,
+        )
 
 
 class DynamicIcon(Icon):
-    template = Template(u'<img {%- if css %} class="{{ css }}"{% endif %} '
-                        u'src="{{ url }}" '
-                        u'width="{{ width }}" height="{{ height }}" />')
+    template = Template(
+        '<img {%- if css %} class="{{ css }}"{% endif %} '
+        'src="{{ url }}" '
+        'width="{{ width }}" height="{{ height }}" />',
+    )
 
-    def __init__(self,
-                 endpoint=None,
-                 width=12,
-                 height=12,
-                 css='',
-                 size=None,
-                 url_args=None,
-                 **fixed_url_args):
+    def __init__(
+        self,
+        endpoint=None,
+        width=12,
+        height=12,
+        css='',
+        size=None,
+        url_args=None,
+        **fixed_url_args
+    ):
         self.endpoint = endpoint
         self.css = css
         self.fixed_url_args = dict()
@@ -171,25 +170,34 @@ class DynamicIcon(Icon):
             url=url_for(endpoint, **url_args),
             width=self.width,
             height=self.height,
-            css=self.css)
+            css=self.css,
+        )
 
 
 class StaticIcon(DynamicIcon):
-    """
-    Renders markup for icon located in static folder served by `endpoint`.
+    """Renders markup for icon located in static folder served by `endpoint`.
 
     Default endpoint is application static folder.
     """
 
-    def __init__(self,
-                 filename,
-                 endpoint='static',
-                 width=12,
-                 height=12,
-                 css='',
-                 size=None):
+    def __init__(
+            self,
+            filename,
+            endpoint='static',
+            width=12,
+            height=12,
+            css='',
+            size=None,
+    ):
         DynamicIcon.__init__(
-            self, endpoint, width, height, css, size, filename=filename)
+            self,
+            endpoint,
+            width,
+            height,
+            css,
+            size,
+            filename=filename,
+        )
 
 
 @python_2_unicode_compatible
@@ -204,9 +212,9 @@ class Endpoint(object):
     def get_kwargs(self):
         """Hook for subclasses.
 
-        The key and values in the returned dictionnary can be safely changed
-        without side effects on self.kwargs (provided you don't alter
-        mutable values, like calling list.pop()).
+        The key and values in the returned dictionnary can be safely
+        changed without side effects on self.kwargs (provided you don't
+        alter mutable values, like calling list.pop()).
         """
         return self.kwargs.copy()
 
@@ -218,12 +226,12 @@ class Endpoint(object):
             cls=self.__class__.__name__,
             name=self.name,
             args=self.args,
-            kwargs=self.kwargs,)
+            kwargs=self.kwargs,
+        )
 
 
 class Action(object):
-    """Action interface.
-    """
+    """Action interface."""
     Endpoint = Endpoint
     category = None
     name = None
@@ -231,7 +239,7 @@ class Action(object):
     description = None
     icon = None
     _url = None
-    CSS_CLASS = u'action action-{category} action-{category}-{name}'
+    CSS_CLASS = 'action action-{category} action-{category}-{name}'
 
     #: A :class:`Endpoint` instance, a string for a simple endpoint, a tuple
     #: ``(endpoint_name, kwargs)``  or a callable which accept a : context dict
@@ -242,25 +250,29 @@ class Action(object):
     #: which accepts a context dict as parameter. See :meth:`available`.
     condition = None
 
-    template_string = (u'<a class="{{ action.css_class }}" href="{{ url }}">'
-                       u'{%- if action.icon %}{{ action.icon }} {% endif %}'
-                       u'{{ action.title }}'
-                       u'</a>')
+    template_string = (
+        '<a class="{{ action.css_class }}" href="{{ url }}">'
+        '{%- if action.icon %}{{ action.icon }} {% endif %}'
+        '{{ action.title }}'
+        '</a>'
+    )
 
-    def __init__(self,
-                 category,
-                 name,
-                 title=None,
-                 description=None,
-                 icon=None,
-                 url=None,
-                 endpoint=None,
-                 condition=None,
-                 status=None,
-                 template=None,
-                 template_string=None,
-                 button=None,
-                 css=None):
+    def __init__(
+            self,
+            category,
+            name,
+            title=None,
+            description=None,
+            icon=None,
+            url=None,
+            endpoint=None,
+            condition=None,
+            status=None,
+            template=None,
+            template_string=None,
+            button=None,
+            css=None,
+    ):
         """
         :param button: if not `None`, a valid `btn` class (i.e `default`,
         `primary`...)
@@ -276,9 +288,9 @@ class Action(object):
         self.name = name
 
         if button is not None:
-            self.CSS_CLASS += u' btn btn-{}'.format(button)
+            self.CSS_CLASS += ' btn btn-{}'.format(button)
         if css is not None:
-            self.CSS_CLASS = self.CSS_CLASS + u' ' + css
+            self.CSS_CLASS = self.CSS_CLASS + ' ' + css
         self._build_css_class()
 
         self.title = title
@@ -333,7 +345,10 @@ class Action(object):
 
     def _build_css_class(self):
         css_cat = self.CSS_CLASS.format(
-            action=self, category=self.category, name=self.name)
+            action=self,
+            category=self.category,
+            name=self.name,
+        )
         css_cat = re.sub(r'[^ _a-zA-Z0-9-]', '-', css_cat)
         self.css_class = css_cat
 
@@ -369,8 +384,9 @@ class Action(object):
                 assert isinstance(kwargs, dict)
                 endpoint = self.Endpoint(endpoint, **kwargs)
             else:
-                raise ValueError('Invalid endpoint specifier: "%s"' %
-                                 repr(endpoint))
+                raise ValueError(
+                    'Invalid endpoint specifier: "%s"' % repr(endpoint),
+                )
 
         return endpoint
 
@@ -389,17 +405,17 @@ class Action(object):
             return False
         try:
             return self.pre_condition(context) and self._check_condition(
-                context)
-        except:
+                context,
+            )
+        except BaseException:
             return False
 
     def pre_condition(self, context):
-        """
-        Called by :meth:`.available` before checking condition.
+        """Called by :meth:`.available` before checking condition.
 
-        Subclasses may override it to ease creating actions with repetitive
-        check (for example: actions that apply on a given content type
-        only).
+        Subclasses may override it to ease creating actions with
+        repetitive check (for example: actions that apply on a given
+        content type only).
         """
         return True
 
@@ -444,44 +460,48 @@ class Action(object):
 
 class ModalActionMixin(object):
     template_string = (
-        u'<a class="{{ action.css_class }}" href="{{ url }}" data-toggle="modal">'
-        u'{%- if action.icon %}{{ action.icon}} {% endif %}'
-        u'{{ action.title }}'
-        u'</a>')
+        '<a class="{{ action.css_class }}" href="{{ url }}" data-toggle="modal">'
+        '{%- if action.icon %}{{ action.icon}} {% endif %}'
+        '{{ action.title }}'
+        '</a>'
+    )
 
 
 class ButtonAction(Action):
     template_string = (
-        u'<button type="submit" '
-        u'class="btn btn-{{ action.btn_class }} {{ action.css_class}}" '
-        u'name="{{ action.submit_name }}" '
-        u'value="{{ action.name }}">'
-        u'{%- if action.icon %}{{ action.icon }} {% endif %}'
-        u'{{ action.title }}</button>')
+        '<button type="submit" '
+        'class="btn btn-{{ action.btn_class }} {{ action.css_class}}" '
+        'name="{{ action.submit_name }}" '
+        'value="{{ action.name }}">'
+        '{%- if action.icon %}{{ action.icon }} {% endif %}'
+        '{{ action.title }}</button>'
+    )
 
     btn_class = 'default'
 
-    def __init__(self,
-                 category,
-                 name,
-                 submit_name="__action",
-                 btn_class='default',
-                 *args,
-                 **kwargs):
+    def __init__(
+        self,
+        category,
+        name,
+        submit_name="__action",
+        btn_class='default',
+        *args,
+        **kwargs
+    ):
         Action.__init__(self, category, name, *args, **kwargs)
         self.submit_name = submit_name
         self.btn_class = btn_class
 
 
 class ActionGroup(Action):
-    """A group of single actions
-    """
+    """A group of single actions."""
     template_string = (
-        u'<div class="btn-group" role="group" aria-label="{{ action.name}}">'
-        u'{%- for entry in action_items %}'
-        u'{{ entry.render() }}'
-        u'{%- endfor %}'
-        u'</div>')
+        '<div class="btn-group" role="group" aria-label="{{ action.name}}">'
+        '{%- for entry in action_items %}'
+        '{{ entry.render() }}'
+        '{%- endfor %}'
+        '</div>'
+    )
 
     def __init__(self, category, name, items=(), *args, **kwargs):
         super(ActionGroup, self).__init__(category, name, *args, **kwargs)
@@ -494,9 +514,8 @@ class ActionGroup(Action):
 
 
 class ActionDropDown(ActionGroup):
-    """Renders as a button dropdown
-    """
-    template_string = u'''
+    """Renders as a button dropdown."""
+    template_string = '''
     <div class="btn-group">
         <button type="button" class="{{ action.css_class }} dropdown-toggle"
                 data-toggle="dropdown" aria-expanded="false">
@@ -539,7 +558,7 @@ class ActionRegistry(object):
     def init_app(self, app):
         if self.__EXTENSION_NAME in app.extensions:
             log.warning(
-                'ActionRegistry.init_app: actions already enabled on this application'
+                'ActionRegistry.init_app: actions already enabled on this application',
             )
             return
 
@@ -551,21 +570,22 @@ class ActionRegistry(object):
             return dict(actions=self)
 
     def installed(self, app=None):
-        """Return `True` if the registry has been installed in current applications
-        """
+        """Return `True` if the registry has been installed in current
+        applications."""
         if app is None:
             app = current_app
         return self.__EXTENSION_NAME in app.extensions
 
     def register(self, *actions):
-        """ Register `actions` in the current application. All `actions` must be an
-        instance of :class:`.Action` or one of its subclasses.
+        """Register `actions` in the current application. All `actions` must be
+        an instance of :class:`.Action` or one of its subclasses.
 
-        If `overwrite` is `True`, then it is allowed to overwrite an existing
-        action with same name and category; else `ValueError` is raised.
+        If `overwrite` is `True`, then it is allowed to overwrite an
+        existing action with same name and category; else `ValueError`
+        is raised.
         """
         assert self.installed(), "Actions not enabled on this application"
-        assert all(map(lambda a: isinstance(a, Action), actions))
+        assert all(isinstance(a, Action) for a in actions)
 
         for action in actions:
             cat = action.category
@@ -573,7 +593,7 @@ class ActionRegistry(object):
             reg.append(action)
 
     def actions(self, context=None):
-        """ Return a mapping of category => actions list.
+        """Return a mapping of category => actions list.
 
         Actions are filtered according to :meth:`.Action.available`.
 
@@ -590,7 +610,7 @@ class ActionRegistry(object):
         return result
 
     def for_category(self, category, context=None):
-        """ Returns actions list for this category in current application.
+        """Returns actions list for this category in current application.
 
         Actions are filtered according to :meth:`.Action.available`.
 
@@ -614,8 +634,9 @@ class ActionRegistry(object):
 
     @property
     def context(self):
-        """ Return action context (dict type). Applications can modify it to suit
-        their needs.
+        """Return action context (dict type).
+
+        Applications can modify it to suit their needs.
         """
         return g.action_context
 
