@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -9,11 +8,11 @@ from itertools import chain
 
 import pytz
 import sqlalchemy as sa
+import sqlalchemy.orm
 from flask import get_template_attribute, render_template, \
     render_template_string, request
 from flask_babel import format_date, get_locale
 from markupsafe import Markup
-from sqlalchemy.orm.attributes import NO_VALUE
 from werkzeug.exceptions import InternalServerError
 from werkzeug.routing import BuildError
 
@@ -39,12 +38,10 @@ def format_date_for_input(date):
 
 
 class JSONUserSearch(JSONView):
-    """
-    Search users by fullname
-    """
+    """Search users by fullname."""
 
     def data(self, q, *args, **kwargs):
-        q = q.replace(u'%', u' ').strip().lower()
+        q = q.replace('%', ' ').strip().lower()
 
         if not q or len(q) < 2:
             raise InternalServerError()
@@ -52,31 +49,43 @@ class JSONUserSearch(JSONView):
         query = User.query
         lower = sa.sql.func.lower
         filters = []
-        for part in q.split(u' '):
+        for part in q.split(' '):
             filters.append(
                 sa.sql.or_(
                     lower(User.first_name).like(part + "%"),
-                    lower(User.last_name).like(part + "%")))
+                    lower(User.last_name).like(part + "%"),
+                ),
+            )
 
         filters = sa.sql.and_(*filters) if len(filters) > 1 else filters[0]
 
-        if u'@' in q:
+        if '@' in q:
             # FIXME: where does this 'part' variable come from ?
             filters = sa.sql.or_(
-                lower(User.email).like('%' + part + '%'), filters)
+                lower(User.email).like('%' + part + '%'),
+                filters,
+            )
 
         query = query \
             .filter(filters) \
             .order_by(User.last_name, User.first_name)
 
-        result = {
-            'results': [{
+        values = query.values(
+            User.id,
+            User.first_name,
+            User.last_name,
+            User.email,
+        )
+        results = [
+            {
                 'id': obj.id,
-                'text':
-                u'{} {} ({})'.format(obj.first_name, obj.last_name, obj.email)
-            }
-                        for obj in query.values(User.id, User.first_name,
-                                                User.last_name, User.email)]
+                'text': '{} {} ({})'
+                .format(obj.first_name, obj.last_name, obj.email),
+            } for obj in values
+        ]
+
+        result = {
+            'results': results,
         }
         return result
 
@@ -95,7 +104,9 @@ class AuditPanel(AdminPanel):
 
     def install_additional_rules(self, add_url_rule):
         add_url_rule(
-            '/search_users', view_func=JSONUserSearch.as_view('search_users'))
+            '/search_users',
+            view_func=JSONUserSearch.as_view('search_users'),
+        )
 
     # noinspection PyComparisonWithNone
     def get(self):
@@ -120,18 +131,22 @@ class AuditPanel(AdminPanel):
 
         # filter by types
         all_classes = sorted(all_entity_classes(), key=lambda c: c.__name__)
-        all_types = set(e.entity_type for e in all_classes)
+        all_types = {e.entity_type for e in all_classes}
         filter_types = set(request.args.getlist('types')) & all_types
         if filter_types:
             if len(filter_types) == 1:
                 t = list(filter_types)[0]
                 audit_expr = AuditEntry.entity_type == t
-                sec_expr = sa.sql.or_(SecurityAudit.object == None,
-                                      Entity._entity_type == t)
+                sec_expr = sa.sql.or_(
+                    SecurityAudit.object == None,
+                    Entity._entity_type == t,
+                )
             else:
                 audit_expr = AuditEntry.entity_type.in_(filter_types)
-                sec_expr = sa.sql.or_(SecurityAudit.object == None,
-                                      Entity._entity_type.in_(filter_types))
+                sec_expr = sa.sql.or_(
+                    SecurityAudit.object == None,
+                    Entity._entity_type.in_(filter_types),
+                )
 
             base_audit_q = base_audit_q.filter(audit_expr)
             base_security_q = base_security_q \
@@ -150,11 +165,11 @@ class AuditPanel(AdminPanel):
                 .order_by(model.happened_at.desc())
 
         if after:
-            after = datetime.strptime(after, u'%Y-%m-%dT%H:%M:%S.%f')
+            after = datetime.strptime(after, '%Y-%m-%dT%H:%M:%S.%f')
             audit_q = after_query(base_audit_q, AuditEntry, after)
             security_q = after_query(base_security_q, SecurityAudit, after)
         else:
-            before = (datetime.strptime(before, u'%Y-%m-%dT%H:%M:%S.%f')
+            before = (datetime.strptime(before, '%Y-%m-%dT%H:%M:%S.%f')
                       if before else datetime.utcnow())
             audit_q = before_query(base_audit_q, AuditEntry, before)
             security_q = before_query(base_security_q, SecurityAudit, before)
@@ -168,13 +183,16 @@ class AuditPanel(AdminPanel):
             .limit(LIMIT) \
             .all()
         # audit_entries = []
-        all_entries = list(
-            chain(
-                #
-                (AuditEntryPresenter(e) for e in audit_entries),
-                #
-                (SecurityEntryPresenter(e) for e in security_entries)))
-        all_entries.sort()
+        all_entries = sorted(
+            list(
+                chain(
+                    #
+                    (AuditEntryPresenter(e) for e in audit_entries),
+                    #
+                    (SecurityEntryPresenter(e) for e in security_entries),
+                ),
+            ),
+        )
 
         if after:
             all_entries = all_entries[:LIMIT]
@@ -197,35 +215,41 @@ class AuditPanel(AdminPanel):
                 entries.append((e_date.date(), day_entries))
             day_entries.append(e)
 
-        top_date = u''
-        lowest_date = u''
+        top_date = ''
+        lowest_date = ''
 
         if entries:
             # top_date and lowest_date are converted to naive datetime (from UTC), so
             # that isoformat does not include TZ shift (else we should fix strptime
             # above)
             top_date = entries[0][1][0].date.astimezone(pytz.utc).replace(
-                tzinfo=None)
+                tzinfo=None,
+            )
             lowest_date = entries[-1][1][-1].date \
                 .astimezone(pytz.utc) \
                 .replace(tzinfo=None)
 
             after_queries = (
                 after_query(base_audit_q, AuditEntry, top_date),
-                after_query(base_security_q, SecurityAudit, top_date),)
+                after_query(base_security_q, SecurityAudit, top_date),
+            )
 
             before_queries = (
                 before_query(base_audit_q, AuditEntry, lowest_date),
-                before_query(base_security_q, SecurityAudit,
-                             lowest_date).limit(1),)
+                before_query(
+                    base_security_q,
+                    SecurityAudit,
+                    lowest_date,
+                ).limit(1),
+            )
 
             if not any(q.limit(1).first() is not None for q in after_queries):
-                top_date = u''
+                top_date = ''
             else:
                 top_date = top_date.isoformat()
 
             if not any(q.first() is not None for q in before_queries):
-                lowest_date = u''
+                lowest_date = ''
             else:
                 lowest_date = lowest_date.isoformat()
 
@@ -240,16 +264,17 @@ class AuditPanel(AdminPanel):
         if filter_types:
             url_params['types'] = list(filter_types)[0]
 
-        return render_template(
-            "admin/audit.html",
-            entries=entries,
-            filter_user=filter_user,
-            all_classes=[(c.__name__, c.entity_type) for c in all_classes],
-            filter_types=filter_types,
-            url_params=url_params,
-            current_date=current_date,
-            top_date=top_date,
-            lowest_date=lowest_date)
+        ctx = {
+            'entries': entries,
+            'filter_user': filter_user,
+            'all_classes': [(c.__name__, c.entity_type) for c in all_classes],
+            'filter_types': filter_types,
+            'url_params': url_params,
+            'current_date': current_date,
+            'top_date': top_date,
+            'lowest_date': lowest_date,
+        }
+        return render_template("admin/audit.html", **ctx)
 
 
 #
@@ -257,10 +282,14 @@ class AuditPanel(AdminPanel):
 #
 class BaseEntryPresenter(object):
 
-    _USER_FMT = (u'<a href="{{ url_for("social.user", user_id=user.id) }}">'
-                 '{{ user.name }}</a>')
-    _GROUP_FMT = (u'<a href="{{ url_for("social.group_home", group_id=group.id)'
-                  ' }}">{{ group.name }}</a>')
+    _USER_FMT = (
+        '<a href="{{ url_for("social.user", user_id=user.id) }}">'
+        '{{ user.name }}</a>'
+    )
+    _GROUP_FMT = (
+        '<a href="{{ url_for("social.group_home", group_id=group.id)'
+        ' }}">{{ group.name }}</a>'
+    )
 
     def __init__(self, user, date):
         self.user = user
@@ -271,10 +300,16 @@ class BaseEntryPresenter(object):
         a, b = self.date, other.date
         return (a > b) - (a < b)
 
+    def __lt__(self, other):
+        return self.date < other.date
+
     def __repr__(self):
-        return '{}({}, {} @ {})'.format(self.__class__.__name__,
-                                        repr(self.user),
-                                        repr(self.date), id(self))
+        return '{}({}, {} @ {})'.format(
+            self.__class__.__name__,
+            repr(self.user),
+            repr(self.date),
+            id(self),
+        )
 
     @staticmethod
     def model(model_name):
@@ -288,9 +323,16 @@ class AuditEntryPresenter(BaseEntryPresenter):
 
     def __init__(self, entry):
         assert isinstance(entry, AuditEntry)
-        super(AuditEntryPresenter, self).__init__(entry.user, entry.happened_at)
+        super(
+            AuditEntryPresenter,
+            self).__init__(
+            entry.user,
+            entry.happened_at)
         self.entry = entry
 
+    # def __lt__(self, other):
+    #     return self.entry < other.entry
+
     def render(self):
         render = render_template_string
         e = self.entry
@@ -306,16 +348,18 @@ class AuditEntryPresenter(BaseEntryPresenter):
             else:
                 entity_html = Markup(
                     render(
-                        u'<a href="{{ url }}">{{ entity.path or entity.name }}</a>',
+                        '<a href="{{ url }}">{{ entity.path or entity.name }}</a>',
                         url=entity_url,
-                        entity=e.entity))
+                        entity=e.entity,
+                    ),
+                )
 
         if e.type == 0:
-            msg = _(u'{user} created {entity_type} {entity_id} "{entity}"')
+            msg = _('{user} created {entity_type} {entity_id} "{entity}"')
         elif e.related or e.op == 1:
-            msg = _(u'{user} made changes on {entity_type} {entity_id} "{entity}"')
+            msg = _('{user} made changes on {entity_type} {entity_id} "{entity}"')
         elif e.op == 2:
-            msg = _(u'{user} has deleted {entity_type}: {entity_id} "{entity}"')
+            msg = _('{user} has deleted {entity_type}: {entity_id} "{entity}"')
         else:
             raise Exception("Bad entry type: {}".format(e.type))
 
@@ -324,7 +368,9 @@ class AuditEntryPresenter(BaseEntryPresenter):
                 user=user,
                 entity=entity_html,
                 entity_type=e.entity_type.rsplit('.', 1)[-1],
-                entity_id=e.entity_id,))
+                entity_id=e.entity_id,
+            ),
+        )
         tmpl = get_template_attribute('admin/_macros.html', 'm_audit_entry')
         return tmpl(self)
 
@@ -333,8 +379,8 @@ class SecurityEntryPresenter(BaseEntryPresenter):
 
     def __init__(self, entry):
         assert isinstance(entry, SecurityAudit)
-        super(SecurityEntryPresenter, self).__init__(entry.manager,
-                                                     entry.happened_at)
+        super(SecurityEntryPresenter, self) \
+            .__init__(entry.manager, entry.happened_at)
         self.entry = entry
 
     def render(self):
@@ -342,21 +388,22 @@ class SecurityEntryPresenter(BaseEntryPresenter):
         e = self.entry
 
         manager = render(
-            u'<img class="avatar" '
-            u'src="{{ user_photo_url(user=e.manager, size=16) }}" alt="" />'
-            u'<a href="'
+            '<img class="avatar" '
+            'src="{{ user_photo_url(user=e.manager, size=16) }}" alt="" />'
+            '<a href="'
             '{{ url_for("social.user", user_id=e.manager.id) }}">'
-            u'{{ e.manager.name }}</a>',
-            e=e)
+            '{{ e.manager.name }}</a>',
+            e=e,
+        )
 
         if self.entry.user:
             principal = render(self._USER_FMT, user=self.entry.user)
         elif self.entry.group:
             principal = render(self._GROUP_FMT, group=self.entry.group)
         else:
-            principal = u''
+            principal = ''
 
-        entity = u''
+        entity = ''
         if e.object_id:
             entity_url = None
             entity_name = e.object_name
@@ -365,28 +412,33 @@ class SecurityEntryPresenter(BaseEntryPresenter):
                 entity_url = url_for(e.object)
 
             entity = render(
-                u'{%- if url %}<a href="{{ url }}">{%- endif %}'
-                u'{{ name }}{%- if url %}</a>{%- endif %}',
+                '{%- if url %}<a href="{{ url }}">{%- endif %}'
+                '{{ name }}{%- if url %}</a>{%- endif %}',
                 url=entity_url,
-                name=entity_name)
+                name=entity_name,
+            )
 
             if e.op == e.SET_INHERIT:
-                msg = _(u'{manager} has activated inheritance on {entity}')
+                msg = _('{manager} has activated inheritance on {entity}')
             elif e.op == e.UNSET_INHERIT:
-                msg = _(u'{manager} has deactivated inheritance on {entity}')
+                msg = _('{manager} has deactivated inheritance on {entity}')
             elif e.op == e.GRANT:
-                msg = _(u'{manager} has given role "{role}" to {principal} '
-                        'on {entity}')
+                msg = _(
+                    '{manager} has given role "{role}" to {principal} '
+                    'on {entity}',
+                )
             elif e.op == e.REVOKE:
-                msg = _(u'{manager} has revoked role "{role}" from '
-                        '{principal} on {entity}')
+                msg = _(
+                    '{manager} has revoked role "{role}" from '
+                    '{principal} on {entity}',
+                )
             else:
                 raise Exception("Invalid entity op: {}".format(e.op))
         else:
             if e.op == e.GRANT:
-                msg = _(u'{manager} has given role "{role}" to {principal}')
+                msg = _('{manager} has given role "{role}" to {principal}')
             elif e.op == e.REVOKE:
-                msg = _(u'{manager} has revoked role "{role}" from {principal}')
+                msg = _('{manager} has revoked role "{role}" from {principal}')
             else:
                 raise Exception("Invalid entity op: {}".format(e.op))
 
@@ -395,6 +447,8 @@ class SecurityEntryPresenter(BaseEntryPresenter):
                 manager=manager,
                 principal=principal,
                 role=e.role,
-                entity=entity))
+                entity=entity,
+            ),
+        )
         tmpl = get_template_attribute('admin/_macros.html', 'm_security_entry')
         return tmpl(self)
