@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -43,19 +42,29 @@ class DashboardPanel(AdminPanel):
         # let's format the data into NVD3 datastructures
         connections = [
             {'key': _('Daily'), 'color': '#7777ff', 'values': daily},
-            {'key': _('Weekly'), 'color': '#2ca02c', 'values': weekly, 'disabled': True},
-            {'key': _('Monthly'), 'color': '#ff7f0e', 'values': monthly, 'disabled': True},
+            {
+                'key': _('Weekly'), 'color': '#2ca02c',
+                'values': weekly, 'disabled': True,
+            },
+            {
+                'key': _('Monthly'), 'color': '#ff7f0e',
+                'values': monthly, 'disabled': True,
+            },
         ]
         new_logins = [
-            {'key': _('New'), 'color': '#ff7f0e', "bar": True, 'values': new_logins},
-            {'key': _('Total'), 'color': '#2ca02c', 'values': total_users}
+            {
+                'key': _('New'), 'color': '#ff7f0e',
+                "bar": True, 'values': new_logins,
+            },
+            {'key': _('Total'), 'color': '#2ca02c', 'values': total_users},
         ]
 
         return render_template(
             "admin/dashboard.html",
             stats=stats,
             connections=connections,
-            new_logins=new_logins)
+            new_logins=new_logins,
+        )
 
 
 def stats_since(dt):
@@ -63,8 +72,10 @@ def stats_since(dt):
     after_date = datetime.utcnow() - dt
     session = current_app.db.session()
     counts_per_type = session \
-        .query(AuditEntry.entity_type.label('type'),
-               sa.func.count(AuditEntry.entity_type).label('count')) \
+        .query(
+            AuditEntry.entity_type.label('type'),
+            sa.func.count(AuditEntry.entity_type).label('count'),
+        ) \
         .group_by(AuditEntry.entity_type) \
         .filter(AuditEntry.happened_at > after_date) \
         .filter(AuditEntry.type == CREATION) \
@@ -79,8 +90,8 @@ def stats_since(dt):
         elif entity_class == 'Message':
             new_messages = count
 
-    active_users = session.query(sa.func.count(User.id))\
-                          .filter(User.last_active > after_date).scalar()
+    active_users = session.query(sa.func.count(User.id)) \
+        .filter(User.last_active > after_date).scalar()
 
     return {
         'new_members': new_members,
@@ -98,8 +109,7 @@ def unix_time_millis(dt):
 
 
 def newlogins(sessions):
-    """
-    Brand new logins each day, and total of users each day.
+    """Brand new logins each day, and total of users each day.
 
     :return: data, total
       2 lists of dictionaries of the following format [{'x':epoch, 'y': value},]
@@ -128,9 +138,9 @@ def newlogins(sessions):
     for date in sorted(dates.keys()):
         # print u"{} : {}".format(date, len(dates[date]))
         date_epoch = unix_time_millis(datetime.strptime(date, "%Y/%m/%d"))
-        data.append({u'x': date_epoch, u'y': len(dates[date])})
+        data.append({'x': date_epoch, 'y': len(dates[date])})
         previous += len(dates[date])
-        total.append({u'x': date_epoch, u'y': previous})
+        total.append({'x': date_epoch, 'y': previous})
 
     return data, total
 
