@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -12,6 +11,7 @@ from flask_babel import gettext as _
 from flask_babel import lazy_gettext as _l
 from jinja2 import Template
 
+from abilian.services import get_service
 from abilian.web import csrf
 
 from ..panel import AdminPanel
@@ -19,8 +19,10 @@ from ..panel import AdminPanel
 
 class Key(object):
 
-    template = Template(u'<input type="text" class="form-control" '
-                        u'name="{{ key.id }}" value="{{ config[key.id] }}" />')
+    template = Template(
+        '<input type="text" class="form-control" '
+        'name="{{ key.id }}" value="{{ config[key.id] }}" />',
+    )
 
     def __init__(self, id, type_, label=None, description=None):
         self.id = id
@@ -30,7 +32,10 @@ class Key(object):
 
     def __html__(self):
         return render_template(
-            self.template, key=self, config=current_app.config)
+            self.template,
+            key=self,
+            config=current_app.config,
+        )
 
     def value_from_request(self):
         return request.form.get(self.id).strip()
@@ -45,9 +50,12 @@ class SessionLifeTimeKey(Key):
             self,
             'PERMANENT_SESSION_LIFETIME',
             'timedelta',
-            label=_l(u'Session lifetime'),
-            description=_l(u'Session expiration time after last visit. '
-                           u'When session is expired user must login again.'))
+            label=_l('Session lifetime'),
+            description=_l(
+                'Session expiration time after last visit. '
+                'When session is expired user must login again.',
+            ),
+        )
 
     def value_from_request(self):
         form = request.form
@@ -57,9 +65,13 @@ class SessionLifeTimeKey(Key):
 
         if (days + hours) == 0 and minutes < 10:
             # avoid dummy sessions durations: minimum is 10 minutes
-            flash(_(u'Minimum session lifetime is 10 minutes. '
-                    u'Value has been adjusted.'),
-                  'warning',)
+            flash(
+                _(
+                    'Minimum session lifetime is 10 minutes. '
+                    'Value has been adjusted.',
+                ),
+                'warning',
+            )
             minutes = 10
 
         return timedelta(days=days, hours=hours, minutes=minutes)
@@ -88,25 +100,26 @@ class SessionLifeTimeKey(Key):
         return self._get_current('minutes')
 
 
-#FIXME: the settings panel should offer hooks for external modules and thus
-#provide unified interface for site settings / customization
+# FIXME: the settings panel should offer hooks for external modules and thus
+# provide unified interface for site settings / customization
 
 
 class SettingsPanel(AdminPanel):
     id = 'settings'
-    label = _l(u'Settings')
+    label = _l('Settings')
     icon = 'cog'
 
     # FIXME: this is very basic, and we support only "string" at this time. A form
     # shoud be used. Really.
     _keys = (
-        Key('SITE_NAME', 'string', _l(u'Site name')),
-        Key('MAIL_SENDER', 'string', _l(u'Mail sender')),
-        SessionLifeTimeKey(),)
+        Key('SITE_NAME', 'string', _l('Site name')),
+        Key('MAIL_SENDER', 'string', _l('Mail sender')),
+        SessionLifeTimeKey(),
+    )
 
     @property
     def settings(self):
-        return current_app.services.get('settings').namespace('config')
+        return get_service('settings').namespace('config')
 
     def get(self):
         return render_template('admin/settings.html', keys=self._keys)
@@ -115,7 +128,7 @@ class SettingsPanel(AdminPanel):
     def post(self):
         action = request.form.get("action")
 
-        if action == u'save':
+        if action == 'save':
             settings = self.settings
             for key in self._keys:
                 value = key.value_from_request()
@@ -127,6 +140,6 @@ class SettingsPanel(AdminPanel):
             # full reload of app stack (web workers + celery workers) has to be done
             # manually.
             current_app.config.update(settings.as_dict())
-            flash(_(u'Changes saved.'))
+            flash(_('Changes saved.'))
 
         return redirect(url_for('.settings'))
