@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -33,8 +32,9 @@ class SysinfoPanel(AdminPanel):
                 name=dist.project_name,
                 key=dist.key,
                 version=dist.version
-                if dist.has_version() else u'Unknown version',
-                vcs=None,)
+                if dist.has_version() else 'Unknown version',
+                vcs=None,
+            )
 
             location = text_type(Path(dist.location).absolute())
             vcs_name = vcs.get_backend_name(location)
@@ -49,17 +49,21 @@ class SysinfoPanel(AdminPanel):
                     revision = vc.get_revision(location)
                 except pip.exceptions.InstallationError:
                     revision = 'None'
-                package['vcs'] = dict(name=vcs_name, url=url, revision=revision)
+                package['vcs'] = dict(
+                    name=vcs_name, url=url, revision=revision)
 
             packages.append(package)
             packages.sort(key=lambda d: d.get('key'))
 
-        config_values = [(k, repr(v))
-                         for k, v in sorted(current_app.config.items())]
+        config_values = [
+            (k, repr(v))
+            for k, v in sorted(current_app.config.items())
+        ]
 
         return render_template(
             "admin/sysinfo.html",
             python_version=python_version,
             packages=packages,
             uname=uname,
-            config_values=config_values)
+            config_values=config_values,
+        )
