@@ -1,13 +1,13 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 from cgi import escape
 
 import sqlalchemy as sa
-from flask import current_app, render_template_string, request
+import sqlalchemy.orm
+from flask import render_template_string, request
 from flask_babel import format_datetime
 from flask_login import current_user
 from sqlalchemy.sql.expression import asc, desc, func, nullslast, or_
@@ -15,6 +15,7 @@ from werkzeug.datastructures import MultiDict
 
 from abilian.core.models.subjects import User, gen_random_password
 from abilian.i18n import _
+from abilian.services import get_service
 from abilian.services.security.models import Admin, Role
 from abilian.web.nav import BreadcrumbItem
 from abilian.web.util import url_for
@@ -26,11 +27,10 @@ from .forms import UserAdminForm, UserCreateForm
 
 
 class JsonUsersList(base.JSONView):
-    """JSON user list for datatable.
-    """
+    """JSON user list for datatable."""
 
     def data(self, *args, **kw):
-        security = current_app.services['security']
+        security = get_service('security')
         length = int(kw.get("iDisplayLength", 0))
         start = int(kw.get("iDisplayStart", 0))
         sort_col = int(kw.get("iSortCol_0", 1))
@@ -40,9 +40,11 @@ class JsonUsersList(base.JSONView):
 
         end = start + length
         query = User.query \
-          .options(sa.orm.subqueryload('groups'),
-                   sa.orm.undefer('photo'), ) \
-          .filter(User.id != 0)
+            .options(
+                sa.orm.subqueryload('groups'),
+                sa.orm.undefer('photo'),
+            ) \
+            .filter(User.id != 0)
         total_count = query.count()
 
         if search:
@@ -50,7 +52,8 @@ class JsonUsersList(base.JSONView):
             filter = or_(
                 func.lower(User.first_name).like("%" + search + "%"),
                 func.lower(User.last_name).like("%" + search + "%"),
-                func.lower(User.email).like("%" + search + "%"))
+                func.lower(User.email).like("%" + search + "%"),
+            )
             query = query.filter(filter)
 
         count = query.count()
@@ -61,10 +64,14 @@ class JsonUsersList(base.JSONView):
         }
         columns = list(SORT_COLS.get(sort_col, []))
         columns.extend(
-            [func.lower(User.last_name), func.lower(User.first_name)])
+            [
+                func.lower(User.last_name),
+                func.lower(User.first_name),
+            ],
+        )
 
         direction = asc if sort_dir == 'asc' else desc
-        order_by = map(direction, columns)
+        order_by = list(map(direction, columns))
 
         # sqlite does not support 'NULLS FIRST|LAST' in ORDER BY clauses
         engine = query.session.get_bind(User.__mapper__)
@@ -84,31 +91,36 @@ class JsonUsersList(base.JSONView):
             name = escape(getattr(user, "name") or "")
             email = escape(getattr(user, "email") or "")
             roles = [
-                r for r in security.get_roles(
-                    user, no_group_roles=True) if r.assignable
+                r for r in security.get_roles(user, no_group_roles=True)
+                if r.assignable
             ]
             columns = [
                 '<a href="{url}"><img src="{src}" width="{size}" height="{size}">'
                 '</a>'.format(url=user_url, src=mugshot, size=MUGSHOT_SIZE),
                 '<a href="{url}">{name}</a>'.format(url=user_url, name=name),
-                '<a href="{url}"><em>{email}</em></a>'.format(url=user_url, email=email),
-                '\u2713' if user.can_login else u'',
+                '<a href="{url}"><em>{email}</em></a>'.format(
+                    url=user_url,
+                    email=email,
+                ),
+                '\u2713' if user.can_login else '',
                 render_template_string(
-                    u'''{%- for g in groups %}
+                    '''{%- for g in groups %}
                         <span class="badge badge-default">{{ g.name }}</span>
                     {%- endfor %}''',
-                    groups=sorted(user.groups)),
+                    groups=sorted(user.groups),
+                ),
                 render_template_string(
-                    u'''{%- for role in roles %}
+                    '''{%- for role in roles %}
                        <span class="badge badge-default">{{ role }}</span>
                     {%- endfor %}''',
-                    roles=roles),
+                    roles=roles,
+                ),
             ]
 
             if user.last_active:
                 last_active = format_datetime(user.last_active)
             else:
-                last_active = _(u'Never logged in')
+                last_active = _('Never logged in')
             columns.append(last_active)
 
             data.append(columns)
@@ -137,12 +149,12 @@ class UserBase(object):
 class UserEdit(UserBase, views.ObjectEdit):
 
     def breadcrumb(self):
-        label = render_template_string(u'<em>{{ u.email }}</em>', u=self.obj)
+        label = render_template_string('<em>{{ u.email }}</em>', u=self.obj)
         return BreadcrumbItem(label=label, url='', description=self.obj.name)
 
     def get_form_kwargs(self):
         kw = super(UserEdit, self).get_form_kwargs()
-        security = current_app.services['security']
+        security = get_service('security')
         roles = security.get_roles(self.obj, no_group_roles=True)
         kw['roles'] = [r.name for r in roles if r.assignable]
         return kw
@@ -159,7 +171,7 @@ class UserEdit(UserBase, views.ObjectEdit):
                 roles.data.append(Admin.name)
         return True
 
-    def form_valid(self):
+    def form_valid(self, *args, **kwargs):
         del self.form.confirm_password
         if self.form.password.data:
             self.obj.set_password(self.form.password.data)
@@ -168,9 +180,9 @@ class UserEdit(UserBase, views.ObjectEdit):
         return super(UserEdit, self).form_valid()
 
     def after_populate_obj(self):
-        security = current_app.services['security']
+        security = get_service('security')
         current_roles = security.get_roles(self.obj, no_group_roles=True)
-        current_roles = set(r for r in current_roles if r.assignable)
+        current_roles = {r for r in current_roles if r.assignable}
         new_roles = {Role(r) for r in self.form.roles.data}
 
         for r in (current_roles - new_roles):
@@ -197,7 +209,7 @@ class UserCreate(UserBase, views.ObjectCreate):
 
         return kw
 
-    def form_valid(self):
+    def form_valid(self, redirect_to=None):
         if not self.form.password.data:
             self.form.password.data = gen_random_password()
 
