@@ -1,11 +1,9 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
 import pkg_resources
-
-from flask import url_for, current_app
+from flask import current_app, url_for
 from flask_assets import Bundle
 
 from abilian.services.security import Anonymous
@@ -18,7 +16,11 @@ def init_app(app):
     assets = app.extensions['webassets']
     assets.append_path(RESOURCES_DIR, '/static/abilian')
     app.add_static_url(
-        'abilian', RESOURCES_DIR, endpoint='abilian_static', roles=Anonymous)
+        'abilian',
+        RESOURCES_DIR,
+        endpoint='abilian_static',
+        roles=Anonymous,
+    )
 
     app.before_first_request(requirejs_config)
 
@@ -31,7 +33,9 @@ def requirejs_config():
     ckeditor_lib = 'ckeditor/ckeditor'
     config['shim']['ckeditor'] = {'exports': 'CKEDITOR'}
     config['paths']['ckeditor'] = url_for(
-        'abilian_static', filename=ckeditor_lib)
+        'abilian_static',
+        filename=ckeditor_lib,
+    )
 
     d3_lib = 'nvd3/d3.min'
     config['shim']['d3'] = {'exports': 'd3'}
@@ -44,8 +48,7 @@ def requirejs_config():
 
 RESOURCES_DIR = pkg_resources.resource_filename('abilian.web', 'resources')
 
-JQUERY = Bundle('jquery/js/jquery-1.11.3.js',
-                'jquery/js/jquery-migrate-1.2.1.js')
+JQUERY = Bundle('jquery/js/jquery-1.11.3.js')
 
 BOOTBOX_JS = Bundle('bootbox/bootbox.js')
 
@@ -54,18 +57,23 @@ BOOTSTRAP_JS = Bundle('bootstrap/js/bootstrap.js')
 
 BOOTSTRAP_DATEPICKER_LESS = 'bootstrap-datepicker/less/datepicker.less'
 BOOTSTRAP_DATEPICKER_JS = Bundle(
-    'bootstrap-datepicker/js/bootstrap-datepicker.js')
+    'bootstrap-datepicker/js/bootstrap-datepicker.js',
+)
 
 BOOTSTRAP_SWITCH_LESS = Bundle(
-    'bootstrap-switch/less/bootstrap3/bootstrap-switch.less')
+    'bootstrap-switch/less/bootstrap3/bootstrap-switch.less',
+)
 BOOTSTRAP_SWITCH_JS = Bundle('bootstrap-switch/bootstrap-switch.js')
 
 BOOTSTRAP_TIMEPICKER_LESS = Bundle('bootstrap-timepicker/less/timepicker.less')
 BOOTSTRAP_TIMEPICKER_JS = Bundle(
-    'bootstrap-timepicker/js/bootstrap-timepicker.js')
+    'bootstrap-timepicker/js/bootstrap-timepicker.js',
+)
 
-DATATABLE_LESS = Bundle('datatables/css/jquery.dataTables.css',
-                        'datatables/css/jquery.dataTables_themeroller.css')
+DATATABLE_LESS = Bundle(
+    'datatables/css/jquery.dataTables.css',
+    'datatables/css/jquery.dataTables_themeroller.css',
+)
 DATATABLE_JS = Bundle('datatables/js/jquery.dataTables.js')
 
 FILEAPI_JS = Bundle('fileapi/FileAPI.js')
@@ -76,7 +84,8 @@ REQUIRE_JS = Bundle('requirejs/require.js', 'requirejs/domReady.js')
 
 SELECT2_LESS = Bundle(
     'select2/select2.css',
-    'select2/select2-bootstrap.css',)
+    'select2/select2-bootstrap.css',
+)
 SELECT2_JS = Bundle('select2/select2.js')
 
 TYPEAHEAD_LESS = Bundle('typeahead/typeahead.js-bootstrap.less')
@@ -96,7 +105,8 @@ ABILIAN_JS = Bundle(
     'js/widgets/file.js',
     'js/widgets/image.js',
     'js/widgets/tags.js',
-    'js/widgets/dynamic-row.js',)
+    'js/widgets/dynamic-row.js',
+)
 
 LESS = Bundle(
     BOOTSTRAP_LESS,
@@ -107,7 +117,8 @@ LESS = Bundle(
     BOOTSTRAP_SWITCH_LESS,
     BOOTSTRAP_TIMEPICKER_LESS,
     DATATABLE_LESS,
-    ABILIAN_LESS,)
+    ABILIAN_LESS,
+)
 
 TOP_JS = Bundle(REQUIRE_JS, JQUERY, ABILIAN_JS_NS)
 
@@ -121,8 +132,10 @@ JS = Bundle(
     BOOTSTRAP_TIMEPICKER_JS,
     DATATABLE_JS,
     FILEAPI_JS,
-    ABILIAN_JS,)
+    ABILIAN_JS,
+)
 
 JS_I18N = (
     'select2/select2_locale_{lang}.js',
-    'bootstrap-datepicker/js/locales/bootstrap-datepicker.{lang}.js',)
+    'bootstrap-datepicker/js/locales/bootstrap-datepicker.{lang}.js',
+)
