@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -19,8 +18,7 @@ _MANAGER_ATTR = '__attachments_manager__'
 
 
 class AttachmentExtension(object):
-    """
-    API for comments, installed as an application extension.
+    """API for comments, installed as an application extension.
 
     It is also available in templates as `attachments`.
     """
@@ -31,9 +29,7 @@ class AttachmentExtension(object):
         app.register_blueprint(blueprint)
 
     def manager(self, obj):
-        """
-        Returns the :class:`AttachmentsManager` instance for this object.
-        """
+        """Returns the :class:`AttachmentsManager` instance for this object."""
         manager = getattr(obj, _MANAGER_ATTR, None)
         if manager is None:
             manager = AttachmentsManager()
@@ -47,7 +43,8 @@ class AttachmentExtension(object):
     def for_entity(self, obj, check_support_attachments=False):
         return self.manager(obj).for_entity(
             obj,
-            check_support_attachments=check_support_attachments,)
+            check_support_attachments=check_support_attachments,
+        )
 
     def has_attachments(self, obj):
         return self.manager(obj).has_attachments(obj)
@@ -56,8 +53,8 @@ class AttachmentExtension(object):
         return self.manager(obj).count(obj)
 
     def get_form_context(self, obj):
-        """
-        Return a dict: form instance, action button, submit url...
+        """Return a dict: form instance, action button, submit url...
+
         Used by macro m_attachment_form(entity)
         """
         return self.manager(obj).get_form_context(obj)
@@ -67,17 +64,18 @@ _DEFAULT_TEMPLATE = 'macros/attachment_default.html'
 
 
 class AttachmentsManager(object):
-    """
-    Allow customization of attachments form, display macros, etc
+    """Allow customization of attachments form, display macros, etc.
 
     can be used as class decorator
     """
     Form = AttachmentForm
     macros_template = 'macros/attachment.html'
 
-    def __init__(self,
-                 Form=AttachmentForm,
-                 macros_template='macros/attachment_default.html'):
+    def __init__(
+            self,
+            Form=AttachmentForm,
+            macros_template='macros/attachment_default.html',
+    ):
         self.Form = Form
         self.macros_template = macros_template
 
@@ -87,22 +85,29 @@ class AttachmentsManager(object):
 
     @property
     def macros(self):
-        default_template = current_app.jinja_env.get_template(_DEFAULT_TEMPLATE)
+        default_template = current_app.jinja_env.get_template(
+            _DEFAULT_TEMPLATE)
         template = current_app.jinja_env.get_template(self.macros_template)
         default = default_template.module
         m = template.module
         return dict(
             m_attachments=getattr(m, 'm_attachments', default.m_attachments),
             m_attachment=getattr(m, 'm_attachment', default.m_attachment),
-            m_attachment_form=getattr(m, 'm_attachment_form',
-                                      default.m_attachment_form))
+            m_attachment_form=getattr(
+                m,
+                'm_attachment_form',
+                default.m_attachment_form,
+            ),
+        )
 
     def is_support_attachments(self, obj):
         return attachments.is_support_attachments(obj)
 
     def for_entity(self, obj, check_support_attachments=False):
         return attachments.for_entity(
-            obj, check_support_attachments=check_support_attachments)
+            obj,
+            check_support_attachments=check_support_attachments,
+        )
 
     def has_attachments(self, obj):
         return bool(self.for_entity(obj, check_support_attachments=True))
@@ -111,39 +116,31 @@ class AttachmentsManager(object):
         return len(self.for_entity(obj, check_support_attachments=True))
 
     def get_form_context(self, obj):
-        """
-        Return a dict: form instance, action button, submit url...
+        """Return a dict: form instance, action button, submit url...
+
         Used by macro m_attachment_form(entity)
         """
-        ctx = {}
-        ctx['url'] = url_for('attachments.create', entity_id=obj.id)
-        ctx['form'] = self.Form()
-        ctx['buttons'] = [UPLOAD_BUTTON]
-        return ctx
+        return {
+            'url': url_for('attachments.create', entity_id=obj.id),
+            'form': self.Form(),
+            'buttons': [UPLOAD_BUTTON],
+        }
 
     #
     # current user capabilities
     #
     def can_view(self, entity):
-        """
-        True if user can view attachments on entity
-        """
+        """True if user can view attachments on entity."""
         return security.has_permission(current_user, READ, obj=entity)
 
     def can_edit(self, entity):
-        """
-        True if user can edit attachments on entity
-        """
+        """True if user can edit attachments on entity."""
         return security.has_permission(current_user, WRITE, obj=entity)
 
     def can_create(self, entity):
-        """
-        True if user can add attachments
-        """
+        """True if user can add attachments."""
         return security.has_permission(current_user, WRITE, obj=entity)
 
     def can_delete(self, entity):
-        """
-        True if user can delete attachments
-        """
+        """True if user can delete attachments."""
         return security.has_permission(current_user, WRITE, obj=entity)
