@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -17,9 +16,13 @@ from abilian.web.forms.validators import required
 class AttachmentForm(Form):
 
     blob = FileField(
-        _l(u'file'), validators=[required()], filters=[strip], multiple=False)
+        _l('file'),
+        validators=[required()],
+        filters=[strip],
+        multiple=False,
+    )
 
-    description = StringField(_l(u'description (optional)'), filters=[strip])
+    description = StringField(_l('description (optional)'), filters=[strip])
 
     class Meta:
         model = Attachment
