@@ -1,12 +1,13 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 from datetime import datetime
+from typing import Optional
 
 import sqlalchemy as sa
+import sqlalchemy.orm
 from flask_login import current_user
 from six import text_type
 from werkzeug.exceptions import BadRequest
@@ -37,7 +38,11 @@ def register_default_view(state):
 
 
 COMMENT_BUTTON = ButtonAction(
-    'form', 'edit', btn_class='primary', title=_l(u'Post'))
+    'form',
+    'edit',
+    btn_class='primary',
+    title=_l('Post'),
+)
 
 
 class BaseCommentView(object):
@@ -45,7 +50,7 @@ class BaseCommentView(object):
     Form = CommentForm
 
     #: commented entity
-    entity = None
+    entity = None  # type: Optional[Entity]
 
     def init_object(self, args, kwargs):
         args, kwargs = super(BaseCommentView, self).init_object(args, kwargs)
@@ -78,10 +83,10 @@ class BaseCommentView(object):
 
 class CommentEditView(BaseCommentView, ObjectEdit):
 
-    _message_success = _l(u'Comment edited')
+    _message_success = _l('Comment edited')
 
     def breadcrumb(self):
-        label = _(u'Edit comment on "{title}"').format(title=self.entity.name)
+        label = _('Edit comment on "{title}"').format(title=self.entity.name)
         return nav.BreadcrumbItem(label=label)
 
     def get_form_buttons(self, *args, **kwargs):
@@ -94,7 +99,9 @@ class CommentEditView(BaseCommentView, ObjectEdit):
             dict(
                 user_id=current_user.id,
                 user=text_type(current_user),
-                date=utc_dt(datetime.utcnow()).isoformat(),))
+                date=utc_dt(datetime.utcnow()).isoformat(),
+            ),
+        )
         self.obj.meta.changed()
 
 
@@ -103,9 +110,8 @@ bp.route('/<int:entity_id>/<int:object_id>/edit')(edit_view)
 
 
 class CommentCreateView(BaseCommentView, ObjectCreate):
-    """
-  """
-    _message_success = _l(u"Comment added")
+    """"""
+    _message_success = _l("Comment added")
 
     def __init__(self, *args, **kwargs):
         super(CommentCreateView, self).__init__(*args, **kwargs)
@@ -121,7 +127,7 @@ class CommentCreateView(BaseCommentView, ObjectCreate):
         return args, kwargs
 
     def breadcrumb(self):
-        label = _(u'New comment on "{title}"').format(title=self.entity.name)
+        label = _('New comment on "{title}"').format(title=self.entity.name)
         return nav.BreadcrumbItem(label=label)
 
     def get_form_buttons(self, *args, **kwargs):
@@ -134,7 +140,7 @@ bp.route('/<int:entity_id>/create')(create_view)
 
 class CommentDeleteView(BaseCommentView, ObjectDelete):
 
-    _message_success = _l(u"Comment deleted")
+    _message_success = _l("Comment deleted")
 
 
 delete_view = CommentDeleteView.as_view('delete')
