@@ -1,7 +1,5 @@
 # coding: utf-8
-"""
-Add a few specific filters to Jinja2.
-"""
+"""Add a few specific filters to Jinja2."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -27,9 +25,7 @@ from .util import url_for
 
 
 def autoescape(filter_func):
-    """
-    Decorator to autoescape result from filters.
-    """
+    """Decorator to autoescape result from filters."""
 
     @evalcontextfilter
     @wraps(filter_func)
@@ -44,9 +40,8 @@ def autoescape(filter_func):
 
 @autoescape
 def nl2br(value):
-    """Replace newlines with <br />.
-    """
-    result = escape(value).replace(u'\n', Markup(u'<br />\n'))
+    """Replace newlines with <br />."""
+    result = escape(value).replace('\n', Markup('<br />\n'))
     return result
 
 
@@ -55,16 +50,16 @@ _PARAGRAPH_RE = re.compile(r'(?:\r\n|\r|\n){2,}')
 
 @autoescape
 def paragraphs(value):
-    """Blank lines delimitates paragraphs.
-    """
-    result = u'\n\n'.join(
-        (u'<p>{}</p>'.format(p.strip().replace('\n', Markup('<br />\n')))
-         for p in _PARAGRAPH_RE.split(escape(value))))
+    """Blank lines delimitates paragraphs."""
+    result = '\n\n'.join(
+        ('<p>{}</p>'.format(p.strip().replace('\n', Markup('<br />\n')))
+         for p in _PARAGRAPH_RE.split(escape(value)))
+    )
     return result
 
 
 def labelize(s):
-    return u" ".join([w.capitalize() for w in s.split(u"_")])
+    return " ".join([w.capitalize() for w in s.split("_")])
 
 
 def filesize(d):
@@ -74,17 +69,17 @@ def filesize(d):
     if d < 1000:
         s = "%d&nbsp;B" % d
 
-    elif d < 1e4:
+    elif d < int(1e4):
         s = "%.1f&nbsp;kB" % (d / 1e3)
-    elif d < 1e6:
+    elif d < int(1e6):
         s = "%.0f&nbsp;kB" % (d / 1e3)
 
-    elif d < 1e7:
+    elif d < int(1e7):
         s = "%.1f&nbsp;MB" % (d / 1e6)
-    elif d < 1e9:
+    elif d < int(1e9):
         s = "%.0f&nbsp;MB" % (d / 1e6)
 
-    elif d < 1e10:
+    elif d < int(1e10):
         s = "%.1f&nbsp;GB" % (d / 1e9)
 
     else:
@@ -94,15 +89,11 @@ def filesize(d):
 
 
 def roughsize(size, above=20, mod=10):
-    """
-    6 -> '6'
-    15 -> '15'
-    134 -> '130+'
-    """
+    """6 -> '6' 15 -> '15' 134 -> '130+'."""
     if size < above:
         return text_type(size)
 
-    return u'{:d}+'.format(size - size % mod)
+    return '{:d}+'.format(size - size % mod)
 
 
 def datetimeparse(s):
@@ -114,7 +105,7 @@ def datetimeparse(s):
     """
     try:
         dt = dateutil.parser.parse(s)
-    except:
+    except ValueError:
         return None
 
     return utc_dt(dt)
@@ -158,7 +149,7 @@ def age(dt, now=None, add_direction=True, date_threshold=None):
             if remove_year:
                 date_fmt = date_fmt.replace('y', '').strip()
                 # remove leading or trailing spaces, comma, etc...
-                date_fmt = re.sub(u'^[^A-Za-z]*|[^A-Za-z]*$', u'', date_fmt)
+                date_fmt = re.sub('^[^A-Za-z]*|[^A-Za-z]*$', '', date_fmt)
 
             fmt = fmt.format(time_fmt, date_fmt)
             return babel.format_datetime(dt, format=fmt)
@@ -170,7 +161,8 @@ def age(dt, now=None, add_direction=True, date_threshold=None):
         locale=locale,
         granularity='minute',
         threshold=0.9,
-        add_direction=add_direction)
+        add_direction=add_direction,
+    )
 
 
 def date_age(dt, now=None):
@@ -179,7 +171,7 @@ def date_age(dt, now=None):
         return ""
 
     formatted_date = babel.format_datetime(dt, format='yyyy-MM-dd HH:mm')
-    return u"{} ({})".format(formatted_date, age(dt, now))
+    return "{} ({})".format(formatted_date, age(dt, now))
 
 
 @deprecated
@@ -194,10 +186,8 @@ def date(value, format="EE, d MMMM y"):
 
 
 def babel2datepicker(pattern):
-    """Convert date format from babel
-    (http://babel.pocoo.org/docs/dates/#date-fields)) to a format understood by
-    bootstrap-datepicker.
-    """
+    """Convert date format from babel (http://babel.pocoo.org/docs/dates/#date-
+    fields)) to a format understood by bootstrap-datepicker."""
     if not isinstance(pattern, DateTimePattern):
         pattern = parse_pattern(pattern)
 
@@ -253,8 +243,7 @@ def abbrev(s, max_size):
 
 
 def bool2check(val, true='\u2713', false=''):
-    """Filter value as boolean and show check mark (✓) or nothing.
-    """
+    """Filter value as boolean and show check mark (✓) or nothing."""
     return true if val else false
 
 
@@ -264,7 +253,8 @@ def linkify(s):
 
 
 def obj_to_url(obj):
-    """Find url for obj using :func:`url_for`, return empty string is not found.
+    """Find url for obj using :func:`url_for`, return empty string is not
+    found.
 
     :func:`url_for` is also provided in jinja context, the filtering version is
     forgiving when `obj` has no default view set.
@@ -272,7 +262,7 @@ def obj_to_url(obj):
     try:
         return url_for(obj)
     except BuildError:
-        return u''
+        return ''
 
 
 def init_filters(env):
