@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -10,24 +9,25 @@ import operator
 from functools import partial
 
 import babel
+import babel.dates
 import sqlalchemy as sa
+import sqlalchemy.exc
 from flask import current_app
 from flask.helpers import locked_cached_property
 from flask_babel import format_date, format_datetime, get_locale, get_timezone
 from flask_login import current_user
 from flask_wtf.file import FileField as BaseFileField
-from six import string_types
+from six import PY2, string_types
 from wtforms import FieldList as BaseFieldList
 from wtforms import FormField as BaseFormField
 from wtforms import Field, SelectField, SelectFieldBase, SelectMultipleField, \
     ValidationError
 from wtforms.compat import text_type
 from wtforms.ext.csrf import SecureForm
-from wtforms.ext.sqlalchemy.fields import get_pk_from_identity, \
-    has_identity_key
 from wtforms.validators import DataRequired, Optional
 from wtforms_alchemy import ModelFieldList as BaseModelFieldList
 from wtforms_alchemy import ModelFormField as BaseModelFormField
+from wtforms_sqlalchemy.fields import get_pk_from_identity, has_identity_key
 
 from abilian import i18n
 from abilian.core.extensions import db
@@ -37,16 +37,20 @@ from .util import babel2datetime
 from .widgets import DateInput, DateTimeInput, FileInput, Select2, Select2Ajax
 
 __all__ = [
-    'ModelFieldList', 'FileField', 'DateField', 'Select2Field',
-    'Select2MultipleField', 'QuerySelect2Field', 'JsonSelect2Field',
-    'JsonSelect2MultipleField', 'FormField'
+    'ModelFieldList',
+    'FileField',
+    'DateField',
+    'Select2Field',
+    'Select2MultipleField',
+    'QuerySelect2Field',
+    'JsonSelect2Field',
+    'JsonSelect2MultipleField',
+    'FormField',
 ]
 
 
 class FormField(BaseFormField):
-    """
-    Discard csrf_token on subform
-    """
+    """Discard csrf_token on subform."""
 
     def process(self, *args, **kwargs):
         super(FormField, self).process(*args, **kwargs)
@@ -60,7 +64,8 @@ class FormField(BaseFormField):
         if not isinstance(self.form, SecureForm):
             return self.form.data
 
-        # SecureForm will try to pop 'csrf_token', but we removed it during process
+        # SecureForm will try to pop 'csrf_token', but we removed it during
+        # process
         self.form._fields['csrf_token'] = self._subform_csrf
         data = self.form.data
         del self.form['csrf_token']
@@ -68,14 +73,12 @@ class FormField(BaseFormField):
 
 
 class ModelFormField(FormField, BaseModelFormField):
-    """
-    Discard csrf_token on subform
-    """
+    """Discard csrf_token on subform."""
 
 
 class FilterFieldListMixin(object):
 
-    def validate(self, form, extra_validators=tuple()):
+    def validate(self, form, extra_validators=()):
         to_remove = []
         for field in self.entries:
             is_subform = isinstance(field, BaseFormField)
@@ -95,8 +98,10 @@ class FilterFieldListMixin(object):
             # 3) by setting raw_data optional() does not reset the errors dict
             # -> subfields errors are propagated
             self.raw_data = [True]
-        return super(FilterFieldListMixin, self).validate(form,
-                                                          extra_validators)
+        return super(FilterFieldListMixin, self).validate(
+            form,
+            extra_validators,
+        )
 
 
 class FieldList(FilterFieldListMixin, BaseFieldList):
@@ -104,9 +109,7 @@ class FieldList(FilterFieldListMixin, BaseFieldList):
 
 
 class ModelFieldList(FilterFieldListMixin, BaseModelFieldList):
-    """
-    Filter empty entries before saving and refills before displaying
-    """
+    """Filter empty entries before saving and refills before displaying."""
 
     def __init__(self, *args, **kwargs):
         super(ModelFieldList, self).__init__(*args, **kwargs)
@@ -116,7 +119,10 @@ class ModelFieldList(FilterFieldListMixin, BaseModelFieldList):
         field_names = []
         labels = []
         fieldsubform = self.unbound_field.bind(
-            form=None, name='dummy', _meta=self.meta)
+            form=None,
+            name='dummy',
+            _meta=self.meta,
+        )
         subform = fieldsubform.form_class(csrf_enabled=False)
         for f in subform:
             if f.is_hidden:
@@ -128,15 +134,15 @@ class ModelFieldList(FilterFieldListMixin, BaseModelFieldList):
         self._field_names = field_names
         self._field_labels = labels
         self._field_nameTolabel = dict(
-            zip(self._field_names, self._field_labels))
+            zip(self._field_names, self._field_labels),
+        )
 
     def __call__(self, **kwargs):
-        """
-        Refill with default min_entry, which were possibly
-        removed by FilterFieldListMixin.
+        """Refill with default min_entry, which were possibly removed by
+        FilterFieldListMixin.
 
-        Mandatory for proper function of DynamicRowWidget which clones an existing
-        field
+        Mandatory for proper function of DynamicRowWidget which clones
+        an existing field
         """
         while len(self) < self.min_entries:
             self.append_entry()
@@ -144,8 +150,8 @@ class ModelFieldList(FilterFieldListMixin, BaseModelFieldList):
 
 
 class FileField(BaseFileField):
-    """
-    Support 'multiple' attribute, enabling html5 multiple file input in widget.
+    """Support 'multiple' attribute, enabling html5 multiple file input in
+    widget.
 
     Can store file using a related model.
 
@@ -173,11 +179,15 @@ class FileField(BaseFileField):
         if allow_delete is not None:
             if any(
                     isinstance(v, DataRequired if allow_delete else Optional)
-                    for v in validators):
+                    for v in validators
+            ):
                 raise ValueError(
                     "Field validators are conflicting with `allow_delete`,"
-                    "validators={!r}, allow_delete={!r}".format(validators,
-                                                                allow_delete))
+                    "validators={!r}, allow_delete={!r}".format(
+                        validators,
+                        allow_delete,
+                    ),
+                )
             if not allow_delete:
                 validators.append(DataRequired())
 
@@ -201,7 +211,7 @@ class FileField(BaseFileField):
         return self._has_uploads
 
     def process(self, formdata, *args, **kwargs):
-        delete_arg = u'__{name}_delete__'.format(name=self.name)
+        delete_arg = '__{name}_delete__'.format(name=self.name)
         self.delete_files_index = (formdata.getlist(delete_arg) if formdata and
                                    delete_arg in formdata else [])
 
@@ -228,8 +238,9 @@ class FileField(BaseFileField):
 
             if fileobj is None:
                 # FIXME: this is a validation task
-                raise ValueError('File with handle {!r} not found'.format(
-                    handle))
+                raise ValueError(
+                    'File with handle {!r} not found'.format(handle),
+                )
 
             meta = uploads.get_metadata(current_user, handle)
             filename = meta.get('filename', handle)
@@ -243,8 +254,7 @@ class FileField(BaseFileField):
             self._has_uploads = True
 
     def populate_obj(self, obj, name):
-        """Store file.
-        """
+        """Store file."""
         from abilian.core.models.blob import Blob
         delete_value = self.allow_delete and self.delete_files_index
 
@@ -261,7 +271,8 @@ class FileField(BaseFileField):
         rel = getattr(mapper.relationships, name)
         if rel.uselist:
             raise ValueError(
-                "Only single target supported; else use ModelFieldList")
+                "Only single target supported; else use ModelFieldList",
+            )
 
         if delete_value:
             setattr(obj, name, None)
@@ -275,7 +286,7 @@ class FileField(BaseFileField):
             val = cls()
             setattr(obj, name, val)
 
-        data = u''
+        data = ''
         if self.has_file():
             data = self.data
             if not issubclass(cls, Blob):
@@ -311,7 +322,11 @@ class DateTimeField(Field):
                 .replace('yy', 'y') \
                 .replace('y', 'yyyy')
             time_fmt = locale.time_formats['short']
-            dt_fmt = locale.datetime_formats['short'].format(time_fmt, date_fmt)
+            # Workaround bug in Babel (at least <= 2.4) under Python 3
+            if not PY2:
+                time_fmt = time_fmt.pattern
+            dt_fmt = locale.datetime_formats['short'].format(
+                time_fmt, date_fmt)
             return format_datetime(self.data, dt_fmt) if self.data else ''
 
     def process_data(self, value):
@@ -337,7 +352,7 @@ class DateTimeField(Field):
                 .replace('%b', '%m')  # force numerical months
             time_fmt = locale.time_formats['short']
             time_fmt = babel2datetime(time_fmt)
-            datetime_fmt = u'{} | {}'.format(date_fmt, time_fmt)
+            datetime_fmt = '{} | {}'.format(date_fmt, time_fmt)
             try:
                 self.data = datetime.datetime.strptime(date_str, datetime_fmt)
                 if not self.use_naive:
@@ -362,9 +377,7 @@ class DateTimeField(Field):
 
 
 class DateField(Field):
-    """
-    A text field which stores a `datetime.date` matching a format.
-    """
+    """A text field which stores a `datetime.date` matching a format."""
     widget = DateInput()
 
     def __init__(self, label=None, validators=None, **kwargs):
@@ -396,8 +409,8 @@ class DateField(Field):
                 .replace('%b', '%m')
 
             try:
-                self.data = datetime.datetime.strptime(date_str,
-                                                       date_fmt).date()
+                strptime = datetime.datetime.strptime
+                self.data = strptime(date_str, date_fmt).date()
             except ValueError:
                 self.data = None
                 raise ValueError(self.gettext('Not a valid datetime value'))
@@ -406,8 +419,7 @@ class DateField(Field):
 
 
 class Select2Field(SelectField):
-    """Allows choices to be a function instead of an iterable.
-    """
+    """Allows choices to be a function instead of an iterable."""
     widget = Select2()
 
     @property
@@ -435,8 +447,7 @@ class Select2MultipleField(SelectMultipleField):
 
 
 class QuerySelect2Field(SelectFieldBase):
-    """
-    COPY/PASTED (and patched) from WTForms!
+    """COPY/PASTED (and patched) from WTForms!
 
     Will display a select drop-down field to choose between ORM results in a
     sqlalchemy `Query`.  The `data` property actually will store/keep an ORM
@@ -464,18 +475,20 @@ class QuerySelect2Field(SelectFieldBase):
     :param allow_blank: DEPRECATED. Use optional()/required() validators instead.
     """
 
-    def __init__(self,
-                 label=None,
-                 validators=None,
-                 query_factory=None,
-                 get_pk=None,
-                 get_label=None,
-                 allow_blank=False,
-                 blank_text='',
-                 widget=None,
-                 multiple=False,
-                 collection_class=list,
-                 **kwargs):
+    def __init__(
+        self,
+        label=None,
+        validators=None,
+        query_factory=None,
+        get_pk=None,
+        get_label=None,
+        allow_blank=False,
+        blank_text='',
+        widget=None,
+        multiple=False,
+        collection_class=list,
+        **kwargs
+    ):
 
         if widget is None:
             widget = Select2(multiple=multiple)
@@ -487,11 +500,14 @@ class QuerySelect2Field(SelectFieldBase):
         if validators is None:
             validators = []
 
-        if not any(isinstance(v, (Optional, DataRequired)) for v in validators):
-            logger = logging.getLogger(__name__ + '.' + self.__class__.__name__)
+        if not any(isinstance(v, (Optional, DataRequired))
+                   for v in validators):
+            logger = logging.getLogger(
+                __name__ + '.' + self.__class__.__name__)
             logger.warning(
-                u'Use deprecated parameter `allow_blank` for field "{}".'
-                .format(label))
+                'Use deprecated parameter `allow_blank` for field "{}".'
+                .format(label),
+            )
             if not allow_blank:
                 validators.append(DataRequired())
 
@@ -504,7 +520,7 @@ class QuerySelect2Field(SelectFieldBase):
         if get_pk is None:
             if not has_identity_key:
                 raise Exception(
-                    'The sqlalchemy identity_key function could not be imported.'
+                    'The sqlalchemy identity_key function could not be imported.',
                 )
             self.get_pk = get_pk_from_identity
         else:
@@ -544,7 +560,8 @@ class QuerySelect2Field(SelectFieldBase):
     def _set_data(self, data):
         if self.multiple and not isinstance(data, self.collection_class):
             data = self.collection_class(
-                data) if data else self.collection_class()
+                data,
+            ) if data else self.collection_class()
         self._data = data
         self._formdata = None
 
@@ -554,17 +571,22 @@ class QuerySelect2Field(SelectFieldBase):
         if self._object_list is None:
             query = self.query or self.query_factory()
             get_pk = self.get_pk
-            self._object_list = list((text_type(get_pk(obj)), obj)
-                                     for obj in query)
+            self._object_list = [(text_type(get_pk(obj)), obj)
+                                 for obj in query]
         return self._object_list
 
     def iter_choices(self):
         if not self.flags.required:
-            yield (None, None, self.data == []
-                   if self.multiple else self.data is None)
+            yield (
+                None,
+                None,
+                self.data == [] if self.multiple else self.data is None,
+            )
 
-        predicate = (operator.contains if
-                     (self.multiple and self.data is not None) else operator.eq)
+        predicate = (
+            operator.contains if
+            (self.multiple and self.data is not None) else operator.eq
+        )
         # remember: operator.contains(b, a) ==> a in b
         # so: obj in data ==> contains(data, obj)
         predicate = partial(predicate, self.data)
@@ -592,13 +614,12 @@ class QuerySelect2Field(SelectFieldBase):
 
             data = set(data)
             valid = {obj for pk, obj in self._get_object_list()}
-            if (data - valid):
+            if data - valid:
                 raise ValidationError(self.gettext('Not a valid choice'))
 
 
 class JsonSelect2Field(SelectFieldBase):
-    """
-    TODO: rewrite this docstring. This is copy-pasted from QuerySelectField
+    """TODO: rewrite this docstring. This is copy-pasted from QuerySelectField.
 
     Will display a select drop-down field to choose between ORM results in a
     sqlalchemy `Query`.  The `data` property actually will store/keep an ORM
@@ -634,15 +655,17 @@ class JsonSelect2Field(SelectFieldBase):
     declaration.
     """
 
-    def __init__(self,
-                 label=None,
-                 validators=None,
-                 ajax_source=None,
-                 widget=None,
-                 blank_text='',
-                 model_class=None,
-                 multiple=False,
-                 **kwargs):
+    def __init__(
+        self,
+        label=None,
+        validators=None,
+        ajax_source=None,
+        widget=None,
+        blank_text='',
+        model_class=None,
+        multiple=False,
+        **kwargs
+    ):
 
         self.multiple = multiple
 
@@ -688,7 +711,7 @@ class JsonSelect2Field(SelectFieldBase):
                 formdata = [formdata]
             data = [
                 self.model_class.query.get(int(pk)) for pk in formdata
-                if pk not in (u'', None)
+                if pk not in ('', None)
             ]
             if not self.multiple:
                 data = data[0] if data else None
@@ -729,7 +752,8 @@ class JsonSelect2Field(SelectFieldBase):
         if self.multiple and name in relations:
             prop = relations[name]
             if prop.collection_class:
-                # data is a list, try to convert to actual type; generally `set()`
+                # data is a list, try to convert to actual type; generally
+                # `set()`
                 data = prop.collection_class(data)
 
         setattr(obj, name, data)
@@ -760,7 +784,8 @@ class LocaleSelectField(SelectField):
 
         raise ValueError(
             'Value cannot be converted to Locale(), or is not None, {!r}'.
-            format(value))
+            format(value),
+        )
 
     def iter_choices(self):
         if not self.flags.required:
