@@ -1,8 +1,8 @@
 # coding=utf-8
-"""
-Front-end for a CRM app.
+"""Front-end for a CRM app.
 
-This should eventually allow implementing very custom CRM-style application.
+This should eventually allow implementing very custom CRM-style
+application.
 """
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
@@ -11,11 +11,13 @@ import copy
 import logging
 import re
 from collections import OrderedDict
+from typing import List, Tuple
 
 import sqlalchemy as sa
 from flask import Blueprint, current_app, g, jsonify, redirect, \
     render_template, request, session, url_for
 from flask_login import current_user
+from six import add_metaclass
 from sqlalchemy import func, orm
 from sqlalchemy.sql.expression import asc, desc, nullsfirst, nullslast
 from werkzeug.exceptions import BadRequest
@@ -23,7 +25,7 @@ from werkzeug.exceptions import BadRequest
 from abilian.core.entities import Entity
 from abilian.core.extensions import db
 from abilian.i18n import _l
-from abilian.services import audit_service
+from abilian.services import audit_service, get_service
 from abilian.services.security import READ  # noqa
 from abilian.services.vocabularies.models import BaseVocabulary
 
@@ -54,8 +56,10 @@ class ModuleAction(Action):
 
     def __init__(self, module, group, name, *args, **kwargs):
         self.group = group
-        super(ModuleAction, self).__init__(module.action_category, name, *args,
-                                           **kwargs)
+        super(ModuleAction, self).__init__(
+            module.action_category, name, *args,
+            **kwargs
+        )
 
     def pre_condition(self, context):
         module = actions.context.get('module')
@@ -100,10 +104,8 @@ def add_to_recent_items(entity, type='ignored'):
 def expose(url='/', methods=('GET',)):
     """Use this decorator to expose views in your view classes.
 
-    `url`
-      Relative URL for the view
-    `methods`
-      Allowed HTTP methods. By default only GET is allowed.
+    `url`   Relative URL for the view `methods`   Allowed HTTP methods.
+    By default only GET is allowed.
     """
 
     def wrap(f):
@@ -122,7 +124,7 @@ def labelize(s):
 def make_single_view(form, **options):
     panels = []
     for gr in form._groups.items():
-        panel = Panel(gr[0], *[Row(x) for x in gr[1]])
+        panel = Panel(gr[0], * [Row(x) for x in gr[1]])
         panels.append(panel)
     return SingleView(form, *panels, **options)
 
@@ -133,7 +135,7 @@ class ModuleView(object):
     Provide :attr:`module`.
     """
     #: :class:`Module` instance
-    module = None
+    module = None  # type: Module
 
     def __init__(self, module, *args, **kwargs):
         self.module = module
@@ -157,8 +159,8 @@ class BaseEntityView(ModuleView):
     def breadcrumb(self):
         return BreadcrumbItem(
             label=self.obj.name or self.obj.id,
-            url=Endpoint(
-                '.entity_view', entity_id=self.obj.id))
+            url=Endpoint('.entity_view', entity_id=self.obj.id),
+        )
 
     def prepare_args(self, args, kwargs):
         args, kwargs = super(BaseEntityView, self).prepare_args(args, kwargs)
@@ -176,7 +178,8 @@ class BaseEntityView(ModuleView):
             view_template=self.module.view_template,
             view=self,
             module=self.module,
-            **self.module.view_options)
+            **self.module.view_options
+        )
 
     def check_access(self):
         return self._check_view_permission(self)
@@ -185,7 +188,7 @@ class BaseEntityView(ModuleView):
         """
         :param view: a :class:`ObjectView` class or instance
         """
-        security = current_app.services['security']
+        security = get_service('security')
         return security.has_permission(current_user, view.permission, self.obj)
 
     @property
@@ -203,33 +206,38 @@ class BaseEntityView(ModuleView):
         cls_permissions = dict(self.Model.__default_permissions__)
 
         if self.permission in cls_permissions:
-            security = current_app.services['security']
+            security = get_service('security')
             return security.has_permission(
                 current_user,
                 create_cls.permission,
                 obj=self.obj,
-                roles=cls_permissions[permission])
+                roles=cls_permissions[permission],
+            )
         return False
 
 
 EDIT_ACTION = Action(
     'module',
     'object:view',
-    title=_l(u'Edit'),
+    title=_l('Edit'),
     button='default',
     condition=lambda ctx: ctx['view'].can_edit,
     icon=FAIcon('edit'),
-    url=lambda ctx: url_for('.entity_edit', **{ctx['view'].pk: ctx['view'].obj.id}),
+    url=lambda ctx: url_for('.entity_edit',
+                            **{ctx['view'].pk: ctx['view'].obj.id}),
 )
 
 DELETE_ACTION = Action(
     'module',
     'object:view',
-    title=_l(u'Delete'),
+    title=_l('Delete'),
     button='danger',
     condition=lambda ctx: ctx['view'].can_delete,
     icon=FAIcon('trash fa-inverse'),
-    url=lambda ctx: url_for('.entity_delete', **{ctx['view'].pk: ctx['view'].obj.id}),
+    url=lambda ctx: url_for(
+        '.entity_delete',
+        **{ctx['view'].pk: ctx['view'].obj.id}
+    ),
 )
 DELETE_ACTION.template = 'widgets/frontend_action_delete_confim.html'
 
@@ -248,7 +256,10 @@ class EntityView(BaseEntityView, ObjectView):
         module = self.module
         related_views = [v.render(self.obj) for v in module.related_views]
         rendered_entity = self.single_view.render(
-            self.obj, self.form, related_views=related_views)
+            self.obj,
+            self.form,
+            related_views=related_views,
+        )
         audit_entries = audit_service.entries_for(self.obj)
 
         return {
@@ -272,7 +283,7 @@ class EntityEdit(BaseEntityView, ObjectEdit):
             'rendered_entity': rendered_entity,
             'show_new_comment_form': False,
             'show_new_attachment_form': False,
-            'module': self.module
+            'module': self.module,
         }
 
 
@@ -292,7 +303,7 @@ class EntityCreate(BaseEntityView, ObjectCreate):
         return {
             'rendered_entity': rendered_entity,
             'for_new': True,
-            'module': self.module
+            'module': self.module,
         }
 
 
@@ -301,8 +312,7 @@ class EntityDelete(BaseEntityView, ObjectDelete):
 
 
 class ListJson(ModuleView, JSONView):
-    """JSON endpoint, for AJAX-backed table views.
-    """
+    """JSON endpoint, for AJAX-backed table views."""
 
     def data(self, *args, **kwargs):
         echo = int(kwargs.get("sEcho", 0))
@@ -319,7 +329,8 @@ class ListJson(ModuleView, JSONView):
         table_view = AjaxMainTableView(
             columns=self.module.list_view_columns,
             name=self.module.managed_class.__name__.lower(),
-            ajax_source=url_for('.list_json'))
+            ajax_source=url_for('.list_json'),
+        )
 
         data = [table_view.render_line(e) for e in entities]
         result = {
@@ -334,8 +345,8 @@ class ListJson(ModuleView, JSONView):
 class ModuleMeta(type):
     """Module metaclass.
 
-    Does some precalculations (like getting list of view methods from the
-    class) to avoid calculating them for each view class instance.
+    Does some precalculations (like getting list of view methods from
+    the class) to avoid calculating them for each view class instance.
     """
 
     def __init__(cls, classname, bases, fields):
@@ -361,10 +372,8 @@ class ModuleMeta(type):
 
 
 class ModuleComponent(object):
-    """
-    A component that provide new functions for a :class:`Module`
-    """
-    name = None
+    """A component that provide new functions for a :class:`Module`"""
+    name = None  # type: str
 
     def __init__(self, name=None):
         if name is not None:
@@ -378,26 +387,24 @@ class ModuleComponent(object):
         self.init()
 
     def init(self, *args, **kwargs):
-        """
-        Implements this in components
-        """
+        """Implements this in components."""
         pass
 
     def get_actions(self):
         return []
 
 
+@add_metaclass(ModuleMeta)
 class Module(object):
-    __metaclass__ = ModuleMeta
 
-    id = None
-    endpoint = None
-    label = None
-    managed_class = None
+    id = None  # type: str
+    endpoint = None  # type: str
+    label = None  # type: str
+    managed_class = None  # type: type
     list_view = None
-    list_view_columns = []
+    list_view_columns = []  # type: List
     single_view = None
-    components = ()
+    components = ()  # type: Tuple
 
     # class based views. If not provided will be automaticaly created from
     # EntityView etc defined above
@@ -407,6 +414,7 @@ class Module(object):
     create_cls = EntityCreate
     delete_cls = EntityDelete
     json_search_cls = JSONWhooshSearch
+    JSON2_SEARCH_LENGTH = 50
 
     # form_class. Used when view_cls/edit_cls are not provided
     edit_form_class = None
@@ -418,12 +426,17 @@ class Module(object):
     static_folder = None
     view_template = None
     view_options = None
-    related_views = []
+    related_views = []  # type: List[RelatedView]
     blueprint = None
-    search_criterions = (search.TextSearchCriterion(
-        "name", attributes=('name', 'nom')),)
-    tableview_options = {}  # used mostly to change datatable search_label
-    _urls = []
+    search_criterions = (
+        search.TextSearchCriterion(
+            "name",
+            attributes=('name', 'nom'),
+        ),
+    )
+    # used mostly to change datatable search_label
+    tableview_options = {}  # type: ignore
+    _urls = []  # type: List[Tuple]
 
     def __init__(self):
         # If endpoint name is not provided, get it from the class name
@@ -457,13 +470,15 @@ class Module(object):
             Model=self.managed_class,
             pk='entity_id',
             module=self,
-            base_template=self.base_template)
+            base_template=self.base_template,
+        )
         self._setup_view(
             "/<int:entity_id>",
             'entity_view',
             self.view_cls,
             Form=self.view_form_class,
-            **kw)
+            **kw
+        )
         view_endpoint = self.endpoint + '.entity_view'
 
         self._setup_view(
@@ -472,7 +487,8 @@ class Module(object):
             self.edit_cls,
             Form=self.edit_form_class,
             view_endpoint=view_endpoint,
-            **kw)
+            **kw
+        )
 
         self._setup_view(
             "/new",
@@ -481,7 +497,8 @@ class Module(object):
             Form=self.edit_form_class,
             chain_create_allowed=self.view_new_save_and_add,
             view_endpoint=view_endpoint,
-            **kw)
+            **kw
+        )
 
         self._setup_view(
             "/<int:entity_id>/delete",
@@ -489,7 +506,8 @@ class Module(object):
             self.delete_cls,
             Form=self.edit_form_class,
             view_endpoint=view_endpoint,
-            **kw)
+            **kw
+        )
 
         self._setup_view("/json", 'list_json', ListJson, module=self)
 
@@ -497,13 +515,17 @@ class Module(object):
             '/json_search',
             'json_search',
             self.json_search_cls,
-            Model=self.managed_class)
+            Model=self.managed_class,
+        )
 
         self.init_related_views()
 
-        # copy criterions instances; without that they may be shared by subclasses
-        self.search_criterions = tuple((copy.deepcopy(c)
-                                        for c in self.search_criterions))
+        # copy criterions instances; without that they may be shared by
+        # subclasses
+        self.search_criterions = tuple((
+            copy.deepcopy(c)
+            for c in self.search_criterions
+        ))
         for sc in self.search_criterions:
             sc.model = self.managed_class
 
@@ -516,9 +538,7 @@ class Module(object):
         return self.__components.get(name)
 
     def _setup_view(self, url, attr, cls, *args, **kwargs):
-        """
-        Register class based views
-        """
+        """Register class based views."""
         view = cls.as_view(attr, *args, **kwargs)
         setattr(self, attr, view)
         self._urls.append((url, attr, view.methods))
@@ -533,7 +553,7 @@ class Module(object):
 
     @property
     def action_category(self):
-        return u'module:{}'.format(self.endpoint)
+        return 'module:{}'.format(self.endpoint)
 
     def get_grouped_actions(self):
         items = actions.for_category(self.action_category)
@@ -547,12 +567,13 @@ class Module(object):
         ACTIONS = [
             ModuleAction(
                 self,
-                u'entity',
-                u'create',
-                title=_l(u'Create New'),
+                'entity',
+                'create',
+                title=_l('Create New'),
                 icon=FAIcon('plus'),
                 endpoint=Endpoint(self.endpoint + '.entity_new'),
-                button='default',),
+                button='default',
+            ),
         ]
         for component in self.components:
             ACTIONS.extend(component.get_actions())
@@ -560,9 +581,7 @@ class Module(object):
         actions.register(*ACTIONS)
 
     def create_blueprint(self, crud_app):
-        """
-        Create a Flask blueprint for this module.
-        """
+        """Create a Flask blueprint for this module."""
         # Store admin instance
         self.crud_app = crud_app
         self.app = crud_app.app
@@ -575,16 +594,23 @@ class Module(object):
                 self.url = '%s/%s' % (self.crud_app.url, self.url)
 
         # Create blueprint and register rules
-        self.blueprint = Blueprint(self.endpoint, __name__, url_prefix=self.url)
+        self.blueprint = Blueprint(
+            self.endpoint, __name__, url_prefix=self.url)
 
         for url, name, methods in self._urls:
             self.blueprint.add_url_rule(
-                url, name, getattr(self, name), methods=methods)
+                url,
+                name,
+                getattr(self, name),
+                methods=methods,
+            )
 
         # run default_view decorator
         default_view(
-            self.blueprint, self.managed_class,
-            id_attr='entity_id')(self.entity_view)
+            self.blueprint,
+            self.managed_class,
+            id_attr='entity_id',
+        )(self.entity_view)
 
         # delay registration of our breadcrumbs to when registered on app; thus
         # 'parents' blueprint can register theirs befores ours
@@ -597,38 +623,32 @@ class Module(object):
 
     def _add_breadcrumb(self, endpoint, values):
         g.breadcrumb.append(
-            BreadcrumbItem(
-                label=self.label, url=Endpoint('.list_view')))
+            BreadcrumbItem(label=self.label, url=Endpoint('.list_view')),
+        )
 
     @property
     def base_query(self):
-        """Return a query instance for :attr:`managed_class`.
-        """
+        """Return a query instance for :attr:`managed_class`."""
         return self.managed_class.query
 
     @property
     def read_query(self):
-        """
-        Return a query instance for :attr:`managed_class` filtering on `READ`
-        permission
-        """
+        """Return a query instance for :attr:`managed_class` filtering on
+        `READ` permission."""
         return self.base_query.with_permission(READ)
 
     @property
     def listing_query(self):
-        """
-        Like `read_query`, but can be made lightweight with only columns and joins
-        of interest.
+        """Like `read_query`, but can be made lightweight with only columns and
+        joins of interest.
 
-        `read_query` can be used with exports for example, with lot more columns
-        (generallly it means more joins).
+        `read_query` can be used with exports for example, with lot more
+        columns (generallly it means more joins).
         """
         return self.base_query.with_permission(READ)
 
     def query(self, request):
-        """
-        Return filtered query based on request args
-        """
+        """Return filtered query based on request args."""
         args = request.args
         search = args.get("sSearch", "").replace("%", "").lower()
         query = self.read_query.distinct()
@@ -639,11 +659,10 @@ class Module(object):
         return query
 
     def list_query(self, request):
-        """
-        Return a filtered query based on request args, for listings.
+        """Return a filtered query based on request args, for listings.
 
-        Like `query`, but subclasses can modify it to remove costly joined loads for
-        example.
+        Like `query`, but subclasses can modify it to remove costly
+        joined loads for example.
         """
         args = request.args
         search = args.get("sSearch", "").replace("%", "").lower()
@@ -658,8 +677,8 @@ class Module(object):
     def ordered_query(self, request, query=None):
         """Order query according to request args.
 
-        If query is None, the query is generated according to request args with
-        self.query(request)
+        If query is None, the query is generated according to request
+        args with self.query(request)
         """
         if query is None:
             query = self.query(request)
@@ -676,7 +695,9 @@ class Module(object):
         for rel_col in rel_sort_names:
             sort_col = getattr(self.managed_class, rel_col)
             if hasattr(sort_col, 'property') and isinstance(
-                    sort_col.property, orm.properties.RelationshipProperty):
+                    sort_col.property,
+                    orm.properties.RelationshipProperty,
+            ):
                 # this is a related model: find attribute to filter on
                 query = query.outerjoin(sort_col_name, aliased=True)
 
@@ -687,22 +708,24 @@ class Module(object):
 
                 rel_sort_name = sort_col_def.get('relationship_sort_on', None)
                 if rel_sort_name is None:
-                    rel_sort_name = sort_col_def.get('sort_on',
-                                                     default_sort_name)
+                    rel_sort_name = sort_col_def.get(
+                        'sort_on',
+                        default_sort_name,
+                    )
                 sort_col = getattr(rel_model, rel_sort_name)
 
             # XXX: Big hack, date are sorted in reverse order by default
             if isinstance(sort_col, _DateAffinity):
                 sort_dir = 'asc' if sort_dir == 'desc' else 'desc'
             elif isinstance(sort_col, sa.types.String) or \
-                            hasattr(sort_col, 'property') and \
-                            isinstance(sort_col.property.columns[0].type, sa.types.String):
+                    hasattr(sort_col, 'property') and \
+                    isinstance(sort_col.property.columns[0].type, sa.types.String):
                 sort_col = func.lower(sort_col)
 
             try:
                 direction = desc if sort_dir == 'desc' else asc
                 sort_col = direction(sort_col)
-            except:
+            except BaseException:
                 # FIXME
                 pass
 
@@ -711,7 +734,7 @@ class Module(object):
                 nullsorder = nullslast if sort_dir == 'desc' else nullsfirst
                 try:
                     sort_col = nullsorder(sort_col)
-                except:
+                except BaseException:
                     # FIXME
                     pass
 
@@ -719,7 +742,7 @@ class Module(object):
 
         try:
             query = query.order_by(*sort_cols)
-        except:
+        except BaseException:
             # FIXME
             pass
         query.reset_joinpoint()
@@ -736,39 +759,54 @@ class Module(object):
             columns=self.list_view_columns,
             ajax_source=url_for('.list_json'),
             search_criterions=self.search_criterions,
-            options=self.tableview_options)
+            options=self.tableview_options,
+        )
         rendered_table = table_view.render()
 
         ctx = dict(
             rendered_table=rendered_table,
             module=self,
-            base_template=self.base_template)
+            base_template=self.base_template,
+        )
         return render_template("default/list_view.html", **ctx)
 
-    @expose("/json2")
-    def list_json2(self):
-        """
-        Other JSON endpoint, this time used for filling select boxes dynamically.
+    def list_json2_query_all(self, q):
+        """Implements the search query for the list_json2 endpoint.
 
-        NB: not used currently.
+        May be re-defined by a Module subclass in order to customize
+        the search results.
+
+        - Return: a list of results (not json) with an 'id' and a
+          'text' (that will be displayed in the select2).
         """
-        args = request.args
         cls = self.managed_class
-
-        q = args.get("q", "").replace("%", " ")
-        if not q or len(q) < 2:
-            raise BadRequest()
-
         query = db.session.query(cls.id, cls.name)
         query = query \
             .filter(cls.name.ilike("%" + q + "%")) \
             .distinct() \
             .order_by(cls.name) \
-            .limit(50)
-        all = query.all()
+            .limit(self.JSON2_SEARCH_LENGTH)
+        results = query.all()
+        results = [{'id': r[0], 'text': r[1]} for r in results]
+        return results
 
-        result = {'results': [{'id': r[0], 'text': r[1]} for r in all]}
-        return jsonify(result)
+    @expose("/json2")
+    def list_json2(self):
+        """Other JSON endpoint, this time used for filling select boxes
+        dynamically.
+
+        You can write your own search method in list_json2_query_all,
+        that returns a list of results (not json).
+        """
+        args = request.args
+
+        q = args.get("q", "").replace("%", " ")
+        if not q or len(q) < 2:
+            raise BadRequest()
+
+        results = self.list_json2_query_all(q)
+        results = {'results': results}
+        return jsonify(results)
 
     #
     # Utils
@@ -789,26 +827,25 @@ class Module(object):
 
 
 class RelatedView(object):
-    """A base class for related views"""
+    """A base class for related views."""
 
     def render(self, entity):
-        """
-        Return a dict with keys 'label', 'attr_name', 'rendered', 'size',
-        'show_empty', 'default_collapsed'
-        """
+        """Return a dict with keys 'label', 'attr_name', 'rendered', 'size',
+        'show_empty', 'default_collapsed'."""
         raise NotImplementedError
 
 
 class DefaultRelatedView(RelatedView):
-    """ Default view used by Module for items directly related to entity
-    """
+    """Default view used by Module for items directly related to entity."""
 
-    def __init__(self,
-                 label,
-                 attr,
-                 column_names,
-                 options=None,
-                 show_empty=False):
+    def __init__(
+            self,
+            label,
+            attr,
+            column_names,
+            options=None,
+            show_empty=False,
+    ):
         self.label = label
         self.attr = attr
         self.show_empty = show_empty
@@ -824,10 +861,10 @@ class DefaultRelatedView(RelatedView):
         return dict(
             label=self.label,
             attr_name=self.attr,
-            rendered=view.render(
-                related_entities, related_to=entity),
+            rendered=view.render(related_entities, related_to=entity),
             show_empty=self.show_empty,
-            size=len(related_entities))
+            size=len(related_entities),
+        )
 
 
 # TODO: rename to CRMApp ?
@@ -839,7 +876,8 @@ class CRUDApp(object):
         if name is None:
             name = self.__class__.__module__
             modules_signature = ','.join(
-                str(module.id) for module in self.modules)
+                str(module.id) for module in self.modules
+            )
             name = name + '-' + modules_signature
 
         self.name = name
