@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-"""
-View decorators for controlling some aspect of HTTP, mainly: Cache headers
-"""
+"""View decorators for controlling some aspect of HTTP, mainly: Cache
+headers."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
