@@ -1,7 +1,6 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
 from abilian.core.signals import register_js_api
 from abilian.web import url_for
