@@ -4,8 +4,9 @@ from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import logging
+from typing import Union
 
-from six import string_types
+from six import string_types, text_type
 from sqlalchemy import func, orm
 from sqlalchemy.sql.expression import or_
 
@@ -20,8 +21,7 @@ _UNDEFINED = UNDEFINED()
 
 
 class BaseCriterion(object):
-
-    form_default_value = _UNDEFINED
+    form_default_value = _UNDEFINED  # type: Union[UNDEFINED, text_type]
     """
     Values to set by default when adding a filter. The provided value(s) must be
     the ones used in html, not in python.
@@ -53,7 +53,6 @@ class BaseCriterion(object):
     model = property(_get_model, _set_model)
 
     def filter(self, query, module, request, searched_text, *args, **kwargs):
-
         raise NotImplementedError
 
     @property
@@ -78,13 +77,13 @@ class BaseCriterion(object):
 
 
 class TextSearchCriterion(BaseCriterion):
-    """Fulltext search on given attributes.
-    """
+    """Fulltext search on given attributes."""
 
     def __init__(self, name, label='', attributes=None, search_fmt='%{q}%'):
         super(TextSearchCriterion, self).__init__(name, label)
         self.attributes = dict.fromkeys(
-            attributes if attributes is not None else (name,))
+            attributes if attributes is not None else (name,),
+        )
         self._attributes_prepared = False
 
         if isinstance(search_fmt, string_types):
@@ -109,8 +108,11 @@ class TextSearchCriterion(BaseCriterion):
                 attr = getattr(self.model, attr_name, None)
 
             if attr is None:
-                logger.debug('Model: "%s", could not find "%s"',
-                             self.model.__class__.__name__, attr_name)
+                logger.debug(
+                    'Model: "%s", could not find "%s"',
+                    self.model.__class__.__name__,
+                    attr_name,
+                )
                 to_del.append(attr_name)
             else:
                 val.update(
@@ -118,7 +120,9 @@ class TextSearchCriterion(BaseCriterion):
                         attr=attr,
                         name=name,
                         model=model,
-                        rel_attr_name=rel_attr_name,))
+                        rel_attr_name=rel_attr_name,
+                    ),
+                )
 
         for k in to_del:
             del self.attributes[k]
@@ -166,9 +170,10 @@ class TextSearchCriterion(BaseCriterion):
         return query
 
     def get_rel_attr(self, attr_name, model):
-        """
-        For a related attribute specification, returns (related model,
-        attribute).  Returns (None, None) if model is not found, or (model, None) if
+        """For a related attribute specification, returns (related model,
+        attribute).
+
+        Returns (None, None) if model is not found, or (model, None) if
         attribute is not found.
         """
         rel_attr_name, attr_name = attr_name.split('.', 1)
@@ -183,9 +188,8 @@ class TextSearchCriterion(BaseCriterion):
         return (rel_model, attr)
 
     def is_excluded(self, attr_name, request):
-        """
-        To be overriden by subclasses that want to filter searched attributes.
-        """
+        """To be overriden by subclasses that want to filter searched
+        attributes."""
         return False
 
     @property
@@ -196,14 +200,14 @@ class TextSearchCriterion(BaseCriterion):
 class TextCriterion(TextSearchCriterion):
 
     def __init__(self, name, label='', attributes=None, search_fmt='%{q}%'):
-        super(TextCriterion, self).__init__(name, label, attributes, search_fmt)
+        super(TextCriterion, self) \
+            .__init__(name, label, attributes, search_fmt)
 
     def filter(self, query, module, request, searched_text, *args, **kwargs):
-        my_searched_text = request.values.get(self.name, u'').strip()
+        my_searched_text = request.values.get(self.name, '').strip()
         if my_searched_text:
-            return super(TextCriterion, self).filter(query, module, request,
-                                                     my_searched_text.lower(),
-                                                     *args, **kwargs)
+            return super(TextCriterion, self) \
+                .filter(query, module, request, my_searched_text.lower(), *args, **kwargs)
         else:
             return query
 
@@ -221,4 +225,4 @@ class TextCriterion(TextSearchCriterion):
 
     @property
     def form_unset_value(self):
-        return u''
+        return ''
