@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -8,13 +7,15 @@ import logging
 from collections import OrderedDict
 from functools import partial
 
-import six
 import whoosh
+import whoosh.highlight
+import whoosh.searching
 import whoosh.sorting
 from flask import Blueprint, current_app, g, render_template, request, url_for
 from six import text_type
 
 from abilian.i18n import _
+from abilian.services import get_service
 from abilian.web import views
 from abilian.web.action import Endpoint
 from abilian.web.nav import BreadcrumbItem
@@ -22,7 +23,11 @@ from abilian.web.nav import BreadcrumbItem
 logger = logging.getLogger(__name__)
 
 BOOTSTRAP_MARKUP_HIGHLIGHTER = whoosh.highlight.HtmlFormatter(
-    tagname='mark', classname='', termclass='term-', between='[…]')
+    tagname='mark',
+    classname='',
+    termclass='term-',
+    between='[…]',
+)
 
 RESULTS_FRAGMENTER = whoosh.highlight.SentenceFragmenter()
 
@@ -33,28 +38,33 @@ PAGE_SIZE = 20
 MAX_LIVE_RESULTS_PER_CLASS = 5
 
 search = Blueprint(
-    'search', __name__, url_prefix="/search", template_folder='templates')
+    'search',
+    __name__,
+    url_prefix="/search",
+    template_folder='templates',
+)
 route = search.route
 
 
 def friendly_fqcn(fqcn):
-    return fqcn.rsplit(u'.', 1)[-1]
+    return fqcn.rsplit('.', 1)[-1]
 
 
 @search.url_value_preprocessor
 def init_search(endpoint, values):
     q = request.args.get("q")
     try:
-        page = max(int(request.args.get('page', 1), 1))
-    except:
+        page = max(int(request.args.get('page', 1)), 1)
+    except BaseException:
         page = 1
 
     g.breadcrumb.append(
         BreadcrumbItem(
             label='"{}"'.format(q),
             icon="search",
-            url=Endpoint(
-                'search.search_main', q=q)))
+            url=Endpoint('search.search_main', q=q),
+        ),
+    )
 
     page_kw = OrderedDict(q=q)
     object_types = request.args.getlist('object_type')
@@ -64,14 +74,17 @@ def init_search(endpoint, values):
         g.breadcrumb.append(
             BreadcrumbItem(
                 label=' | '.join(friendly_fqcn(name) for name in object_types),
-                url=Endpoint('search.search_main', **page_kw)))
+                url=Endpoint('search.search_main', **page_kw),
+            ),
+        )
 
     if page > 1:
         g.breadcrumb.append(
             BreadcrumbItem(
                 label=text_type(page),
-                url=Endpoint(
-                    'search.search_main', page=page, **page_kw)))
+                url=Endpoint('search.search_main', page=page, **page_kw),
+            ),
+        )
 
     values['q'] = q
     values['page'] = page
@@ -84,12 +97,13 @@ def install_hit_to_url():
 
 _COUNT_OBJECT_TYPE_FACET = whoosh.sorting.FieldFacet(
     "object_type",
-    maptype=whoosh.sorting.Count,)
+    maptype=whoosh.sorting.Count,
+)
 
 
 @route('')
 def search_main(q='', page=1):
-    svc = current_app.services['indexing']
+    svc = get_service('indexing')
     q = q.strip()
     page = int(request.args.get('page', page))
     search_kwargs = {'limit': page * PAGE_SIZE}
@@ -122,12 +136,14 @@ def search_main(q='', page=1):
     if by_object_type:
         # Insert 'all' to clear all filters
         is_active = len(filtered_by_type) == 0
-        all_types = (_(u'All'), len(results), page_url(object_type=(),),
-                     is_active,)
+        all_types = (
+            _('All'), len(results), page_url(object_type=(),),
+            is_active,
+        )
         by_object_type.insert(0, all_types)
 
     if filtered_by_type:
-        #FIXME: sanitize input
+        # FIXME: sanitize input
         results = svc.search(q, object_types=filtered_by_type, **search_kwargs)
 
     results.formatter = BOOTSTRAP_MARKUP_HIGHLIGHTER
@@ -152,38 +168,37 @@ def search_main(q='', page=1):
     next_pages_numbered = [(index, page_url(page=index))
                            for index in range(page_min, page_max + 1)]
 
-    return render_template(
-        'search/search.html',
-        q=q,
-        results=results,
-        results_count=results_count,
-        pagecount=pagecount,
-        filtered_by_type=filtered_by_type,
-        by_object_type=by_object_type,
-        prev_page=prev_page,
-        next_page=next_page,
-        first_page=first_page,
-        last_page=last_page,
-        next_pages_numbered=next_pages_numbered,
-        friendly_fqcn=friendly_fqcn,)
+    ctx = {
+        'q': q,
+        'results': results,
+        'results_count': results_count,
+        'pagecount': pagecount,
+        'filtered_by_type': filtered_by_type,
+        'by_object_type': by_object_type,
+        'prev_page': prev_page,
+        'next_page': next_page,
+        'first_page': first_page,
+        'last_page': last_page,
+        'next_pages_numbered': next_pages_numbered,
+        'friendly_fqcn': friendly_fqcn,
+    }
+    return render_template('search/search.html', **ctx)
 
 
 class Live(views.JSONView):
-    """
-    JSON response for live search
-    """
+    """JSON response for live search."""
 
     def data(self, q='', page=None, *args, **kwargs):
         if not q:
             q = ''
-        svc = current_app.services['indexing']
+        svc = get_service('indexing')
         url_for_hit = svc.app_state.url_for_hit
         search_kwargs = {'facet_by_type': 5}
         response = {}
         results = svc.search(q, **search_kwargs)
         datasets = {}
 
-        for typename, docs in six.iteritems(results):
+        for typename, docs in results.items():
             dataset = []
             for doc in docs:
                 # Because it happens sometimes
