@@ -1,60 +1,69 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
+import logging
 import os
 import socket
-import logging
 from collections import OrderedDict, namedtuple
 from pathlib import Path
 
-import sqlalchemy as sa
 import redis
-
-from flask import (render_template, request, flash, session, redirect, url_for,
-                   current_app, make_response)
 import six
+import sqlalchemy as sa
+import sqlalchemy.dialects
+import sqlalchemy.exc
+from flask import current_app, flash, make_response, redirect, \
+    render_template, request, session, url_for
 from six import text_type
 
-from abilian.services import get_service
-from abilian.services.security import Admin
-from abilian.core.models.subjects import User
 from abilian.core.commands import config as cmd_config
 from abilian.core.extensions import csrf
-from abilian.services.security import Anonymous
+from abilian.core.models.subjects import User
+from abilian.services import get_service
+from abilian.services.security import Admin, Anonymous
 from abilian.web.blueprints import Blueprint
 
 logger = logging.getLogger(__name__)
 setup = Blueprint(
-    'setup', __name__, allowed_roles=Anonymous, template_folder='templates')
+    'setup',
+    __name__,
+    allowed_roles=Anonymous,
+    template_folder='templates',
+)
 
 # list supported dialects and detect unavailable ones due to missing dbapi
 # module ('psycopg2' missing for example)
 
 _dialects = OrderedDict((
     ('sqlite', u'SQLite (for demo)'),
-    ('postgres', u'PostgreSQL'),))
+    ('postgres', u'PostgreSQL'),
+))
 
 _dialects_unavailable = OrderedDict()
 
-for dialect, label in six.iteritems(_dialects):
+for dialect, _label in _dialects.items():
     d = sa.dialects.registry.load(dialect)
     try:
         d.dbapi()
     except ImportError as e:
-        _dialects_unavailable[dialect] = e.message
+        _dialects_unavailable[dialect] = str(e)
 
 # enumerate steps for left column progress
 Step = namedtuple('SetupStep', ('name', 'endpoint', 'title', 'description'))
 
 _setup_steps = (
     Step('db', 'step_db', 'Setup Database', 'Setup basic database connection'),
-    Step('redis', 'step_redis', 'Setup Redis', 'Redis connection'), Step(
-        'site_info', 'step_site_info', 'Basic site informations',
-        'Site name, admin email...'),
+    Step('redis', 'step_redis', 'Setup Redis', 'Redis connection'),
+    Step(
+        'site_info',
+        'step_site_info',
+        'Basic site informations',
+        'Site name, admin email...',
+    ),
     Step('admin_account', 'step_admin_account', u'Admin account', None),
-    Step('finalize', 'finalize', 'Finalize', None))
+    Step('finalize', 'finalize', 'Finalize', None),
+)
 
 
 @setup.before_request
@@ -85,7 +94,7 @@ def common_context():
         'setup_steps': _setup_steps,
         'dialects': _dialects,
         'dialects_unavailable': _dialects_unavailable,
-        'validated_steps': session_get('validated', ())
+        'validated_steps': session_get('validated', ()),
     }
 
     ctx.update(request.setup_step_progress)
@@ -130,7 +139,9 @@ def step_db():
 
 def step_db_form():
     return render_template(
-        'setupwizard/step_db.html', data=session_get('db', {}))
+        'setupwizard/step_db.html',
+        data=session_get('db', {}),
+    )
 
 
 def step_db_validate():
@@ -152,7 +163,7 @@ def step_db_validate():
             if password:
                 db_uri += u':' + password
 
-        #FIXME: it is an error to have a username and no host, SA will interpret
+        # FIXME: it is an error to have a username and no host, SA will interpret
         # username:password as host:port
         if host:
             db_uri += u'@' + host
@@ -164,7 +175,8 @@ def step_db_validate():
 
     if dialect == u'sqlite' and (not database or database == u':memory:'):
         database = text_type(
-            Path(current_app.instance_path) / u'data' / u'sqlite.db')
+            Path(current_app.instance_path) / u'data' / u'sqlite.db',
+        )
 
     db_uri += database
 
@@ -176,7 +188,8 @@ def step_db_validate():
         password=password,
         host=host,
         port=port,
-        database=database,)
+        database=database,
+    )
     session_set('db', db_params)
 
     # test connection
@@ -185,7 +198,7 @@ def step_db_validate():
     try:
         conn = engine.connect()
     except sa.exc.OperationalError as e:
-        error = e.message
+        error = str(e)
     else:
         conn.close()
         del conn
@@ -217,7 +230,9 @@ def step_redis():
 
 def step_redis_form():
     return render_template(
-        'setupwizard/step_redis.html', data=session_get('redis', {}))
+        'setupwizard/step_redis.html',
+        data=session_get('redis', {}),
+    )
 
 
 def step_redis_validate():
@@ -225,7 +240,8 @@ def step_redis_validate():
     data = dict(
         host=form.get(u'host', u'localhost').strip(),
         port=form.get(u'port', u'').strip() or u'6379',
-        db=form.get(u'db', u'').strip() or u'1',)
+        db=form.get(u'db', u'').strip() or u'1',
+    )
 
     for k in ('port', 'db'):
         try:
@@ -239,7 +255,10 @@ def step_redis_validate():
 
     try:
         r = redis.StrictRedis(
-            host=data['host'], port=data['port'], db=data['db'])
+            host=data['host'],
+            port=data['port'],
+            db=data['db'],
+        )
     except Exception as e:
         error = u'Connection error, check parameters'
         raise e
@@ -247,8 +266,10 @@ def step_redis_validate():
     try:
         r.info()
     except redis.exceptions.InvalidResponse:
-        error = (u"Connection error: doesn't look like it's a redis server. "
-                 u"Verify host and port are those of your redis server.")
+        error = (
+            u"Connection error: doesn't look like it's a redis server. "
+            u"Verify host and port are those of your redis server."
+        )
     except redis.exceptions.ResponseError as e:
         error = u'Redis server response: {}'.format(e)
     except redis.exceptions.RedisError as e:
@@ -288,8 +309,10 @@ def get_possible_hostnames():
         for a in aliases:
             names.setdefault(a, []).extend(ips)
 
-    return sorted(u'{} ({})'.format(name, u', '.join(sorted(set(ips))))
-                  for name, ips in six.iteritems(names))
+    return sorted(
+        u'{} ({})'.format(name, u', '.join(sorted(set(ips))))
+        for name, ips in six.iteritems(names)
+    )
 
 
 def step_site_info_form():
@@ -301,7 +324,8 @@ def step_site_info_form():
     return render_template(
         'setupwizard/step_site_info.html',
         data=session_get('site_info', default_data),
-        suggested_hosts=get_possible_hostnames())
+        suggested_hosts=get_possible_hostnames(),
+    )
 
 
 def step_site_info_validate():
@@ -309,7 +333,8 @@ def step_site_info_validate():
     data = dict(
         sitename=form.get('sitename', u'').strip(),
         mailsender=form.get('mailsender', u'').strip(),
-        server_mode=form.get('server_mode', u'').strip())
+        server_mode=form.get('server_mode', u'').strip(),
+    )
 
     session_set('site_info', data)
     step_validated('site_info')
@@ -331,7 +356,8 @@ def step_admin_account():
 def step_admin_account_form():
     return render_template(
         'setupwizard/step_admin_account.html',
-        data=session_get('admin_account', {}))
+        data=session_get('admin_account', {}),
+    )
 
 
 def step_admin_account_validate():
@@ -343,7 +369,8 @@ def step_admin_account_validate():
         name=form.get('name', u'').strip(),
         firstname=form.get('firstname', u'').strip(),
         password=password,
-        confirm_password=confirm_password)
+        confirm_password=confirm_password,
+    )
     session_set('admin_account', admin_user)
 
     if password != confirm_password:
@@ -372,7 +399,9 @@ def finalize():
 def finalize_form():
     file_location = os.path.join(current_app.instance_path, 'config.py')
     return render_template(
-        'setupwizard/finalize.html', file_location=file_location)
+        'setupwizard/finalize.html',
+        file_location=file_location,
+    )
 
 
 def finalize_validate():
@@ -410,7 +439,8 @@ def finalize_validate():
         static_url_path=setup_app.static_url_path,
         static_folder=setup_app.static_folder,
         template_folder=setup_app.template_folder,
-        instance_path=setup_app.instance_path,)
+        instance_path=setup_app.instance_path,
+    )
     with app.test_request_context('/setup/finalize'):
         app.create_db()
         db_session = app.db.session()
@@ -419,7 +449,8 @@ def finalize_validate():
             password=admin_account['password'],
             last_name=admin_account['name'],
             first_name=admin_account['firstname'],
-            can_login=True)
+            can_login=True,
+        )
         db_session.add(admin)
         security = get_service('security')
         security.grant_role(admin, Admin)
@@ -431,6 +462,8 @@ def finalize_validate():
         render_template(
             'setupwizard/done.html',
             config_file=config_file,
-            logging_file=logging_file),
-        200)
+            logging_file=logging_file,
+        ),
+        200,
+    )
     return response
