@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, print_function, unicode_literals
 
 import sqlalchemy as sa
@@ -14,17 +13,15 @@ from .extension import ENTITY_DEFAULT_NS_ATTR
 
 
 class TagCriterion(BaseCriterion):
-    """
-    Filter entities with selected tag(s).
-    """
-    form_default_value = u''
+    """Filter entities with selected tag(s)."""
+    form_default_value = ''
 
     def __init__(self, *args, **kwargs):
         if len(args) == 0:
             kwargs.setdefault('name', 'tags')
 
         if len(args) < 2:
-            kwargs.setdefault('label', _(u'Tags'))
+            kwargs.setdefault('label', _('Tags'))
 
         super(TagCriterion, self).__init__(*args, **kwargs)
 
@@ -37,12 +34,17 @@ class TagCriterion(BaseCriterion):
     def valid_tags(self):
         join_clause = entity_tag_tbl.join(
             self.model,
-            self.model.id == entity_tag_tbl.c.entity_id,)
+            self.model.id == entity_tag_tbl.c.entity_id,
+        )
         model_tags = sa.sql.select(
-            [entity_tag_tbl.c.tag_id], from_obj=join_clause)
-        return Tag.query.filter(Tag.ns == self.ns,
-                                Tag.id.in_(model_tags))\
-                        .all()
+            [entity_tag_tbl.c.tag_id],
+            from_obj=join_clause,
+        )
+        return Tag.query.filter(
+            Tag.ns == self.ns,
+            Tag.id.in_(model_tags),
+        )\
+            .all()
 
     def get_request_values(self, request):
         tag_ids = []
@@ -69,10 +71,14 @@ class TagCriterion(BaseCriterion):
             return query
 
         cond = sa.sql.exists(
-            sa.sql.select([1],
-                          sa.sql.and_(
-                              entity_tag_tbl.c.entity_id == self.model.id,
-                              entity_tag_tbl.c.tag_id.in_(t.id for t in tags))))
+            sa.sql.select(
+                [1],
+                sa.sql.and_(
+                    entity_tag_tbl.c.entity_id == self.model.id,
+                    entity_tag_tbl.c.tag_id.in_(t.id for t in tags),
+                ),
+            ),
+        )
         return query.filter(cond)
 
     @property
