@@ -3,14 +3,13 @@
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
-from unittest import TestCase
-
 import pytest
 import sqlalchemy as sa
 from flask.signals import request_started
 from wtforms import Form, IntegerField, StringField
 
 # Import for side-effects (monkey-patch)
+# noinspection PyUnresolvedReferences
 import abilian.web.forms  # noqa
 from abilian.core.entities import Entity
 from abilian.testing import BaseTestCase
@@ -23,9 +22,7 @@ skip = pytest.mark.skip
 
 
 class WidgetTestModel(Entity):
-    """
-    Mock model.
-    """
+    """Mock model."""
     __tablename__ = 'widget_test_model'
     id = sa.Column(sa.Integer, primary_key=True)
     price = sa.Column(sa.Integer)
@@ -41,9 +38,9 @@ class WidgetTestModel(Entity):
 
 
 class DummyForm(Form):
-    name = StringField(u'Nom du véhicule')
-    price = IntegerField(u"Prix du véhicule")
-    email = StringField(u'email', view_widget=EmailWidget())
+    name = StringField('Nom du véhicule')
+    price = IntegerField("Prix du véhicule")
+    email = StringField('email', view_widget=EmailWidget())
 
 
 class TableViewTestCase(BaseTestCase):
@@ -81,10 +78,13 @@ class ModelViewTestCase(BaseTestCase):
         with self.app.test_request_context():
             panels = [Panel('main', Row('name'), Row('price'), Row('email'))]
             view = SingleView(
-                DummyForm, *panels, view=dict(
-                    can_edit=False, can_delete=False))
+                DummyForm, *panels, view=dict(can_edit=False, can_delete=False)
+            )
             model = WidgetTestModel(
-                name="Renault Megane", price=10000, email="joe@example.com")
+                name="Renault Megane",
+                price=10000,
+                email="joe@example.com",
+            )
             form = DummyForm(obj=model)
             res = view.render(model, form)
 
@@ -107,37 +107,39 @@ class ModelViewTestCase(BaseTestCase):
             assert "10000" in res
 
 
-class TestLinkify(TestCase):
-
-    EXPECTED = (u'<a href="http://example.com">example.com</a>'
-                u'&nbsp;<i class="fa fa-external-link"></i>')
-
-    def test_http(self):
-        value = "http://example.com"
-        result = linkify_url(value)
-        assert result == self.EXPECTED
-
-    def test_no_http(self):
-        value = "example.com"
-        result = linkify_url(value)
-        assert result == self.EXPECTED
+EXPECTED = (
+    '<a href="http://example.com">example.com</a>'
+    '&nbsp;<i class="fa fa-external-link"></i>'
+)
 
 
-class TestText2Html(TestCase):
+def test_http():
+    value = "http://example.com"
+    result = linkify_url(value)
+    assert result == EXPECTED
 
-    def test1(self):
-        result = text2html("a")
-        self.assertEqual(result, "a")
 
-    def test2(self):
-        result = text2html("a\nb")
-        self.assertEqual(str(result), "<p>a</p>\n<p>b</p>")
+def test_no_http():
+    value = "example.com"
+    result = linkify_url(value)
+    assert result == EXPECTED
 
-    def test3(self):
-        result = text2html("a\n\nb")
-        self.assertEqual(str(result), "<p>a</p>\n<p>b</p>")
 
-    def test4(self):
-        result = text2html("a\n<a>toto</a>")
-        self.assertEqual(
-            str(result), "<p>a</p>\n<p>&lt;a&gt;toto&lt;/a&gt;</p>")
+def test1():
+    result = text2html("a")
+    assert result == "a"
+
+
+def test2():
+    result = text2html("a\nb")
+    assert str(result) == "<p>a</p>\n<p>b</p>"
+
+
+def test3():
+    result = text2html("a\n\nb")
+    assert str(result) == "<p>a</p>\n<p>b</p>"
+
+
+def test4():
+    result = text2html("a\n<a>toto</a>")
+    assert str(result) == "<p>a</p>\n<p>&lt;a&gt;toto&lt;/a&gt;</p>"
