@@ -1,7 +1,5 @@
 # coding=utf-8
-"""
-Base classes for file download
-"""
+"""Base classes for file download."""
 from __future__ import absolute_import, print_function, unicode_literals
 
 from datetime import datetime, timedelta
@@ -25,11 +23,13 @@ class BaseFileDownload(View):
     #: in url (path or query string), such as a timestamp, a serial, a hash...
     expire_vary_arg = None
 
-    def __init__(self,
-                 set_expire=None,
-                 expire_offset=None,
-                 expire_vary_arg=None,
-                 as_attachment=None):
+    def __init__(
+            self,
+            set_expire=None,
+            expire_offset=None,
+            expire_vary_arg=None,
+            as_attachment=None,
+    ):
         # override class default value only if arg is specified in constructor. This
         # allows subclasses to easily override theses defaults.
         if set_expire is not None:
@@ -49,19 +49,24 @@ class BaseFileDownload(View):
 
     def prepare_args(self, args, kwargs):
         if self.set_expire:
-            vary_arg = kwargs.get(self.expire_vary_arg,
-                                  request.args.get(self.expire_vary_arg))
+            vary_arg = kwargs.get(
+                self.expire_vary_arg,
+                request.args.get(self.expire_vary_arg),
+            )
             if vary_arg is None:
                 # argument for timestamp, serial etc is missing. We must refuse to serve
                 # an image with expiry date set up to maybe 1 year from now.
                 # Check the code that has generated this url!
                 raise BadRequest('File version marker is missing ({}=?)'.format(
-                    repr(self.expire_vary_arg)))
+                    repr(self.expire_vary_arg),
+                ))
 
         args, kwargs = super(BaseFileDownload, self).prepare_args(args, kwargs)
-        kwargs['attach'] = request.args.get('attach',
-                                            self.as_attachment,
-                                            type=bool)
+        kwargs['attach'] = request.args.get(
+            'attach',
+            self.as_attachment,
+            type=bool,
+        )
         return args, kwargs
 
     def make_response(self, *args, **kwargs):
@@ -81,16 +86,19 @@ class BaseFileDownload(View):
         :param s: requested maximum width/height size
         """
         response = self.make_response(*args, **kwargs)
-        response.headers['content-type'] = self.get_content_type(*args,
-                                                                 **kwargs)
+        response.headers['content-type'] = self.get_content_type(
+            *args, **kwargs
+        )
 
         if attach:
             filename = self.get_filename(*args, **kwargs)
             if not filename:
-                filename = u'file.bin'
-            response.headers.add('Content-Disposition',
-                                 u'attachment',
-                                 filename=filename)
+                filename = 'file.bin'
+            response.headers.add(
+                'Content-Disposition',
+                'attachment',
+                filename=filename,
+            )
 
         self.set_cache_headers(response)
         return response
@@ -100,7 +108,8 @@ class BaseFileDownload(View):
             response.cache_control.public = False
             response.cache_control.private = True
             response.cache_control.max_age = int(
-                self.expire_offset.total_seconds())
+                self.expire_offset.total_seconds(),
+            )
             response.expires = utc_dt(datetime.utcnow() + self.expire_offset)
 
 
@@ -133,4 +142,5 @@ class BaseBlobDownload(BaseFileDownload):
             mimetype=self.content_type,
             cache_timeout=0,
             add_etags=False,
-            conditional=False)
+            conditional=False,
+        )
