@@ -1,7 +1,5 @@
 # coding=utf-8
-"""
-Blueprint for views of dynamic images
-"""
+"""Blueprint for views of dynamic images."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -11,13 +9,15 @@ from pathlib import Path
 
 import pkg_resources
 import sqlalchemy as sa
+import sqlalchemy.orm
 from flask import Blueprint, make_response, render_template, request
 from six import text_type
 from werkzeug.exceptions import BadRequest, NotFound
 
 from abilian.core.models.blob import Blob
 from abilian.core.models.subjects import User
-from abilian.services.image import CROP, RESIZE_MODES, get_size
+from abilian.services.image import CROP, RESIZE_MODES, get_format, get_size, \
+    resize
 from abilian.web.util import url_for
 
 from .files import BaseFileDownload
@@ -26,8 +26,11 @@ blueprint = Blueprint('images', __name__, url_prefix='/images')
 route = blueprint.route
 
 DEFAULT_AVATAR = Path(
-    pkg_resources.resource_filename('abilian.web',
-                                    'resources/img/avatar-default.png'))
+    pkg_resources.resource_filename(
+        'abilian.web',
+        'resources/img/avatar-default.png',
+    ),
+)
 DEFAULT_AVATAR_MD5 = hashlib.md5(DEFAULT_AVATAR.open('rb').read()).hexdigest()
 
 
@@ -48,12 +51,14 @@ class BaseImageView(BaseFileDownload):
             size = int(size)
         except ValueError:
             raise BadRequest(
-                'Invalid value for "s": {}. Not an integer.'.format(repr(size)))
+                'Invalid value for "s": {:d}. Not an integer.'.format(size),
+            )
 
-        if self.max_size is not None:
-            if size > self.max_size:
-                raise BadRequest('Size too large: {:d} (max: {:d})'.format(
-                    size, self.max_size))
+        if self.max_size is not None and size > self.max_size:
+            raise BadRequest('Size too large: {:d} (max: {:d})'.format(
+                size,
+                self.max_size,
+            ))
 
         kwargs['size'] = size
 
@@ -67,22 +72,20 @@ class BaseImageView(BaseFileDownload):
     def make_response(self, image, size, mode, *args, **kwargs):
         """
         :param image: image as bytes
-        :param s: requested maximum width/height size
+        :param size: requested maximum width/height size
         """
-        from abilian.services.image import resize, get_format
-
         try:
             fmt = get_format(image)
         except IOError:
             #  not a known image file
             raise NotFound()
 
-        self.content_type = u'image/png' if fmt == 'PNG' else u'image/jpeg'
-        ext = u'.' + text_type(fmt.lower())
+        self.content_type = 'image/png' if fmt == 'PNG' else 'image/jpeg'
+        ext = '.' + text_type(fmt.lower())
 
         filename = kwargs.get('filename')
         if not filename:
-            filename = u'image'
+            filename = 'image'
         if not filename.lower().endswith(ext):
             filename += ext
         self.filename = filename
@@ -104,8 +107,7 @@ class BaseImageView(BaseFileDownload):
 
 
 class StaticImageView(BaseImageView):
-    """
-    View for static assets not served by static directory.
+    """View for static assets not served by static directory.
 
     Useful for default avatars for example.
     """
@@ -128,8 +130,8 @@ class StaticImageView(BaseImageView):
 
 
 class BlobView(BaseImageView):
-    """
-    Default :attr:`expire_vary_arg` to `"md5"`.
+    """Default :attr:`expire_vary_arg` to `"md5"`.
+
     :attr:`set_expire` is set to `False` by default.
     """
     expire_vary_arg = 'md5'
@@ -142,13 +144,13 @@ class BlobView(BaseImageView):
 
     def prepare_args(self, args, kwargs):
         args, kwargs = BaseImageView.prepare_args(self, args, kwargs)
-        b_id = kwargs.get(self.id_arg)
+        blob_id = kwargs.get(self.id_arg)
         try:
-            b_id = int(b_id)
+            blob_id = int(blob_id)
         except ValueError:
-            raise BadRequest('Invalid image id: {}'.format(repr(b_id)))
+            raise BadRequest('Invalid blob id: {}'.format(repr(blob_id)))
 
-        blob = Blob.query.get(b_id)
+        blob = Blob.query.get(blob_id)
         if not blob:
             raise NotFound()
 
@@ -171,8 +173,8 @@ class UserMugshot(BaseImageView):
 
         user_id = kwargs['user_id']
         user = User.query \
-          .options(sa.orm.undefer(User.photo)) \
-          .get(user_id)
+            .options(sa.orm.undefer(User.photo)) \
+            .get(user_id)
 
         if user is None:
             raise NotFound()
@@ -184,8 +186,8 @@ class UserMugshot(BaseImageView):
     def make_response(self, user, image, size, *args, **kwargs):
         if image:
             #  user has set a photo
-            return super(UserMugshot, self).make_response(image, size, *args,
-                                                          **kwargs)
+            return super(UserMugshot, self) \
+                .make_response(image, size, *args, **kwargs)
 
         # render svg avatar
         if user.last_name:
@@ -193,7 +195,7 @@ class UserMugshot(BaseImageView):
         elif user.first_name:
             letter = user.first_name[0]
         else:
-            letter = u"?"
+            letter = "?"
         letter = letter.upper()
         # generate bg color, pastel: sat=65% in hsl color space
         id_hash = hash((user.name + user.email).encode('utf-8'))
@@ -201,19 +203,26 @@ class UserMugshot(BaseImageView):
         hue = (hue * 36) / 360.0  # 10 colors: 360 / 10
         color = colorsys.hsv_to_rgb(hue, 0.65, 1.0)
         color = [int(x * 255) for x in color]
-        color = u'rgb({0[0]}, {0[1]}, {0[2]})'.format(color)
+        color = 'rgb({0[0]}, {0[1]}, {0[2]})'.format(color)
         svg = render_template(
-            'default/avatar.svg', color=color, letter=letter, size=size)
+            'default/avatar.svg',
+            color=color,
+            letter=letter,
+            size=size,
+        )
         response = make_response(svg)
-        self.content_type = u'image/svg+xml'
-        self.filename = u'avatar-{}.svg'.format(id_hash)
+        self.content_type = 'image/svg+xml'
+        self.filename = 'avatar-{}.svg'.format(id_hash)
         return response
 
 
 user_photo = UserMugshot.as_view('user_photo', set_expire=True, max_size=500)
 route("/users/<int:user_id>")(user_photo)
 route('/users/default')(StaticImageView.as_view(
-    'user_default', set_expire=True, image=DEFAULT_AVATAR))
+    'user_default',
+    set_expire=True,
+    image=DEFAULT_AVATAR,
+))
 
 
 def user_url_args(user, size):
@@ -231,7 +240,6 @@ def user_url_args(user, size):
 
 
 def user_photo_url(user, size):
-    """Return url to use for this user.
-    """
+    """Return url to use for this user."""
     endpoint, kwargs = user_url_args(user, size)
     return url_for(endpoint, **kwargs)
