@@ -1,13 +1,13 @@
 # coding=utf-8
-"""
-Class based views
-"""
+"""Class based views."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import logging
 
 import sqlalchemy as sa
+import sqlalchemy.exc
+import sqlalchemy.orm
 from flask import current_app, flash, g, redirect, render_template, request, \
     url_for
 from six import text_type
@@ -16,6 +16,7 @@ from werkzeug.exceptions import BadRequest, NotFound
 from abilian.core.entities import ValidationError
 from abilian.core.signals import activity
 from abilian.i18n import _, _l
+from abilian.services import get_service
 from abilian.services.security import CREATE, DELETE, READ, WRITE
 
 from .. import csrf, forms, nav
@@ -26,9 +27,7 @@ logger = logging.getLogger(__name__)
 
 
 class BaseObjectView(View):
-    """
-    Base class common to all database objects views.
-    """
+    """Base class common to all database objects views."""
     #: form title
     title = None
 
@@ -51,14 +50,18 @@ class BaseObjectView(View):
     #: templates with a custom base
     base_template = "base.html"
 
-    def __init__(self, Model=None, pk=None, base_template=None, *args,
-                 **kwargs):
+    def __init__(
+        self, Model=None, pk=None, base_template=None, *args,
+        **kwargs
+    ):
         View.__init__(self, *args, **kwargs)
         cls = self.__class__
         self.pk = pk if pk is not None else cls.pk
         self.Model = Model if Model is not None else cls.Model
-        self.base_template = (base_template if base_template is not None else
-                              cls.base_template)
+        self.base_template = (
+            base_template if base_template is not None else
+            cls.base_template
+        )
 
     def prepare_args(self, args, kwargs):
         args, kwargs = self.init_object(args, kwargs)
@@ -69,18 +72,17 @@ class BaseObjectView(View):
         return args, kwargs
 
     def breadcrumb(self):
-        """
-        Return :class:`..nav.BreadcrumbItem` instance for this object.
+        """Return :class:`..nav.BreadcrumbItem` instance for this object.
 
-        This method may return a list of BreadcrumbItem instances. Return
-        `None` if nothing.
+        This method may return a list of BreadcrumbItem instances.
+        Return `None` if nothing.
         """
         return None
 
     def init_object(self, args, kwargs):
-        """
-        This method is reponsible for setting :attr:`obj`. It is called during
-        :meth:`prepare_args`.
+        """This method is reponsible for setting :attr:`obj`.
+
+        It is called during :meth:`prepare_args`.
         """
         self.object_id = kwargs.pop(self.pk, None)
         if self.object_id is not None:
@@ -104,16 +106,16 @@ class BaseObjectView(View):
 
     @property
     def template_kwargs(self):
-        """
-        Template render arguments. You can override `base_template` for
-        instance. Only `view` cannot be overriden.
+        """Get template render arguments.
+
+        You may override `base_template` for instance. Only `view`
+        cannot be overriden.
         """
         return {}
 
 
 class ObjectView(BaseObjectView):
-    """View objects.
-    """
+    """View objects."""
 
     #: html template
     template = 'default/object_view.html'
@@ -128,13 +130,15 @@ class ObjectView(BaseObjectView):
     #: form instance for this view
     form = None
 
-    def __init__(self,
-                 Model=None,
-                 pk=None,
-                 Form=None,
-                 template=None,
-                 *args,
-                 **kwargs):
+    def __init__(
+        self,
+        Model=None,
+        pk=None,
+        Form=None,
+        template=None,
+        *args,
+        **kwargs
+    ):
         super(ObjectView, self).__init__(Model, pk, *args, **kwargs)
         cls = self.__class__
         self.Form = Form if Form is not None else cls.Form
@@ -162,8 +166,7 @@ class ObjectView(BaseObjectView):
 
     @property
     def template_kwargs(self):
-        """Provides :attr:`form` to templates
-        """
+        """Provides :attr:`form` to templates."""
         kw = super(ObjectView, self).template_kwargs
         kw['form'] = self.form
         return kw
@@ -172,17 +175,28 @@ class ObjectView(BaseObjectView):
 CANCEL_BUTTON = ButtonAction(
     'form',
     'cancel',
-    title=_l(u'Cancel'),
-    btn_class='default cancel'  # .cancel: if jquery.validate is used it will
+    title=_l('Cancel'),
+    btn_class='default cancel',  # .cancel: if jquery.validate is used it will
 )  # properly skip validation
 
 EDIT_BUTTON = ButtonAction(
-    'form', 'edit', btn_class='primary', title=_l(u'Save'))
+    'form',
+    'edit',
+    btn_class='primary',
+    title=_l('Save'),
+)
+
+ADD_ANOTHER_BUTTON = ButtonAction(
+    'form',
+    'create_add_another',
+    btn_class='primary',
+    title=_l('Create and add another'),
+    condition=lambda ctx: getattr(ctx['view'], 'add_another_button', False),
+)
 
 
 class ObjectEdit(ObjectView):
-    """Edit objects.
-    """
+    """Edit object."""
     template = 'default/object_edit.html'
     decorators = (csrf.support_graceful_failure,)
     permission = WRITE
@@ -203,21 +217,24 @@ class ObjectEdit(ObjectView):
     activity_verb = 'update'
 
     #: UI flash message
-    _message_success = _l(u"Entity successfully edited")
+    _message_success = _l("Entity successfully edited")
 
     view_endpoint = None
 
-    def __init__(self,
-                 Model=None,
-                 pk=None,
-                 Form=None,
-                 template=None,
-                 view_endpoint=None,
-                 message_success=None,
-                 *args,
-                 **kwargs):
+    def __init__(
+        self,
+        Model=None,
+        pk=None,
+        Form=None,
+        template=None,
+        view_endpoint=None,
+        message_success=None,
+        *args,
+        **kwargs
+    ):
         ObjectView.__init__(
-            self, Model, pk, Form, template=template, *args, **kwargs)
+            self, Model, pk, Form, template=template, *args, **kwargs
+        )
         if view_endpoint is not None:
             self.view_endpoint = view_endpoint
 
@@ -229,8 +246,8 @@ class ObjectEdit(ObjectView):
 
     def post(self, *args, **kwargs):
         # conservative: no action submitted -> cancel
-        action = self.data.get('__action', u'cancel')
-        if action == u'cancel':
+        action = self.data.get('__action', 'cancel')
+        if action == 'cancel':
             return self.cancel()
 
         return self.handle_action(action)
@@ -275,8 +292,9 @@ class ObjectEdit(ObjectView):
                                      ''.format(action.encode('utf-8')))
                 break
         else:
-            raise ValueError('Unknown action: "{}"'.format(
-                action.encode('utf-8')))
+            raise ValueError(
+                'Unknown action: "{}"'.format(action.encode('utf-8')),
+            )
 
         self.action = action
         self.button = button
@@ -285,33 +303,35 @@ class ObjectEdit(ObjectView):
     def cancel(self):
         return self.redirect_to_view()
 
-    def edit(self):
+    def edit(self, redirect_to=None):
         if self.validate():
-            return self.form_valid()
+            return self.form_valid(redirect_to=redirect_to)
         else:
             if request.csrf_failed:
                 errors = self.form.errors
                 csrf_failed = errors.pop('csrf_token', False)
                 if csrf_failed and not errors:
-                    # failed only because of invalid/expired csrf, no error on form
+                    # failed only because of invalid/expired csrf, no error on
+                    # form
                     return self.form_csrf_invalid()
 
             resp = self.form_invalid()
             if resp:
                 return resp
 
-            flash(_(u"Please fix the error(s) below"), "error")
+            flash(_("Please fix the error(s) below"), "error")
 
         # if we end here then something wrong has happened: show form with error
         # messages
         return self.get()
 
     def before_populate_obj(self):
-        """
-        This method is called after form has been validated and before calling
-        `form.populate_obj()`. Sometimes one may want to remove a field from
-        the form because it's non-sense to store it on edited object, and use it in
-        a specific manner, for example::
+        """This method is called after form has been validated and before
+        calling `form.populate_obj()`.
+
+        Sometimes one may want to remove a field
+        from the form because it's non-sense to store it on edited object, and
+        use it in a specific manner, for example::
 
             image = form.image
             del form.image
@@ -320,15 +340,12 @@ class ObjectEdit(ObjectView):
         pass
 
     def after_populate_obj(self):
-        """
-        Called after `self.obj` values have been updated, and `self.obj`
-        attached to an ORM session.
-        """
+        """Called after `self.obj` values have been updated, and `self.obj`
+        attached to an ORM session."""
         pass
 
     def handle_commit_exception(self, exc):
-        """
-        hook point to handle exception that may happen during commit.
+        """Hook point to handle exception that may happen during commit.
 
         It is the responsability of this method to perform a rollback if it is
         required for handling `exc`. If the method does not handle `exc` if should
@@ -340,17 +357,18 @@ class ObjectEdit(ObjectView):
         return None
 
     def commit_success(self):
-        """
-        Called after object has been successfully saved to database
-        """
+        """Called after object has been successfully saved to database."""
 
     def validate(self):
         return self.form.validate()
 
-    def form_valid(self):
+    def form_valid(self, redirect_to=None):
         """Save object.
 
         Called when form is validated.
+
+        :param redirect_to: real url (created with url_for) to redirect to,
+          instead of the view by default.
         """
         session = current_app.db.session()
 
@@ -364,30 +382,38 @@ class ObjectEdit(ObjectView):
             session.flush()
             self.send_activity()
             session.commit()
+
         except ValidationError as e:
             rv = self.handle_commit_exception(e)
             if rv is not None:
                 return rv
             session.rollback()
-            flash(e.message, "error")
+            flash(str(e), "error")
             return self.get()
+
         except sa.exc.IntegrityError as e:
             rv = self.handle_commit_exception(e)
             if rv is not None:
                 return rv
             session.rollback()
             logger.error(e)
-            flash(_(u"An entity with this name already exists in the system."),
-                  "error")
+            flash(
+                _("An entity with this name already exists in the system."),
+                "error",
+            )
             return self.get()
+
         else:
             self.commit_success()
             flash(self.message_success(), "success")
-            return self.redirect_to_view()
+
+            if redirect_to:
+                return redirect(redirect_to)
+            else:
+                return self.redirect_to_view()
 
     def form_invalid(self):
-        """
-        When a form doesn't validate this method is called.
+        """When a form doesn't validate this method is called.
 
         It may return a :class:`Flask.Response` instance, to handle specific
         errors in custom screens.
@@ -400,8 +426,8 @@ class ObjectEdit(ObjectView):
         return None
 
     def form_csrf_invalid(self):
-        """
-        Called when a form doesn't validate *only* because of csrf token expiration.
+        """Called when a form doesn't validate *only* because of csrf token
+        expiration.
 
         This works only if form is an instance of :class:`flask_wtf.form.SecureForm`.
         Else default CSRF protection (before request) will take place.
@@ -418,33 +444,36 @@ class ObjectEdit(ObjectView):
             actor=g.user,
             verb=self.activity_verb,
             object=self.obj,
-            target=self.activity_target)
+            target=self.activity_target,
+        )
 
     @property
     def activity_target(self):
-        """
-        Return `target` to use when creating activity.
-        """
+        """Return `target` to use when creating activity."""
         return None
 
 
 CREATE_BUTTON = ButtonAction(
-    'form', 'create', btn_class='primary', title=_l(u'Create'))
+    'form',
+    'create',
+    btn_class='primary',
+    title=_l('Create'),
+)
 CHAIN_CREATE_BUTTON = ButtonAction(
     'form',
     'chain_create',
     btn_class='primary',
-    title=_l(u'Create and add new'),
+    title=_l('Create and add new'),
     endpoint=lambda ctx: Endpoint(request.endpoint, **request.view_args),
-    condition=lambda ctx: getattr(ctx['view'], 'chain_create_allowed', False))
+    condition=lambda ctx: getattr(ctx['view'], 'chain_create_allowed', False),
+)
 
 
 class ObjectCreate(ObjectEdit):
-    """Create a new object.
-    """
+    """Create a new object."""
     permission = CREATE
     activity_verb = 'post'
-    _message_success = _l(u"Entity successfully added")
+    _message_success = _l("Entity successfully added")
 
     #: set to `True` to show 'Save and add new' button
     chain_create_allowed = False
@@ -501,16 +530,18 @@ class ObjectCreate(ObjectEdit):
         return self.redirect_to_index()
 
 
-DELETE_BUTTON = ButtonAction('form', 'delete', title=_l(u'Delete'))
+DELETE_BUTTON = ButtonAction('form', 'delete', title=_l('Delete'))
 
 
 class ObjectDelete(ObjectEdit):
-    """Delete object. Supports DELETE verb.
+    """Delete object.
+
+    Supports the DELETE verb.
     """
     methods = ['POST']
     permission = DELETE
     activity_verb = 'delete'
-    _message_success = _l(u"Entity deleted")
+    _message_success = _l("Entity deleted")
 
     init_object = BaseObjectView.init_object
 
@@ -525,7 +556,8 @@ class ObjectDelete(ObjectEdit):
             actor=g.user,
             verb="delete",
             object=self.obj,
-            target=self.activity_target)
+            target=self.activity_target,
+        )
         try:
             session.commit()
         except sa.exc.IntegrityError as e:
@@ -534,8 +566,10 @@ class ObjectDelete(ObjectEdit):
                 return rv
             session.rollback()
             logger.error(e)
-            flash(_("This entity is referenced by another object and cannot be deleted."),
-                  "error")
+            flash(
+                _("This entity is referenced by another object and cannot be deleted."),
+                "error",
+            )
             return self.redirect_to_view()
         else:
             flash(self.message_success(), 'success')
@@ -550,21 +584,26 @@ class JSONBaseSearch(JSONView):
 
     def __init__(self, *args, **kwargs):
         Model = kwargs.pop('Model', self.Model)
-        minimum_input_length = kwargs.pop('minimum_input_length',
-                                          self.minimum_input_length)
+        minimum_input_length = kwargs.pop(
+            'minimum_input_length',
+            self.minimum_input_length,
+        )
         super(JSONBaseSearch, self).__init__(*args, **kwargs)
         self.Model = Model
         self.minimum_input_length = minimum_input_length
 
     def prepare_args(self, args, kwargs):
         args, kwargs = JSONView.prepare_args(self, args, kwargs)
-        kwargs['q'] = kwargs.get("q", u'').replace(u"%", u" ").lower()
+        kwargs['q'] = kwargs.get("q", '').replace("%", " ").lower()
         return args, kwargs
 
     def data(self, q, *args, **kwargs):
         if self.minimum_input_length and len(q) < self.minimum_input_length:
-            raise BadRequest('Minimum query length is {:d}'.format(
-                self.minimum_input_length),)
+            raise BadRequest(
+                'Minimum query length is {:d}'.format(
+                    self.minimum_input_length,
+                ),
+            )
 
         results = []
         for obj in self.get_results(q, **kwargs):
@@ -576,8 +615,7 @@ class JSONBaseSearch(JSONView):
         raise NotImplementedError
 
     def get_item(self, obj):
-        """
-        Return a result item
+        """Return a result item.
 
         :param obj: Instance object
         :returns: a dictionnary with at least `id` and `text` values
@@ -586,9 +624,9 @@ class JSONBaseSearch(JSONView):
 
 
 class JSONModelSearch(JSONBaseSearch):
-    """
-    Base class for json sqlalchemy model search, as used by select2 widgets for
-    example
+    """Base class for json sqlalchemy model search.
+
+    As used by select2 widgets for example.
     """
 
     def get_results(self, q, *args, **kwargs):
@@ -616,8 +654,7 @@ class JSONModelSearch(JSONBaseSearch):
         return obj.name
 
     def get_item(self, obj):
-        """
-        Return a result item.
+        """Return a result item.
 
         :param obj: Instance object
         :returns: a dictionnary with at least `id` and `text` values
@@ -626,14 +663,34 @@ class JSONModelSearch(JSONBaseSearch):
 
 
 class JSONWhooshSearch(JSONBaseSearch):
-    """
-    Base class for JSON Whoosh search, as used by select2 widgets for example
-    """
+    """Base class for JSON Whoosh search, as used by select2 widgets for
+    example."""
 
     def get_results(self, q, *args, **kwargs):
-        svc = current_app.services['indexing']
-        search_kwargs = {'limit': 30, 'Models': (self.Model,)}
+        svc = get_service('indexing')
+        search_kwargs = {'limit': 50, 'Models': (self.Model,)}
         results = svc.search(q, **search_kwargs)
+
+        itemkey = None
+        try:
+            # 'nom' doesn't always exist but for Contacts, sorting on
+            # the last name ('nom') feels more natural than 'name',
+            # which starts with the first name ('prenom').
+            if not results.is_empty():
+                res = results[0]
+                fields = res.fields()
+                if 'nom' in fields:
+                    itemkey = 'nom'
+                elif 'name' in fields:
+                    itemkey = 'name'
+                if itemkey:
+                    results.sort(key=lambda it: it.fields().get(itemkey))
+        except Exception:
+            if itemkey is not None:
+                msg = "we could not sort whoosh results on fields' key {}." \
+                    .format(itemkey)
+                logger.warning(msg)
+
         return results
 
     def get_item(self, hit):
